@@ -86,98 +86,98 @@ public interface Message {
       name -> (name.startsWith(Message.HDR_ROUTE_TO_IDS) && !name.equals(Message.HDR_ROUTE_TO_IDS)) ||
       (name.startsWith(Message.HDR_ROUTE_TO_ACK_IDS) && !name.equals(Message.HDR_ROUTE_TO_ACK_IDS));
 
-   SimpleString HDR_ROUTE_TO_IDS = new SimpleString("_AMQ_ROUTE_TO");
+   SimpleString HDR_ROUTE_TO_IDS = SimpleString.of("_AMQ_ROUTE_TO");
 
-   SimpleString HDR_SCALEDOWN_TO_IDS = new SimpleString("_AMQ_SCALEDOWN_TO");
+   SimpleString HDR_SCALEDOWN_TO_IDS = SimpleString.of("_AMQ_SCALEDOWN_TO");
 
-   SimpleString HDR_ROUTE_TO_ACK_IDS = new SimpleString("_AMQ_ACK_ROUTE_TO");
+   SimpleString HDR_ROUTE_TO_ACK_IDS = SimpleString.of("_AMQ_ACK_ROUTE_TO");
 
    // used by the bridges to set duplicates
-   SimpleString HDR_BRIDGE_DUPLICATE_ID = new SimpleString("_AMQ_BRIDGE_DUP");
+   SimpleString HDR_BRIDGE_DUPLICATE_ID = SimpleString.of("_AMQ_BRIDGE_DUP");
 
    /**
     * the actual time the message was expired.
     * * *
     */
-   SimpleString HDR_ACTUAL_EXPIRY_TIME = new SimpleString("_AMQ_ACTUAL_EXPIRY");
+   SimpleString HDR_ACTUAL_EXPIRY_TIME = SimpleString.of("_AMQ_ACTUAL_EXPIRY");
 
    /**
     * The original address of a message when a message is diverted or transferred through DLQ or expiry
     */
-   SimpleString HDR_ORIGINAL_ADDRESS = new SimpleString("_AMQ_ORIG_ADDRESS");
+   SimpleString HDR_ORIGINAL_ADDRESS = SimpleString.of("_AMQ_ORIG_ADDRESS");
 
    /**
     * The original address of a message when a message is transferred through DLQ or expiry
     */
-   SimpleString HDR_ORIGINAL_QUEUE = new SimpleString("_AMQ_ORIG_QUEUE");
+   SimpleString HDR_ORIGINAL_QUEUE = SimpleString.of("_AMQ_ORIG_QUEUE");
 
    /**
     * The original message ID before the message was transferred.
     */
-   SimpleString HDR_ORIG_MESSAGE_ID = new SimpleString("_AMQ_ORIG_MESSAGE_ID");
+   SimpleString HDR_ORIG_MESSAGE_ID = SimpleString.of("_AMQ_ORIG_MESSAGE_ID");
 
    /**
     * For the Message Grouping feature.
     */
-   SimpleString HDR_GROUP_ID = new SimpleString("_AMQ_GROUP_ID");
+   SimpleString HDR_GROUP_ID = SimpleString.of("_AMQ_GROUP_ID");
 
-   SimpleString HDR_GROUP_SEQUENCE = new SimpleString("_AMQ_GROUP_SEQUENCE");
+   SimpleString HDR_GROUP_SEQUENCE = SimpleString.of("_AMQ_GROUP_SEQUENCE");
 
    /**
     * to determine if the Large Message was compressed.
     */
-   SimpleString HDR_LARGE_COMPRESSED = new SimpleString("_AMQ_LARGE_COMPRESSED");
+   SimpleString HDR_LARGE_COMPRESSED = SimpleString.of("_AMQ_LARGE_COMPRESSED");
 
    /**
     * The body size of a large message before it was compressed.
     */
-   SimpleString HDR_LARGE_BODY_SIZE = new SimpleString("_AMQ_LARGE_SIZE");
+   SimpleString HDR_LARGE_BODY_SIZE = SimpleString.of("_AMQ_LARGE_SIZE");
 
    /**
     * To be used with Scheduled Delivery.
     */
-   SimpleString HDR_SCHEDULED_DELIVERY_TIME = new SimpleString("_AMQ_SCHED_DELIVERY");
+   SimpleString HDR_SCHEDULED_DELIVERY_TIME = SimpleString.of("_AMQ_SCHED_DELIVERY");
 
    /**
     * To be used with duplicate detection.
     */
-   SimpleString HDR_DUPLICATE_DETECTION_ID = new SimpleString("_AMQ_DUPL_ID");
+   SimpleString HDR_DUPLICATE_DETECTION_ID = SimpleString.of("_AMQ_DUPL_ID");
 
    /**
     * To be used with Last value queues.
     */
-   SimpleString HDR_LAST_VALUE_NAME = new SimpleString("_AMQ_LVQ_NAME");
+   SimpleString HDR_LAST_VALUE_NAME = SimpleString.of("_AMQ_LVQ_NAME");
 
    /**
     * To define the mime-type of body messages. Mainly for stomp but it could be informed on any message for user purposes.
     */
-   SimpleString HDR_CONTENT_TYPE = new SimpleString("_AMQ_CONTENT_TYPE");
+   SimpleString HDR_CONTENT_TYPE = SimpleString.of("_AMQ_CONTENT_TYPE");
 
    /**
     * The name of the validated user who sent the message. Useful for auditing.
     */
-   SimpleString HDR_VALIDATED_USER = new SimpleString("_AMQ_VALIDATED_USER");
+   SimpleString HDR_VALIDATED_USER = SimpleString.of("_AMQ_VALIDATED_USER");
 
    /**
     * The Routing Type for this message.  Ensures that this message is only routed to queues with matching routing type.
     */
-   SimpleString HDR_ROUTING_TYPE = new SimpleString("_AMQ_ROUTING_TYPE");
+   SimpleString HDR_ROUTING_TYPE = SimpleString.of("_AMQ_ROUTING_TYPE");
 
    /**
     * The original routing type of a message before getting transferred through DLQ or expiry
     */
-   SimpleString HDR_ORIG_ROUTING_TYPE = new SimpleString("_AMQ_ORIG_ROUTING_TYPE");
+   SimpleString HDR_ORIG_ROUTING_TYPE = SimpleString.of("_AMQ_ORIG_ROUTING_TYPE");
 
    /**
     * The time at which the message arrived at the broker.
     */
-   SimpleString HDR_INGRESS_TIMESTAMP = new SimpleString("_AMQ_INGRESS_TIMESTAMP");
+   SimpleString HDR_INGRESS_TIMESTAMP = SimpleString.of("_AMQ_INGRESS_TIMESTAMP");
 
    /**
     * The prefix used (if any) when sending this message.  For protocols (e.g. STOMP) that need to track this and restore
     * the prefix when the message is consumed.
     */
-   SimpleString HDR_PREFIX = new SimpleString("_AMQ_PREFIX");
+   SimpleString HDR_PREFIX = SimpleString.of("_AMQ_PREFIX");
 
    byte DEFAULT_TYPE = 0;
 
@@ -268,6 +268,10 @@ public interface Message {
     *  Return null if not scheduled. */
    Long getScheduledDeliveryTime();
 
+   void setPaged();
+
+   boolean isPaged();
+
    default Message setScheduledDeliveryTime(Long time) {
       return this;
    }
@@ -466,6 +470,7 @@ public interface Message {
 
    void reloadPersistence(ActiveMQBuffer record, CoreMessageObjectPools pools);
 
+   /** Propagate message modifications to clients. */
    default void reencode() {
       // only valid probably on AMQP
    }
@@ -496,7 +501,7 @@ public interface Message {
          if (duplicateID instanceof SimpleString) {
             return ((SimpleString) duplicateID).getData();
          } else if (duplicateID instanceof String) {
-            return new SimpleString(duplicateID.toString()).getData();
+            return SimpleString.of(duplicateID.toString()).getData();
          } else {
             return (byte[]) duplicateID;
          }
@@ -520,54 +525,75 @@ public interface Message {
       return null;
    }
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putBooleanProperty(String key, boolean value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putByteProperty(String key, byte value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putBytesProperty(String key, byte[] value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putShortProperty(String key, short value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putCharProperty(String key, char value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putIntProperty(String key, int value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putLongProperty(String key, long value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putFloatProperty(String key, float value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putDoubleProperty(String key, double value);
 
 
-
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putBooleanProperty(SimpleString key, boolean value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putByteProperty(SimpleString key, byte value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putBytesProperty(SimpleString key, byte[] value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putShortProperty(SimpleString key, short value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putCharProperty(SimpleString key, char value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putIntProperty(SimpleString key, int value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putLongProperty(SimpleString key, long value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putFloatProperty(SimpleString key, float value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putDoubleProperty(SimpleString key, double value);
 
    /**
     * Puts a String property in this message.
+    * <p>
+    * Callers must call {@link #reencode()} in order to be sent to clients
     *
     * @param key   property name
     * @param value property value
     */
    Message putStringProperty(String key, String value);
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putObjectProperty(String key, Object value) throws ActiveMQPropertyConversionException;
 
+   /** Callers must call {@link #reencode()} in order to be sent to clients */
    Message putObjectProperty(SimpleString key, Object value) throws ActiveMQPropertyConversionException;
 
    Object removeProperty(String key);
@@ -783,6 +809,12 @@ public interface Message {
 
    int getMemoryEstimate();
 
+   /** The first estimate that's been calculated without any updates. */
+   default int getOriginalEstimate() {
+      // For Core Protocol we always use the same estimate
+      return getMemoryEstimate();
+   }
+
    /**
     * This is the size of the message when persisted on disk which is used for metrics tracking
     * Note that even if the message itself is not persisted on disk (ie non-durable) this value is
@@ -801,4 +833,10 @@ public interface Message {
    default String getStringBody() {
       return null;
    }
+
+   /** Used for user context data. Useful on interceptors. */
+   Object getUserContext(Object key);
+
+   /** Used for user context data. Useful on interceptors. */
+   void setUserContext(Object key, Object value);
 }
