@@ -44,10 +44,19 @@ public class PacketImpl implements Packet {
    // 2.21.0
    public static final int ARTEMIS_2_21_0_VERSION = 132;
 
-   public static final SimpleString OLD_QUEUE_PREFIX = new SimpleString("jms.queue.");
-   public static final SimpleString OLD_TEMP_QUEUE_PREFIX = new SimpleString("jms.tempqueue.");
-   public static final SimpleString OLD_TOPIC_PREFIX = new SimpleString("jms.topic.");
-   public static final SimpleString OLD_TEMP_TOPIC_PREFIX = new SimpleString("jms.temptopic.");
+   // 2.24.0
+   public static final int ARTEMIS_2_24_0_VERSION = 133;
+
+   // 2.28.0
+   public static final int ARTEMIS_2_28_0_VERSION = 134;
+
+   // 2.29.0
+   public static final int ARTEMIS_2_29_0_VERSION = 135;
+
+   public static final SimpleString OLD_QUEUE_PREFIX = SimpleString.of("jms.queue.");
+   public static final SimpleString OLD_TEMP_QUEUE_PREFIX = SimpleString.of("jms.tempqueue.");
+   public static final SimpleString OLD_TOPIC_PREFIX = SimpleString.of("jms.topic.");
+   public static final SimpleString OLD_TEMP_TOPIC_PREFIX = SimpleString.of("jms.temptopic.");
 
    // The minimal size for all the packets, Common data for all the packets (look at
    // PacketImpl.encode)
@@ -290,7 +299,11 @@ public class PacketImpl implements Packet {
 
    public static final byte DISCONNECT_V3 = -19;
 
+   public static final byte CREATE_PRODUCER = -20;
 
+   public static final byte REMOVE_PRODUCER = -21;
+
+   public static final byte SESS_BINDINGQUERY_RESP_V5 = -22;
 
    public PacketImpl(final byte type) {
       this.type = type;
