@@ -774,39 +774,47 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
 
       recoverOperationContext();
 
-      if (me != null) {
-         //filter it like the other protocols
-         if (!(me instanceof ActiveMQRemoteDisconnectException)) {
-            ActiveMQClientLogger.LOGGER.connectionFailureDetected(this.transportConnection.getRemoteAddress(), me.getMessage(), me.getType());
-         }
-      }
       try {
-         if (this.getConnectionInfo() != null) {
-            protocolManager.removeConnection(getClientID(), this);
+         if (me != null) {
+            //filter it like the other protocols
+            if (!(me instanceof ActiveMQRemoteDisconnectException)) {
+               ActiveMQClientLogger.LOGGER.connectionFailureDetected(this.transportConnection.getRemoteAddress(), me.getMessage(), me.getType());
+            }
          }
+         try {
+            if (this.getConnectionInfo() != null) {
+               protocolManager.removeConnection(getClientID(), this);
+            }
+         } finally {
+            try {
+               disconnect(false);
+            } catch (Throwable e) {
+               // it should never happen, but never say never
+               logger.debug("OpenWireConnection::disconnect failure", e);
+            }
+
+            // there may be some transactions not associated with sessions
+            // deal with them after sessions are removed via connection removal
+            operationContext.executeOnCompletion(new IOCallback() {
+               @Override
+               public void done() {
+                  rollbackInProgressLocalTransactions();
+               }
+
+               @Override
+               public void onError(int errorCode, String errorMessage) {
+                  rollbackInProgressLocalTransactions();
+               }
+            });
+         }
+         shutdown(true);
       } finally {
          try {
-            disconnect(false);
-         } catch (Throwable e) {
-            // it should never happen, but never say never
-            logger.debug("OpenWireConnection::disconnect failure", e);
+            transportConnection.close();
+         } catch (Throwable e2) {
+            logger.warn(e2.getMessage(), e2);
          }
-
-         // there may be some transactions not associated with sessions
-         // deal with them after sessions are removed via connection removal
-         operationContext.executeOnCompletion(new IOCallback() {
-            @Override
-            public void done() {
-               rollbackInProgressLocalTransactions();
-            }
-
-            @Override
-            public void onError(int errorCode, String errorMessage) {
-               rollbackInProgressLocalTransactions();
-            }
-         });
       }
-      shutdown(true);
    }
 
    private void delayedStop(final int waitTimeMillis, final String reason, Throwable cause) {
@@ -909,9 +917,9 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
          return;
       }
 
-      SimpleString qName = SimpleString.toSimpleString(dest.getPhysicalName());
+      SimpleString qName = SimpleString.of(dest.getPhysicalName());
 
-      AutoCreateResult autoCreateResult = internalSession.checkAutoCreate(new QueueConfiguration(qName)
+      AutoCreateResult autoCreateResult = internalSession.checkAutoCreate(QueueConfiguration.of(qName)
                                                                              .setRoutingType(dest.isQueue() ? RoutingType.ANYCAST : RoutingType.MULTICAST)
                                                                              .setDurable(!dest.isTemporary())
                                                                              .setTemporary(dest.isTemporary()));
@@ -1150,7 +1158,7 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
             logger.warn("OpenWire client sending a queue remove towards {}", dest.getPhysicalName());
          }
          try {
-            server.destroyQueue(new SimpleString(dest.getPhysicalName()), getRemotingConnection());
+            server.destroyQueue(SimpleString.of(dest.getPhysicalName()), getRemotingConnection());
          } catch (ActiveMQNonExistentQueueException neq) {
             //this is ok, ActiveMQ 5 allows this and will actually do it quite often
             logger.debug("queue never existed");
