@@ -21,14 +21,13 @@ import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLEngine;
 import javax.net.ssl.SSLHandshakeException;
 import javax.net.ssl.SSLParameters;
+import java.lang.invoke.MethodHandles;
 import java.net.InetSocketAddress;
 import java.net.SocketAddress;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
-import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashSet;
-import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
@@ -96,14 +95,16 @@ import org.apache.activemq.artemis.spi.core.remoting.ssl.SSLContextFactoryProvid
 import org.apache.activemq.artemis.utils.ActiveMQThreadFactory;
 import org.apache.activemq.artemis.utils.ConfigurationHelper;
 import org.apache.activemq.artemis.utils.collections.TypedProperties;
-import org.jboss.logging.Logger;
+import org.apache.commons.lang3.exception.ExceptionUtils;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * A Netty TCP Acceptor that is embedding Netty.
  */
 public class NettyAcceptor extends AbstractAcceptor {
 
-   private static final Logger logger = Logger.getLogger(NettyAcceptor.class);
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
 
    public static final String INVM_ACCEPTOR_TYPE = "IN-VM";
@@ -161,6 +162,8 @@ public class NettyAcceptor extends AbstractAcceptor {
 
    private final String keyStorePassword;
 
+   private final String keystoreAlias;
+
    private final String trustStoreProvider;
 
    private final String trustStoreType;
@@ -233,7 +236,7 @@ public class NettyAcceptor extends AbstractAcceptor {
 
    private final boolean autoStart;
 
-   private final String redirectTo;
+   private final String router;
 
    final AtomicBoolean warningPrinted = new AtomicBoolean(false);
 
@@ -241,6 +244,8 @@ public class NettyAcceptor extends AbstractAcceptor {
 
    private volatile Object providerAgnosticSslContext;
 
+   private volatile int actualPort = 0;
+
    public NettyAcceptor(final String name,
                         final ClusterConnection clusterConnection,
                         final Map<String, Object> configuration,
@@ -325,11 +330,14 @@ public class NettyAcceptor extends AbstractAcceptor {
 
          trustManagerFactoryPlugin = ConfigurationHelper.getStringProperty(TransportConstants.TRUST_MANAGER_FACTORY_PLUGIN_PROP_NAME, TransportConstants.DEFAULT_TRUST_MANAGER_FACTORY_PLUGIN, configuration);
 
+         keystoreAlias = ConfigurationHelper.getStringProperty(TransportConstants.KEYSTORE_ALIAS_PROP_NAME, TransportConstants.DEFAULT_KEYSTORE_ALIAS, configuration);
+
          sslContextConfig = SSLContextConfig.builder()
             .keystoreProvider(keyStoreProvider)
             .keystorePath(keyStorePath)
             .keystoreType(keyStoreType)
             .keystorePassword(keyStorePassword)
+            .keystoreAlias(keystoreAlias)
             .truststoreProvider(trustStoreProvider)
             .truststorePath(trustStorePath)
             .truststoreType(trustStoreType)
@@ -343,6 +351,7 @@ public class NettyAcceptor extends AbstractAcceptor {
          keyStoreType = TransportConstants.DEFAULT_KEYSTORE_TYPE;
          keyStorePath = TransportConstants.DEFAULT_KEYSTORE_PATH;
          keyStorePassword = TransportConstants.DEFAULT_KEYSTORE_PASSWORD;
+         keystoreAlias = TransportConstants.DEFAULT_KEYSTORE_ALIAS;
          trustStoreProvider = TransportConstants.DEFAULT_TRUSTSTORE_PROVIDER;
          trustStoreType = TransportConstants.DEFAULT_TRUSTSTORE_TYPE;
          trustStorePath = TransportConstants.DEFAULT_TRUSTSTORE_PATH;
@@ -375,7 +384,7 @@ public class NettyAcceptor extends AbstractAcceptor {
 
       autoStart = ConfigurationHelper.getBooleanProperty(TransportConstants.AUTO_START, TransportConstants.DEFAULT_AUTO_START, configuration);
 
-      redirectTo = ConfigurationHelper.getStringProperty(TransportConstants.REDIRECT_TO, TransportConstants.DEFAULT_REDIRECT_TO, configuration);
+      router = ConfigurationHelper.getStringProperty(TransportConstants.ROUTER, TransportConstants.DEFAULT_ROUTER, configuration);
    }
 
    private Object loadSSLContext() {
@@ -470,12 +479,10 @@ public class NettyAcceptor extends AbstractAcceptor {
                   pipeline.addLast("ssl", getSslHandler(channel.alloc(), peerInfo.getA(), peerInfo.getB()));
                   pipeline.addLast("sslHandshakeExceptionHandler", new SslHandshakeExceptionHandler());
                } catch (Exception e) {
-                  Throwable rootCause = getRootCause(e);
+                  Throwable rootCause = ExceptionUtils.getRootCause(e);
                   ActiveMQServerLogger.LOGGER.gettingSslHandlerFailed(channel.remoteAddress().toString(), rootCause.getClass().getName() + ": " + rootCause.getMessage());
 
-                  if (ActiveMQServerLogger.LOGGER.isDebugEnabled()) {
-                     ActiveMQServerLogger.LOGGER.debug("Getting SSL handler failed", e);
-                  }
+                  logger.debug("Getting SSL handler failed", e);
                   throw e;
                }
             }
@@ -527,14 +534,14 @@ public class NettyAcceptor extends AbstractAcceptor {
 
          if (notificationService != null) {
             TypedProperties props = new TypedProperties();
-            props.putSimpleStringProperty(new SimpleString("factory"), new SimpleString(NettyAcceptorFactory.class.getName()));
-            props.putSimpleStringProperty(new SimpleString("host"), new SimpleString(host));
-            props.putIntProperty(new SimpleString("port"), port);
+            props.putSimpleStringProperty(SimpleString.of("factory"), SimpleString.of(NettyAcceptorFactory.class.getName()));
+            props.putSimpleStringProperty(SimpleString.of("host"), SimpleString.of(host));
+            props.putIntProperty(SimpleString.of("port"), actualPort);
             Notification notification = new Notification(null, CoreNotificationType.ACCEPTOR_STARTED, props);
             notificationService.sendNotification(notification);
          }
 
-         ActiveMQServerLogger.LOGGER.startedAcceptor(acceptorType, host, port, protocolsString);
+         ActiveMQServerLogger.LOGGER.startedAcceptor(acceptorType, host, actualPort, protocolsString);
       }
 
       if (batchDelay > 0) {
@@ -561,12 +568,14 @@ public class NettyAcceptor extends AbstractAcceptor {
    }
 
    // only for testing purposes
-   public void setKeyStorePath(String keyStorePath) {
+   public void setKeyStoreParameters(String keyStorePath, String keyStoreAlias) {
       this.keyStorePath = keyStorePath;
       this.configuration.put(TransportConstants.KEYSTORE_PATH_PROP_NAME, keyStorePath);
+      this.configuration.put(TransportConstants.KEYSTORE_ALIAS_PROP_NAME, keyStoreAlias);
       sslContextConfig = SSLContextConfig.builder()
          .from(sslContextConfig)
          .keystorePath(keyStorePath)
+         .keystoreAlias(keyStoreAlias)
          .build();
    }
 
@@ -688,7 +697,7 @@ public class NettyAcceptor extends AbstractAcceptor {
       if (configuration.containsKey(TransportConstants.SSL_CONTEXT_PROP_NAME)) {
          return;
       }
-      if (keyStorePath == null && TransportConstants.DEFAULT_KEYSTORE_PROVIDER.equals(keyStoreProvider)) {
+      if (keyStorePath == null && keyStoreProvider == null) {
          throw new IllegalArgumentException("If \"" + TransportConstants.SSL_ENABLED_PROP_NAME + "\" is true then \"" + TransportConstants.KEYSTORE_PATH_PROP_NAME + "\" must be non-null unless an alternative \"" + TransportConstants.KEYSTORE_PROVIDER_PROP_NAME + "\" has been specified.");
       }
    }
@@ -715,6 +724,13 @@ public class NettyAcceptor extends AbstractAcceptor {
          Channel serverChannel = null;
          try {
             serverChannel = bootstrap.bind(address).syncUninterruptibly().channel();
+
+            // The port may be configured as `0` which means the JVM will select an ephemeral port
+            if (serverChannel.localAddress() instanceof InetSocketAddress) {
+               actualPort = ((InetSocketAddress)serverChannel.localAddress()).getPort();
+            } else {
+               actualPort = port;
+            }
          } catch (Exception e) {
             throw ActiveMQMessageBundle.BUNDLE.failedToBind(getName(), h + ":" + port, e);
          }
@@ -778,16 +794,16 @@ public class NettyAcceptor extends AbstractAcceptor {
       channelClazz = null;
 
       for (Connection connection : connections.values()) {
-         listener.connectionDestroyed(connection.getID());
+         listener.connectionDestroyed(connection.getID(), true);
       }
 
       connections.clear();
 
       if (notificationService != null) {
          TypedProperties props = new TypedProperties();
-         props.putSimpleStringProperty(new SimpleString("factory"), new SimpleString(NettyAcceptorFactory.class.getName()));
-         props.putSimpleStringProperty(new SimpleString("host"), new SimpleString(host));
-         props.putIntProperty(new SimpleString("port"), port);
+         props.putSimpleStringProperty(SimpleString.of("factory"), SimpleString.of(NettyAcceptorFactory.class.getName()));
+         props.putSimpleStringProperty(SimpleString.of("host"), SimpleString.of(host));
+         props.putIntProperty(SimpleString.of("port"), port);
          Notification notification = new Notification(null, CoreNotificationType.ACCEPTOR_STOPPED, props);
          try {
             notificationService.sendNotification(notification);
@@ -911,7 +927,7 @@ public class NettyAcceptor extends AbstractAcceptor {
             super.channelActive(ctx);
             Listener connectionListener = new Listener();
 
-            NettyServerConnection nc = new NettyServerConnection(configuration, ctx.channel(), connectionListener, !httpEnabled && batchDelay > 0, directDeliver, redirectTo);
+            NettyServerConnection nc = new NettyServerConnection(configuration, ctx.channel(), connectionListener, !httpEnabled && batchDelay > 0, directDeliver, router);
 
             connectionListener.connectionCreated(NettyAcceptor.this, nc, protocolHandler.getProtocol(protocol));
 
@@ -953,9 +969,9 @@ public class NettyAcceptor extends AbstractAcceptor {
       }
 
       @Override
-      public void connectionDestroyed(final Object connectionID) {
+      public void connectionDestroyed(final Object connectionID, boolean failed) {
          if (connections.remove(connectionID) != null) {
-            listener.connectionDestroyed(connectionID);
+            listener.connectionDestroyed(connectionID, failed);
          }
       }
 
@@ -1020,28 +1036,22 @@ public class NettyAcceptor extends AbstractAcceptor {
       @Override
       public void exceptionCaught(ChannelHandlerContext ctx, Throwable cause) throws Exception {
          if (cause.getMessage() != null && cause.getMessage().startsWith(SSLHandshakeException.class.getName())) {
-            Throwable rootCause = getRootCause(cause);
+            Throwable rootCause = ExceptionUtils.getRootCause(cause);
             String errorMessage = rootCause.getClass().getName() + ": " + rootCause.getMessage();
 
             ActiveMQServerLogger.LOGGER.sslHandshakeFailed(ctx.channel().remoteAddress().toString(), errorMessage);
 
-            if (ActiveMQServerLogger.LOGGER.isDebugEnabled()) {
-               ActiveMQServerLogger.LOGGER.debug("SSL handshake failed", cause);
-            }
+            logger.debug("SSL handshake failed", cause);
          }
       }
    }
 
-   private Throwable getRootCause(Throwable throwable) {
-      List<Throwable> list = new ArrayList<>();
-      while (throwable != null && list.contains(throwable) == false) {
-         list.add(throwable);
-         throwable = throwable.getCause();
-      }
-      return (list.size() < 2 ? throwable : list.get(list.size() - 1));
-   }
-
    public boolean isAutoStart() {
       return autoStart;
    }
+
+   @Override
+   public int getActualPort() {
+      return actualPort;
+   }
 }
