@@ -21,39 +21,43 @@ import java.io.FileOutputStream;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.nio.channels.FileChannel;
+import java.util.ArrayDeque;
+import java.util.ArrayList;
 import java.util.EnumSet;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
-import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.concurrent.Executor;
-import java.util.concurrent.TimeUnit;
 
 import org.apache.activemq.artemis.api.core.ActiveMQException;
+import org.apache.activemq.artemis.api.core.Interceptor;
 import org.apache.activemq.artemis.api.core.Message;
 import org.apache.activemq.artemis.api.core.SimpleString;
 import org.apache.activemq.artemis.core.config.Configuration;
-import org.apache.activemq.artemis.core.io.IOCriticalErrorListener;
 import org.apache.activemq.artemis.core.io.SequentialFile;
+import org.apache.activemq.artemis.core.journal.EncoderPersister;
 import org.apache.activemq.artemis.core.journal.Journal;
 import org.apache.activemq.artemis.core.journal.Journal.JournalState;
 import org.apache.activemq.artemis.core.journal.JournalLoadInformation;
 import org.apache.activemq.artemis.core.journal.impl.FileWrapperJournal;
 import org.apache.activemq.artemis.core.journal.impl.JournalFile;
+import org.apache.activemq.artemis.core.journal.impl.dataformat.ByteArrayEncoding;
 import org.apache.activemq.artemis.core.paging.PagedMessage;
 import org.apache.activemq.artemis.core.paging.PagingManager;
 import org.apache.activemq.artemis.core.paging.impl.Page;
-import org.apache.activemq.artemis.core.paging.impl.PagingManagerImpl;
-import org.apache.activemq.artemis.core.paging.impl.PagingStoreFactoryNIO;
 import org.apache.activemq.artemis.core.persistence.StorageManager;
 import org.apache.activemq.artemis.core.persistence.impl.journal.AbstractJournalStorageManager.JournalContent;
 import org.apache.activemq.artemis.core.persistence.impl.journal.LargeServerMessageInSync;
 import org.apache.activemq.artemis.core.protocol.core.Channel;
 import org.apache.activemq.artemis.core.protocol.core.ChannelHandler;
+import org.apache.activemq.artemis.core.protocol.core.CoreRemotingConnection;
 import org.apache.activemq.artemis.core.protocol.core.Packet;
 import org.apache.activemq.artemis.core.protocol.core.impl.PacketImpl;
+import org.apache.activemq.artemis.core.protocol.core.impl.RemotingConnectionImpl;
 import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ActiveMQExceptionMessage;
 import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.BackupReplicationStartFailedMessage;
 import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ReplicationAddMessage;
@@ -64,7 +68,7 @@ import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.Replicatio
 import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ReplicationLargeMessageBeginMessage;
 import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ReplicationLargeMessageEndMessage;
 import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ReplicationLargeMessageWriteMessage;
-import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ReplicationLiveIsStoppingMessage;
+import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ReplicationPrimaryIsStoppingMessage;
 import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ReplicationPageEventMessage;
 import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ReplicationPageWriteMessage;
 import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ReplicationPrepareMessage;
@@ -73,15 +77,17 @@ import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.Replicatio
 import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ReplicationStartSyncMessage;
 import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ReplicationStartSyncMessage.SyncDataType;
 import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ReplicationSyncFileMessage;
+import org.apache.activemq.artemis.core.remoting.impl.netty.NettyConnection;
 import org.apache.activemq.artemis.core.replication.ReplicationManager.ADD_OPERATION_TYPE;
 import org.apache.activemq.artemis.core.server.ActiveMQComponent;
 import org.apache.activemq.artemis.core.server.ActiveMQMessageBundle;
 import org.apache.activemq.artemis.core.server.ActiveMQServerLogger;
 
-import org.apache.activemq.artemis.core.server.cluster.qourum.SharedNothingBackupQuorum;
 import org.apache.activemq.artemis.core.server.impl.ActiveMQServerImpl;
-import org.apache.activemq.artemis.core.server.impl.SharedNothingBackupActivation;
-import org.jboss.logging.Logger;
+import org.apache.activemq.artemis.utils.actors.OrderedExecutorFactory;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import java.lang.invoke.MethodHandles;
 
 /**
  * Handles all the synchronization necessary for replication on the backup side (that is the
@@ -89,14 +95,23 @@ import org.jboss.logging.Logger;
  */
 public final class ReplicationEndpoint implements ChannelHandler, ActiveMQComponent {
 
-   private static final Logger logger = Logger.getLogger(ReplicationEndpoint.class);
+   public interface ReplicationEndpointEventListener {
+
+      void onRemoteBackupUpToDate(String nodeId, long activationSequence);
+
+      void onPrimaryStopping(ReplicationPrimaryIsStoppingMessage.PrimaryStopping message) throws ActiveMQException;
+
+      void onPrimaryNodeId(String nodeId);
+   }
+
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
-   private final IOCriticalErrorListener criticalErrorListener;
    private final ActiveMQServerImpl server;
    private final boolean wantedFailBack;
-   private final SharedNothingBackupActivation activation;
+   private final ReplicationEndpointEventListener eventListener;
    private final boolean noSync = false;
    private Channel channel;
+   private boolean supportResponseBatching;
 
    private Journal[] journals;
    private final JournalLoadInformation[] journalLoadInformation = new JournalLoadInformation[2];
@@ -116,29 +131,32 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
 
    private PagingManager pageManager;
 
-   private final ConcurrentMap<SimpleString, ConcurrentMap<Integer, Page>> pageIndex = new ConcurrentHashMap<>();
+   private final ConcurrentMap<SimpleString, ConcurrentMap<Long, Page>> pageIndex = new ConcurrentHashMap<>();
    private final ConcurrentMap<Long, ReplicatedLargeMessage> largeMessages = new ConcurrentHashMap<>();
 
    // Used on tests, to simulate failures on delete pages
    private boolean deletePages = true;
    private volatile boolean started;
 
-   private SharedNothingBackupQuorum backupQuorum;
-
    private Executor executor;
 
-   // Constructors --------------------------------------------------
+   private List<Interceptor> outgoingInterceptors = null;
+
+   private final ArrayDeque<Packet> pendingPackets;
+
+   private boolean synchronizing = true;
+
+
    public ReplicationEndpoint(final ActiveMQServerImpl server,
-                              IOCriticalErrorListener criticalErrorListener,
                               boolean wantedFailBack,
-                              SharedNothingBackupActivation activation) {
+                              ReplicationEndpointEventListener eventListener) {
       this.server = server;
-      this.criticalErrorListener = criticalErrorListener;
       this.wantedFailBack = wantedFailBack;
-      this.activation = activation;
+      this.eventListener = eventListener;
+      this.pendingPackets = new ArrayDeque<>();
+      this.supportResponseBatching = false;
    }
 
-   // Public --------------------------------------------------------
 
    public synchronized void registerJournal(final byte id, final Journal journal) {
       if (journals == null || id >= journals.length) {
@@ -153,19 +171,37 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
       journals[id] = journal;
    }
 
+   public void addOutgoingInterceptorForReplication(Interceptor interceptor) {
+      if (outgoingInterceptors == null) {
+         outgoingInterceptors = new CopyOnWriteArrayList<>();
+      }
+      outgoingInterceptors.add(interceptor);
+   }
+
+   /**
+    * This is for tests basically, do not use it as its API is not guaranteed for future usage.
+    */
+   public void pause() {
+      started = false;
+   }
+
+   /**
+    * This is for tests basically, do not use it as its API is not guaranteed for future usage.
+    */
+   public void resume() {
+      started = true;
+   }
+
    @Override
    public void handlePacket(final Packet packet) {
-      if (logger.isTraceEnabled()) {
-         logger.trace("handlePacket::handling " + packet);
-      }
+      logger.trace("handlePacket::handling {}", packet);
+
       PacketImpl response = new ReplicationResponseMessage();
       final byte type = packet.getType();
 
       try {
          if (!started) {
-            if (logger.isTraceEnabled()) {
-               logger.trace("handlePacket::ignoring " + packet);
-            }
+            logger.trace("handlePacket::ignoring {}", packet);
 
             return;
          }
@@ -197,20 +233,46 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
          } else if (type == PacketImpl.REPLICATION_SYNC_FILE) {
             handleReplicationSynchronization((ReplicationSyncFileMessage) packet);
          } else if (type == PacketImpl.REPLICATION_SCHEDULED_FAILOVER) {
-            handleLiveStopping((ReplicationLiveIsStoppingMessage) packet);
+            handlePrimaryStopping((ReplicationPrimaryIsStoppingMessage) packet);
          } else if (type == PacketImpl.BACKUP_REGISTRATION_FAILED) {
             handleFatalError((BackupReplicationStartFailedMessage) packet);
          } else {
             ActiveMQServerLogger.LOGGER.invalidPacketForReplication(packet);
          }
       } catch (ActiveMQException e) {
-         ActiveMQServerLogger.LOGGER.errorHandlingReplicationPacket(e, packet);
+         logger.warn(e.getMessage(), e);
+         ActiveMQServerLogger.LOGGER.errorHandlingReplicationPacket(packet, e);
          response = new ActiveMQExceptionMessage(e);
       } catch (Exception e) {
-         ActiveMQServerLogger.LOGGER.errorHandlingReplicationPacket(e, packet);
+         logger.warn(e.getMessage(), e);
+         ActiveMQServerLogger.LOGGER.errorHandlingReplicationPacket(packet, e);
          response = new ActiveMQExceptionMessage(ActiveMQMessageBundle.BUNDLE.replicationUnhandledError(e));
       }
-      channel.send(response);
+
+      if (response != null) {
+         logger.trace("Returning {}", response);
+
+         if (supportResponseBatching) {
+            pendingPackets.add(response);
+         } else {
+            channel.send(response);
+         }
+      } else {
+         logger.trace("Response is null, ignoring response");
+      }
+   }
+
+   @Override
+   public void endOfBatch() {
+      final ArrayDeque<Packet> pendingPackets = this.pendingPackets;
+      if (pendingPackets.isEmpty()) {
+         return;
+      }
+      for (int i = 0, size = pendingPackets.size(); i < size; i++) {
+         final Packet packet = pendingPackets.poll();
+         final boolean isLast = i == (size - 1);
+         channel.send(packet, isLast);
+      }
    }
 
    /**
@@ -225,8 +287,8 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
     * @param packet
     * @throws ActiveMQException
     */
-   private void handleLiveStopping(ReplicationLiveIsStoppingMessage packet) throws ActiveMQException {
-      activation.remoteFailOver(packet.isFinalMessage());
+   private void handlePrimaryStopping(ReplicationPrimaryIsStoppingMessage packet) throws ActiveMQException {
+      eventListener.onPrimaryStopping(packet.isFinalMessage());
    }
 
    @Override
@@ -252,7 +314,8 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
             journalLoadInformation[jc.typeByte] = journalsHolder.get(jc).loadSyncOnly(JournalState.SYNCING);
          }
 
-         pageManager = new PagingManagerImpl(new PagingStoreFactoryNIO(storageManager, config.getPagingLocation(), config.getJournalBufferSize_NIO(), server.getScheduledPool(), server.getExecutorFactory(), config.isJournalSyncNonTransactional(), criticalErrorListener), server.getAddressSettingsRepository());
+
+         pageManager = server.createPagingManager();
 
          pageManager.start();
 
@@ -269,13 +332,19 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
          return;
       }
 
-      // Channel may be null if there isn't a connection to a live server
+      logger.trace("Stopping endpoint");
+
+      started = false;
+
+      OrderedExecutorFactory.flushExecutor(executor);
+
+      // Channel may be null if there isn't a connection to a primary server
       if (channel != null) {
          channel.close();
       }
 
       for (ReplicatedLargeMessage largeMessage : largeMessages.values()) {
-         largeMessage.releaseResources();
+         largeMessage.releaseResources(true, false);
       }
       largeMessages.clear();
 
@@ -293,10 +362,9 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
          }
       }
 
-      for (ConcurrentMap<Integer, Page> map : pageIndex.values()) {
+      for (ConcurrentMap<Long, Page> map : pageIndex.values()) {
          for (Page page : map.values()) {
             try {
-               page.sync();
                page.close(false);
             } catch (Exception e) {
                ActiveMQServerLogger.LOGGER.errorClosingPageOnReplication(e);
@@ -306,15 +374,6 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
       pageManager.stop();
 
       pageIndex.clear();
-      final CountDownLatch latch = new CountDownLatch(1);
-      executor.execute(new Runnable() {
-
-         @Override
-         public void run() {
-            latch.countDown();
-         }
-      });
-      latch.await(30, TimeUnit.SECONDS);
 
       // Storage needs to be the last to stop
       storageManager.stop();
@@ -328,50 +387,119 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
 
    public void setChannel(final Channel channel) {
       this.channel = channel;
+      if (channel == null) {
+         supportResponseBatching = false;
+      } else {
+         try {
+            final CoreRemotingConnection connection = channel.getConnection();
+            if (connection != null) {
+               this.supportResponseBatching = connection.getTransportConnection() instanceof NettyConnection;
+            } else {
+               this.supportResponseBatching = false;
+            }
+         } catch (Throwable t) {
+            logger.warn("Error while checking the channel connection", t);
+            this.supportResponseBatching = false;
+         }
+      }
+
+      if (channel != null && outgoingInterceptors != null) {
+         if (channel.getConnection() instanceof RemotingConnectionImpl)  {
+            try {
+               RemotingConnectionImpl impl = (RemotingConnectionImpl) channel.getConnection();
+               for (Interceptor interceptor : outgoingInterceptors) {
+                  impl.getOutgoingInterceptors().add(interceptor);
+               }
+            } catch (Throwable e) {
+               // This is code for embedded or testing, it should not affect server's semantics in case of error
+               logger.warn(e.getMessage(), e);
+            }
+         }
+      }
    }
 
-   private void finishSynchronization(String liveID) throws Exception {
+   private synchronized void finishSynchronization(String primaryID, long activationSequence) throws Exception {
       if (logger.isTraceEnabled()) {
-         logger.trace("finishSynchronization::" + liveID);
+         logger.trace("BACKUP-SYNC-START: finishSynchronization::{} activationSequence = {}", primaryID, activationSequence);
       }
+
+      synchronizing = false;
+
       for (JournalContent jc : EnumSet.allOf(JournalContent.class)) {
          Journal journal = journalsHolder.remove(jc);
+         logger.trace("getting lock on {}, journal = {}", jc, journal);
+
+         registerJournal(jc.typeByte, journal);
          journal.synchronizationLock();
          try {
+            logger.trace("lock acquired on {}", jc);
+
             // files should be already in place.
             filesReservedForSync.remove(jc);
-            registerJournal(jc.typeByte, journal);
+
+            logger.trace("stopping journal for {}", jc);
+
             journal.stop();
+
+            logger.trace("starting journal for {}", jc);
+
             journal.start();
+
+            logger.trace("loadAndSync {}", jc);
+
             journal.loadSyncOnly(JournalState.SYNCING_UP_TO_DATE);
          } finally {
+            logger.trace("unlocking {}", jc);
+
             journal.synchronizationUnlock();
          }
       }
+
+      logger.trace("Sync on large messages...");
+
+      ArrayList<Long> lmToRemove = null;
+
       ByteBuffer buffer = ByteBuffer.allocate(4 * 1024);
       for (Entry<Long, ReplicatedLargeMessage> entry : largeMessages.entrySet()) {
          ReplicatedLargeMessage lm = entry.getValue();
          if (lm instanceof LargeServerMessageInSync) {
             LargeServerMessageInSync lmSync = (LargeServerMessageInSync) lm;
+            logger.trace("lmSync on {}", lmSync);
+
             lmSync.joinSyncedData(buffer);
+
+            if (!lmSync.getSyncFile().isOpen()) {
+               if (lmToRemove == null) {
+                  lmToRemove = new ArrayList<>();
+               }
+               lmToRemove.add(lm.getMessage().getMessageID());
+            }
          }
       }
 
+      if (lmToRemove != null) {
+         lmToRemove.forEach(largeMessages::remove);
+      }
+
+      logger.trace("setRemoteBackupUpToDate and primaryIDSet for {}", primaryID);
+
       journalsHolder = null;
-      backupQuorum.liveIDSet(liveID);
-      activation.setRemoteBackupUpToDate();
-      ActiveMQServerLogger.LOGGER.backupServerSynched(server);
+      eventListener.onRemoteBackupUpToDate(primaryID, activationSequence);
+
+      logger.trace("Backup is synchronized / BACKUP-SYNC-DONE");
+
+      ActiveMQServerLogger.LOGGER.backupServerSynchronized(server, primaryID);
       return;
    }
 
    /**
-    * Receives 'raw' journal/page/large-message data from live server for synchronization of logs.
+    * Receives 'raw' journal/page/large-message data from primary server for synchronization of logs.
     *
     * @param msg
     * @throws Exception
     */
    private void handleReplicationSynchronization(ReplicationSyncFileMessage msg) throws Exception {
-      Long id = Long.valueOf(msg.getId());
+      long id = msg.getId();
       byte[] data = msg.getData();
       SequentialFile channel1;
       switch (msg.getFileType()) {
@@ -405,13 +533,17 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
       }
 
       if (data == null) {
+         // this means close file
+         if (channel1.isOpen()) {
+            channel1.close();
+         }
          return;
       }
 
       if (!channel1.isOpen()) {
          channel1.open();
       }
-      channel1.writeDirect(ByteBuffer.wrap(data), true);
+      channel1.writeDirect(ByteBuffer.wrap(data), false);
    }
 
    /**
@@ -424,20 +556,26 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
     * @throws Exception
     */
    private ReplicationResponseMessageV2 handleStartReplicationSynchronization(final ReplicationStartSyncMessage packet) throws Exception {
+      logger.trace("handleStartReplicationSynchronization:: nodeID = {}", packet);
 
-      if (logger.isTraceEnabled()) {
-         logger.trace("handleStartReplicationSynchronization:: nodeID = " + packet);
-      }
       ReplicationResponseMessageV2 replicationResponseMessage = new ReplicationResponseMessageV2();
       if (!started)
          return replicationResponseMessage;
 
       if (packet.isSynchronizationFinished()) {
-         finishSynchronization(packet.getNodeID());
+         long activationSequence = 0;
+         if (packet.getFileIds() != null && packet.getFileIds().length == 1) {
+            // this is the version sequence of the data we are replicating
+            // verified if we activate with this data
+            activationSequence = packet.getFileIds()[0];
+         }
+         finishSynchronization(packet.getNodeID(), activationSequence);
          replicationResponseMessage.setSynchronizationIsFinishedAcknowledgement(true);
          return replicationResponseMessage;
       }
 
+      synchronizing = true;
+
       switch (packet.getDataType()) {
          case LargeMessages:
             for (long msgID : packet.getFileIds()) {
@@ -453,11 +591,6 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
             final JournalContent journalContent = SyncDataType.getJournalContentType(packet.getDataType());
             final Journal journal = journalsHolder.get(journalContent);
 
-            if (packet.getNodeID() != null) {
-               // At the start of replication, we still do not know which is the nodeID that the live uses.
-               // This is the point where the backup gets this information.
-               backupQuorum.liveIDSet(packet.getNodeID());
-            }
             Map<Long, JournalSyncFile> mapToFill = filesReservedForSync.get(journalContent);
 
             for (Entry<Long, JournalFile> entry : journal.createFilesForBackupSync(packet.getFileIds()).entrySet()) {
@@ -465,6 +598,24 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
             }
             FileWrapperJournal syncJournal = new FileWrapperJournal(journal);
             registerJournal(journalContent.typeByte, syncJournal);
+
+            /* We send a response now to avoid a situation where we handle votes during the deactivation of the primary
+             * during a failback.
+             */
+            if (supportResponseBatching) {
+               endOfBatch();
+            }
+            channel.send(replicationResponseMessage);
+            replicationResponseMessage = null;
+
+            // This needs to be done after the response is sent to avoid voting shutting it down for any reason.
+            if (packet.getNodeID() != null) {
+               /* At the start of replication we still do not know which is the nodeID that the primary uses.
+                * This is the point where the backup gets this information.
+                */
+               eventListener.onPrimaryNodeId(packet.getNodeID());
+            }
+
             break;
          default:
             throw ActiveMQMessageBundle.BUNDLE.replicationUnhandledDataType();
@@ -475,23 +626,30 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
 
    private void handleLargeMessageEnd(final ReplicationLargeMessageEndMessage packet) {
       if (logger.isTraceEnabled()) {
-         logger.trace("handleLargeMessageEnd on " + packet.getMessageId());
+         logger.trace("handleLargeMessageEnd on {}", packet.getMessageId());
       }
       final ReplicatedLargeMessage message = lookupLargeMessage(packet.getMessageId(), true, false);
       if (message != null) {
-         executor.execute(new Runnable() {
-            @Override
-            public void run() {
-               try {
-                  if (logger.isTraceEnabled()) {
-                     logger.trace("Deleting LargeMessage " + packet.getMessageId() + " on the executor @ handleLargeMessageEnd");
-                  }
-                  message.deleteFile();
-               } catch (Exception e) {
-                  ActiveMQServerLogger.LOGGER.errorDeletingLargeMessage(e, packet.getMessageId());
-               }
+         if (!packet.isDelete()) {
+            if (logger.isTraceEnabled()) {
+               logger.trace("Closing LargeMessage {} on the executor @ handleLargeMessageEnd", packet.getMessageId());
             }
-         });
+            message.releaseResources(true, false);
+         } else {
+            executor.execute(new Runnable() {
+               @Override
+               public void run() {
+                  try {
+                     if (logger.isTraceEnabled()) {
+                        logger.trace("Deleting LargeMessage {} on the executor @ handleLargeMessageEnd", packet.getMessageId());
+                     }
+                     message.deleteFile();
+                  } catch (Exception e) {
+                     ActiveMQServerLogger.LOGGER.errorDeletingLargeMessage(packet.getMessageId(), e);
+                  }
+               }
+            });
+         }
       }
    }
 
@@ -506,12 +664,20 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
    }
 
    private ReplicatedLargeMessage lookupLargeMessage(final long messageId,
-                                                     final boolean delete,
+                                                     final boolean remove,
                                                      final boolean createIfNotExists) {
       ReplicatedLargeMessage message;
 
-      if (delete) {
+      if (remove) {
          message = largeMessages.remove(messageId);
+         if (message == null) {
+            return newLargeMessage(messageId, false);
+         } else {
+            if (synchronizing && message instanceof LargeServerMessageInSync) {
+               // putting it back as it is still synchronizing
+               largeMessages.put(messageId, message);
+            }
+         }
       } else {
          message = largeMessages.get(messageId);
          if (message == null) {
@@ -519,8 +685,7 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
                createLargeMessage(messageId, false);
                message = largeMessages.get(messageId);
             } else {
-               // No warnings if it's a delete, as duplicate deletes may be sent repeatedly.
-               ActiveMQServerLogger.LOGGER.largeMessageNotAvailable(messageId);
+               return newLargeMessage(messageId, false);
             }
          }
       }
@@ -536,21 +701,26 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
       final long id = packet.getMessageId();
       createLargeMessage(id, false);
       if (logger.isTraceEnabled()) {
-         logger.trace("Receiving Large Message Begin " + id + " on backup");
+         logger.trace("Receiving Large Message Begin {} on backup", id);
       }
    }
 
    private void createLargeMessage(final long id, boolean liveToBackupSync) {
+      ReplicatedLargeMessage msg = newLargeMessage(id, liveToBackupSync);
+      largeMessages.put(id, msg);
+   }
+
+   private ReplicatedLargeMessage newLargeMessage(long id, boolean liveToBackupSync) {
       ReplicatedLargeMessage msg;
       if (liveToBackupSync) {
          msg = new LargeServerMessageInSync(storageManager);
       } else {
-         msg = storageManager.createLargeMessage();
+         msg = storageManager.createCoreLargeMessage();
       }
 
       msg.setDurable(true);
       msg.setMessageID(id);
-      largeMessages.put(id, msg);
+      return msg;
    }
 
    /**
@@ -587,7 +757,7 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
     */
    private void handleAppendDelete(final ReplicationDeleteMessage packet) throws Exception {
       Journal journalToUse = getJournal(packet.getJournalID());
-      journalToUse.appendDeleteRecord(packet.getId(), noSync);
+      journalToUse.tryAppendDeleteRecord(packet.getId(), null, noSync);
    }
 
    /**
@@ -609,16 +779,25 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
     */
    private void handleAppendAddRecord(final ReplicationAddMessage packet) throws Exception {
       Journal journalToUse = getJournal(packet.getJournalID());
-      if (packet.getRecord() == ADD_OPERATION_TYPE.UPDATE) {
-         if (logger.isTraceEnabled()) {
-            logger.trace("Endpoint appendUpdate id = " + packet.getId());
-         }
-         journalToUse.appendUpdateRecord(packet.getId(), packet.getJournalRecordType(), packet.getRecordData(), noSync);
-      } else {
-         if (logger.isTraceEnabled()) {
-            logger.trace("Endpoint append id = " + packet.getId());
-         }
-         journalToUse.appendAddRecord(packet.getId(), packet.getJournalRecordType(), packet.getRecordData(), noSync);
+      switch (packet.getRecord()) {
+         case UPDATE:
+            if (logger.isTraceEnabled()) {
+               logger.trace("Endpoint appendUpdate id = {}", packet.getId());
+            }
+            journalToUse.appendUpdateRecord(packet.getId(), packet.getJournalRecordType(), packet.getRecordData(), noSync);
+            break;
+         case ADD:
+            if (logger.isTraceEnabled()) {
+               logger.trace("Endpoint append id = {}", packet.getId());
+            }
+            journalToUse.appendAddRecord(packet.getId(), packet.getJournalRecordType(), packet.getRecordData(), noSync);
+            break;
+         case EVENT:
+            if (logger.isTraceEnabled()) {
+               logger.trace("Endpoint append id = {}", packet.getId());
+            }
+            journalToUse.appendAddEvent(packet.getId(), packet.getJournalRecordType(), EncoderPersister.getInstance(), new ByteArrayEncoding(packet.getRecordData()), noSync, null);
+            break;
       }
    }
 
@@ -626,12 +805,17 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
     * @param packet
     */
    private void handlePageEvent(final ReplicationPageEventMessage packet) throws Exception {
-      ConcurrentMap<Integer, Page> pages = getPageMap(packet.getStoreName());
+      ConcurrentMap<Long, Page> pages = getPageMap(packet.getStoreName());
 
       Page page = pages.remove(packet.getPageNumber());
 
       if (page == null) {
-         page = getPage(packet.getStoreName(), packet.getPageNumber());
+         // if page is null, we create it the instance and include it on the map
+         // then we must recurse this call
+         // so page.delete or page.close will not leave any closed objects on the hashmap
+         getPage(packet.getStoreName(), packet.getPageNumber());
+         handlePageEvent(packet);
+         return;
       }
 
       if (page != null) {
@@ -654,15 +838,15 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
       pgdMessage.initMessage(storageManager);
       Message msg = pgdMessage.getMessage();
       Page page = getPage(msg.getAddressSimpleString(), packet.getPageNumber());
-      page.write(pgdMessage);
+      page.writeDirect(pgdMessage);
    }
 
-   private ConcurrentMap<Integer, Page> getPageMap(final SimpleString storeName) {
-      ConcurrentMap<Integer, Page> resultIndex = pageIndex.get(storeName);
+   private ConcurrentMap<Long, Page> getPageMap(final SimpleString storeName) {
+      ConcurrentMap<Long, Page> resultIndex = pageIndex.get(storeName);
 
       if (resultIndex == null) {
          resultIndex = new ConcurrentHashMap<>();
-         ConcurrentMap<Integer, Page> mapResult = pageIndex.putIfAbsent(storeName, resultIndex);
+         ConcurrentMap<Long, Page> mapResult = pageIndex.putIfAbsent(storeName, resultIndex);
          if (mapResult != null) {
             resultIndex = mapResult;
          }
@@ -671,8 +855,8 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
       return resultIndex;
    }
 
-   private Page getPage(final SimpleString storeName, final int pageId) throws Exception {
-      ConcurrentMap<Integer, Page> map = getPageMap(storeName);
+   private Page getPage(final SimpleString storeName, final long pageId) throws Exception {
+      ConcurrentMap<Long, Page> map = getPageMap(storeName);
 
       Page page = map.get(pageId);
 
@@ -688,14 +872,14 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
     * @param map
     * @return
     */
-   private synchronized Page newPage(final int pageId,
+   private synchronized Page newPage(final long pageId,
                                      final SimpleString storeName,
-                                     final ConcurrentMap<Integer, Page> map) throws Exception {
+                                     final ConcurrentMap<Long, Page> map) throws Exception {
       Page page = map.get(pageId);
 
       if (page == null) {
-         page = pageManager.getPageStore(storeName).createPage(pageId);
-         page.open();
+         page = pageManager.getPageStore(storeName).newPageObject(pageId);
+         page.open(true);
          map.put(pageId, page);
       }
 
@@ -743,20 +927,21 @@ public final class ReplicationEndpoint implements ChannelHandler, ActiveMQCompon
       }
    }
 
-   /**
-    * Sets the quorumManager used by the server in the replicationEndpoint. It is used to inform the
-    * backup server of the live's nodeID.
-    *
-    * @param backupQuorum
-    */
-   public void setBackupQuorum(SharedNothingBackupQuorum backupQuorum) {
-      this.backupQuorum = backupQuorum;
-   }
-
    /**
     * @param executor2
     */
    public void setExecutor(Executor executor2) {
       this.executor = executor2;
    }
+
+   public ConcurrentMap<SimpleString, ConcurrentMap<Long, Page>> getPageIndex() {
+      return pageIndex;
+   }
+
+   /**
+    * This is for tests basically, do not use it as its API is not guaranteed for future usage.
+    */
+   public ConcurrentMap<Long, ReplicatedLargeMessage> getLargeMessages() {
+      return largeMessages;
+   }
 }
