@@ -16,6 +16,11 @@
  */
 package org.apache.activemq.artemis.core.list;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Objects;
@@ -25,11 +30,10 @@ import org.apache.activemq.artemis.utils.collections.NodeStore;
 import org.apache.activemq.artemis.utils.collections.LinkedListImpl;
 import org.apache.activemq.artemis.utils.collections.LinkedListIterator;
 import org.apache.activemq.artemis.utils.collections.PriorityLinkedListImpl;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
-public final class PriorityLinkedListTest extends Assert {
+public final class PriorityLinkedListTest {
 
    protected Wibble a;
 
@@ -89,7 +93,7 @@ public final class PriorityLinkedListTest extends Assert {
       return new PriorityLinkedListImpl<>(10);
    }
 
-   @Before
+   @BeforeEach
    public void setUp() throws Exception {
 
       list = getList();
@@ -124,15 +128,15 @@ public final class PriorityLinkedListTest extends Assert {
 
    @Test
    public void testEmpty() throws Exception {
-      Assert.assertTrue(list.isEmpty());
+      assertTrue(list.isEmpty());
 
       list.addHead(a, 0);
 
-      Assert.assertFalse(list.isEmpty());
+      assertFalse(list.isEmpty());
 
       Wibble w1 = list.poll();
-      Assert.assertEquals(a, w1);
-      Assert.assertTrue(list.isEmpty());
+      assertEquals(a, w1);
+      assertTrue(list.isEmpty());
 
       assertEquals(0, list.size());
    }
@@ -147,12 +151,12 @@ public final class PriorityLinkedListTest extends Assert {
 
       assertEquals(5, list.size());
 
-      Assert.assertEquals(e, list.poll());
-      Assert.assertEquals(d, list.poll());
-      Assert.assertEquals(c, list.poll());
-      Assert.assertEquals(b, list.poll());
-      Assert.assertEquals(a, list.poll());
-      Assert.assertNull(list.poll());
+      assertEquals(e, list.poll());
+      assertEquals(d, list.poll());
+      assertEquals(c, list.poll());
+      assertEquals(b, list.poll());
+      assertEquals(a, list.poll());
+      assertNull(list.poll());
 
       assertEquals(0, list.size());
    }
@@ -166,12 +170,12 @@ public final class PriorityLinkedListTest extends Assert {
       list.addTail(e, 0);
       assertEquals(5, list.size());
 
-      Assert.assertEquals(a, list.poll());
-      Assert.assertEquals(b, list.poll());
-      Assert.assertEquals(c, list.poll());
-      Assert.assertEquals(d, list.poll());
-      Assert.assertEquals(e, list.poll());
-      Assert.assertNull(list.poll());
+      assertEquals(a, list.poll());
+      assertEquals(b, list.poll());
+      assertEquals(c, list.poll());
+      assertEquals(d, list.poll());
+      assertEquals(e, list.poll());
+      assertNull(list.poll());
 
       assertEquals(0, list.size());
 
@@ -306,18 +310,18 @@ public final class PriorityLinkedListTest extends Assert {
       list.addTail(i, 8);
       list.addTail(j, 9);
 
-      Assert.assertEquals(j, list.poll());
-      Assert.assertEquals(i, list.poll());
-      Assert.assertEquals(h, list.poll());
-      Assert.assertEquals(g, list.poll());
-      Assert.assertEquals(f, list.poll());
-      Assert.assertEquals(e, list.poll());
-      Assert.assertEquals(d, list.poll());
-      Assert.assertEquals(c, list.poll());
-      Assert.assertEquals(b, list.poll());
-      Assert.assertEquals(a, list.poll());
+      assertEquals(j, list.poll());
+      assertEquals(i, list.poll());
+      assertEquals(h, list.poll());
+      assertEquals(g, list.poll());
+      assertEquals(f, list.poll());
+      assertEquals(e, list.poll());
+      assertEquals(d, list.poll());
+      assertEquals(c, list.poll());
+      assertEquals(b, list.poll());
+      assertEquals(a, list.poll());
 
-      Assert.assertNull(list.poll());
+      assertNull(list.poll());
 
       list.addTail(a, 9);
       list.addTail(b, 8);
@@ -330,18 +334,18 @@ public final class PriorityLinkedListTest extends Assert {
       list.addTail(i, 1);
       list.addTail(j, 0);
 
-      Assert.assertEquals(a, list.poll());
-      Assert.assertEquals(b, list.poll());
-      Assert.assertEquals(c, list.poll());
-      Assert.assertEquals(d, list.poll());
-      Assert.assertEquals(e, list.poll());
-      Assert.assertEquals(f, list.poll());
-      Assert.assertEquals(g, list.poll());
-      Assert.assertEquals(h, list.poll());
-      Assert.assertEquals(i, list.poll());
-      Assert.assertEquals(j, list.poll());
+      assertEquals(a, list.poll());
+      assertEquals(b, list.poll());
+      assertEquals(c, list.poll());
+      assertEquals(d, list.poll());
+      assertEquals(e, list.poll());
+      assertEquals(f, list.poll());
+      assertEquals(g, list.poll());
+      assertEquals(h, list.poll());
+      assertEquals(i, list.poll());
+      assertEquals(j, list.poll());
 
-      Assert.assertNull(list.poll());
+      assertNull(list.poll());
 
       list.addTail(a, 9);
       list.addTail(b, 0);
@@ -354,18 +358,18 @@ public final class PriorityLinkedListTest extends Assert {
       list.addTail(i, 5);
       list.addTail(j, 4);
 
-      Assert.assertEquals(a, list.poll());
-      Assert.assertEquals(c, list.poll());
-      Assert.assertEquals(e, list.poll());
-      Assert.assertEquals(g, list.poll());
-      Assert.assertEquals(i, list.poll());
-      Assert.assertEquals(j, list.poll());
-      Assert.assertEquals(h, list.poll());
-      Assert.assertEquals(f, list.poll());
-      Assert.assertEquals(d, list.poll());
-      Assert.assertEquals(b, list.poll());
+      assertEquals(a, list.poll());
+      assertEquals(c, list.poll());
+      assertEquals(e, list.poll());
+      assertEquals(g, list.poll());
+      assertEquals(i, list.poll());
+      assertEquals(j, list.poll());
+      assertEquals(h, list.poll());
+      assertEquals(f, list.poll());
+      assertEquals(d, list.poll());
+      assertEquals(b, list.poll());
 
-      Assert.assertNull(list.poll());
+      assertNull(list.poll());
 
       list.addTail(a, 0);
       list.addTail(b, 3);
@@ -378,18 +382,18 @@ public final class PriorityLinkedListTest extends Assert {
       list.addTail(i, 9);
       list.addTail(j, 9);
 
-      Assert.assertEquals(h, list.poll());
-      Assert.assertEquals(i, list.poll());
-      Assert.assertEquals(j, list.poll());
-      Assert.assertEquals(e, list.poll());
-      Assert.assertEquals(f, list.poll());
-      Assert.assertEquals(g, list.poll());
-      Assert.assertEquals(b, list.poll());
-      Assert.assertEquals(c, list.poll());
-      Assert.assertEquals(d, list.poll());
-      Assert.assertEquals(a, list.poll());
+      assertEquals(h, list.poll());
+      assertEquals(i, list.poll());
+      assertEquals(j, list.poll());
+      assertEquals(e, list.poll());
+      assertEquals(f, list.poll());
+      assertEquals(g, list.poll());
+      assertEquals(b, list.poll());
+      assertEquals(c, list.poll());
+      assertEquals(d, list.poll());
+      assertEquals(a, list.poll());
 
-      Assert.assertNull(list.poll());
+      assertNull(list.poll());
 
       list.addTail(a, 5);
       list.addTail(b, 5);
@@ -402,18 +406,18 @@ public final class PriorityLinkedListTest extends Assert {
       list.addTail(i, 5);
       list.addTail(j, 5);
 
-      Assert.assertEquals(a, list.poll());
-      Assert.assertEquals(b, list.poll());
-      Assert.assertEquals(c, list.poll());
-      Assert.assertEquals(d, list.poll());
-      Assert.assertEquals(e, list.poll());
-      Assert.assertEquals(f, list.poll());
-      Assert.assertEquals(g, list.poll());
-      Assert.assertEquals(h, list.poll());
-      Assert.assertEquals(i, list.poll());
-      Assert.assertEquals(j, list.poll());
+      assertEquals(a, list.poll());
+      assertEquals(b, list.poll());
+      assertEquals(c, list.poll());
+      assertEquals(d, list.poll());
+      assertEquals(e, list.poll());
+      assertEquals(f, list.poll());
+      assertEquals(g, list.poll());
+      assertEquals(h, list.poll());
+      assertEquals(i, list.poll());
+      assertEquals(j, list.poll());
 
-      Assert.assertNull(list.poll());
+      assertNull(list.poll());
 
       list.addTail(j, 5);
       list.addTail(i, 5);
@@ -426,18 +430,18 @@ public final class PriorityLinkedListTest extends Assert {
       list.addTail(b, 5);
       list.addTail(a, 5);
 
-      Assert.assertEquals(j, list.poll());
-      Assert.assertEquals(i, list.poll());
-      Assert.assertEquals(h, list.poll());
-      Assert.assertEquals(g, list.poll());
-      Assert.assertEquals(f, list.poll());
-      Assert.assertEquals(e, list.poll());
-      Assert.assertEquals(d, list.poll());
-      Assert.assertEquals(c, list.poll());
-      Assert.assertEquals(b, list.poll());
-      Assert.assertEquals(a, list.poll());
+      assertEquals(j, list.poll());
+      assertEquals(i, list.poll());
+      assertEquals(h, list.poll());
+      assertEquals(g, list.poll());
+      assertEquals(f, list.poll());
+      assertEquals(e, list.poll());
+      assertEquals(d, list.poll());
+      assertEquals(c, list.poll());
+      assertEquals(b, list.poll());
+      assertEquals(a, list.poll());
 
-      Assert.assertNull(list.poll());
+      assertNull(list.poll());
 
       assertEquals(0, list.size());
 
@@ -480,262 +484,262 @@ public final class PriorityLinkedListTest extends Assert {
          w1 = iter.next();
          count++;
       }
-      Assert.assertEquals(26, count);
-      Assert.assertEquals(26, list.size());
+      assertEquals(26, count);
+      assertEquals(26, list.size());
 
       iter = list.iterator();
 
       assertTrue(iter.hasNext());
       w1 = iter.next();
       assertTrue(iter.hasNext());
-      Assert.assertEquals("a", w1.s1);
+      assertEquals("a", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
       assertTrue(iter.hasNext());
-      Assert.assertEquals("b", w1.s1);
+      assertEquals("b", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("c", w1.s1);
+      assertEquals("c", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("d", w1.s1);
+      assertEquals("d", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("e", w1.s1);
+      assertEquals("e", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("f", w1.s1);
+      assertEquals("f", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("g", w1.s1);
+      assertEquals("g", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("h", w1.s1);
+      assertEquals("h", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("i", w1.s1);
+      assertEquals("i", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("j", w1.s1);
+      assertEquals("j", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("k", w1.s1);
+      assertEquals("k", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("l", w1.s1);
+      assertEquals("l", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("m", w1.s1);
+      assertEquals("m", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("n", w1.s1);
+      assertEquals("n", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("o", w1.s1);
+      assertEquals("o", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("p", w1.s1);
+      assertEquals("p", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("q", w1.s1);
+      assertEquals("q", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("r", w1.s1);
+      assertEquals("r", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("s", w1.s1);
+      assertEquals("s", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("t", w1.s1);
+      assertEquals("t", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("u", w1.s1);
+      assertEquals("u", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("v", w1.s1);
+      assertEquals("v", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("w", w1.s1);
+      assertEquals("w", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("x", w1.s1);
+      assertEquals("x", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("y", w1.s1);
+      assertEquals("y", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("z", w1.s1);
+      assertEquals("z", w1.s1);
       assertFalse(iter.hasNext());
 
       iter = list.iterator();
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("a", w1.s1);
+      assertEquals("a", w1.s1);
 
       iter.remove();
 
-      Assert.assertEquals(25, list.size());
+      assertEquals(25, list.size());
 
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("b", w1.s1);
+      assertEquals("b", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("c", w1.s1);
+      assertEquals("c", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("d", w1.s1);
+      assertEquals("d", w1.s1);
 
       iter.remove();
 
-      Assert.assertEquals(24, list.size());
+      assertEquals(24, list.size());
 
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("c", w1.s1);
+      assertEquals("c", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("e", w1.s1);
+      assertEquals("e", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("f", w1.s1);
+      assertEquals("f", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("g", w1.s1);
+      assertEquals("g", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("h", w1.s1);
+      assertEquals("h", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("i", w1.s1);
+      assertEquals("i", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("j", w1.s1);
+      assertEquals("j", w1.s1);
 
       iter.remove();
 
-      Assert.assertEquals(23, list.size());
+      assertEquals(23, list.size());
 
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("i", w1.s1);
+      assertEquals("i", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("k", w1.s1);
+      assertEquals("k", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("l", w1.s1);
+      assertEquals("l", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("m", w1.s1);
+      assertEquals("m", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("n", w1.s1);
+      assertEquals("n", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("o", w1.s1);
+      assertEquals("o", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("p", w1.s1);
+      assertEquals("p", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("q", w1.s1);
+      assertEquals("q", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("r", w1.s1);
+      assertEquals("r", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("s", w1.s1);
+      assertEquals("s", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("t", w1.s1);
+      assertEquals("t", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("u", w1.s1);
+      assertEquals("u", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("v", w1.s1);
+      assertEquals("v", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("w", w1.s1);
+      assertEquals("w", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("x", w1.s1);
+      assertEquals("x", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("y", w1.s1);
+      assertEquals("y", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("z", w1.s1);
+      assertEquals("z", w1.s1);
       iter.remove();
 
       iter = list.iterator();
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("b", w1.s1);
+      assertEquals("b", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("c", w1.s1);
+      assertEquals("c", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("e", w1.s1);
+      assertEquals("e", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("f", w1.s1);
+      assertEquals("f", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("g", w1.s1);
+      assertEquals("g", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("h", w1.s1);
+      assertEquals("h", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("i", w1.s1);
+      assertEquals("i", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("k", w1.s1);
+      assertEquals("k", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("l", w1.s1);
+      assertEquals("l", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("m", w1.s1);
+      assertEquals("m", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("n", w1.s1);
+      assertEquals("n", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("o", w1.s1);
+      assertEquals("o", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("p", w1.s1);
+      assertEquals("p", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("q", w1.s1);
+      assertEquals("q", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("r", w1.s1);
+      assertEquals("r", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("s", w1.s1);
+      assertEquals("s", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("t", w1.s1);
+      assertEquals("t", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("u", w1.s1);
+      assertEquals("u", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("v", w1.s1);
+      assertEquals("v", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("w", w1.s1);
+      assertEquals("w", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("x", w1.s1);
+      assertEquals("x", w1.s1);
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("y", w1.s1);
+      assertEquals("y", w1.s1);
 
       assertFalse(iter.hasNext());
       assertFalse(iter.hasNext());
@@ -747,11 +751,11 @@ public final class PriorityLinkedListTest extends Assert {
 
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("a", w1.s1);
+      assertEquals("a", w1.s1);
 
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("b", w1.s1);
+      assertEquals("b", w1.s1);
 
       assertFalse(iter.hasNext());
 
@@ -760,11 +764,11 @@ public final class PriorityLinkedListTest extends Assert {
 
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("c", w1.s1);
+      assertEquals("c", w1.s1);
 
       assertTrue(iter.hasNext());
       w1 = iter.next();
-      Assert.assertEquals("d", w1.s1);
+      assertEquals("d", w1.s1);
 
       assertFalse(iter.hasNext());
 
@@ -821,7 +825,7 @@ public final class PriorityLinkedListTest extends Assert {
 
       list.clear();
 
-      Assert.assertNull(list.poll());
+      assertNull(list.poll());
    }
 
    @Test
@@ -878,6 +882,21 @@ public final class PriorityLinkedListTest extends Assert {
    }
 
 
+   @Test
+   public void testPeek() {
+      assertNull(list.peek());
+
+      list.addTail(c, 5);
+      assertEquals(c, list.peek());
+
+      list.addTail(k, 0);
+      assertEquals(k, list.peek());
+
+      list.addHead(a, 0);
+      assertEquals(a, list.peek());
+   }
+
+
    @Test
    public void testRemoveWithID() {
 
@@ -918,10 +937,10 @@ public final class PriorityLinkedListTest extends Assert {
 
       // remove every 3rd
       for (int i = 3; i <= 3000; i += 3) {
-         Assert.assertEquals(new Wibble("" + i, i), list.removeWithID("", i));
+         assertEquals(new Wibble("" + i, i), list.removeWithID("", i));
       }
 
-      Assert.assertEquals(2000, list.size());
+      assertEquals(2000, list.size());
 
       Iterator<Wibble> iterator = list.iterator();
 
@@ -930,14 +949,14 @@ public final class PriorityLinkedListTest extends Assert {
          values.add(iterator.next().s1);
       }
 
-      Assert.assertEquals(2000, values.size());
+      assertEquals(2000, values.size());
 
 
       for (int i = 1; i <= 3000; i += 3) {
          if (i % 3 == 0) {
-            Assert.assertFalse(values.contains("" + i));
+            assertFalse(values.contains("" + i));
          } else {
-            Assert.assertTrue(values.contains("" + i));
+            assertTrue(values.contains("" + i));
          }
       }
 
