@@ -16,6 +16,12 @@
  */
 package org.apache.activemq.artemis.core.server.impl;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+
+import java.lang.invoke.MethodHandles;
 import java.util.Collection;
 import java.util.HashSet;
 import java.util.LinkedList;
@@ -60,13 +66,11 @@ import org.apache.activemq.artemis.utils.collections.LinkedListIterator;
 import org.apache.activemq.artemis.utils.collections.NodeStoreFactory;
 import org.apache.activemq.artemis.utils.critical.CriticalComponentImpl;
 import org.apache.activemq.artemis.utils.critical.EmptyCriticalAnalyzer;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import java.lang.invoke.MethodHandles;
-import org.junit.Assert;
-import org.junit.Test;
 
-public class ScheduledDeliveryHandlerTest extends Assert {
+public class ScheduledDeliveryHandlerTest {
 
    private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
@@ -292,7 +296,7 @@ public class ScheduledDeliveryHandlerTest extends Assert {
       }
 
       for (long i = 0; i < numberOfExpectedMessages; i++) {
-         assertTrue(messages.contains(Long.valueOf(i)));
+         assertTrue(messages.contains(i));
       }
    }
 
@@ -308,6 +312,16 @@ public class ScheduledDeliveryHandlerTest extends Assert {
 
       }
 
+      @Override
+      public void setPaged() {
+
+      }
+
+      @Override
+      public boolean isPaged() {
+         return false;
+      }
+
       @Override
       public String getProtocolName() {
          // should normally not be visible in GUI
@@ -1023,7 +1037,7 @@ public class ScheduledDeliveryHandlerTest extends Assert {
 
       @Override
       public Long getID() {
-         return Long.valueOf(0L);
+         return 0L;
       }
 
       @Override
