@@ -16,6 +16,10 @@
  */
 package org.apache.activemq.artemis.core.settings;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.fail;
+
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -27,17 +31,16 @@ import org.apache.activemq.artemis.core.config.WildcardConfiguration;
 import org.apache.activemq.artemis.core.security.Role;
 import org.apache.activemq.artemis.core.settings.impl.AddressSettings;
 import org.apache.activemq.artemis.core.settings.impl.HierarchicalObjectRepository;
-import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.apache.activemq.artemis.tests.util.ServerTestBase;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
-public class RepositoryTest extends ActiveMQTestBase {
+public class RepositoryTest extends ServerTestBase {
 
    HierarchicalRepository<HashSet<Role>> securityRepository;
 
    @Override
-   @Before
+   @BeforeEach
    public void setUp() throws Exception {
       super.setUp();
 
@@ -49,7 +52,7 @@ public class RepositoryTest extends ActiveMQTestBase {
       securityRepository.setDefault(new HashSet<Role>());
       HashSet<Role> roles = securityRepository.getMatch("queues.something");
 
-      Assert.assertEquals(roles.size(), 0);
+      assertEquals(roles.size(), 0);
    }
 
    @Test
@@ -60,13 +63,13 @@ public class RepositoryTest extends ActiveMQTestBase {
       repo.addMatch("a.b.d.#", "abd#");
       repo.addMatch("#", "root");
 
-      Assert.assertEquals("ab#", repo.getMatch("a.b"));
-      Assert.assertEquals("ab#", repo.getMatch("a.b.c"));
-      Assert.assertEquals("abd#", repo.getMatch("a.b.d.lll"));
-      Assert.assertEquals("root", repo.getMatch("z.z.z.z.z"));
-      Assert.assertEquals("root", repo.getMatch("a.babc"));
-      Assert.assertEquals("ab#", repo.getMatch("a.b.dabc"));
-      Assert.assertEquals("abd#", repo.getMatch("a.b.d"));
+      assertEquals("ab#", repo.getMatch("a.b"));
+      assertEquals("ab#", repo.getMatch("a.b.c"));
+      assertEquals("abd#", repo.getMatch("a.b.d.lll"));
+      assertEquals("root", repo.getMatch("z.z.z.z.z"));
+      assertEquals("root", repo.getMatch("a.babc"));
+      assertEquals("ab#", repo.getMatch("a.b.dabc"));
+      assertEquals("abd#", repo.getMatch("a.b.d"));
    }
 
    /*
@@ -83,18 +86,18 @@ public class RepositoryTest extends ActiveMQTestBase {
       repo.addMatch("a.*", new DummyMergeable(4));
 
       DummyMergeable abDummyMatch = repo.getMatch("a.b");
-      Assert.assertEquals(3, abDummyMatch.getMergedItems().size());
-      Assert.assertEquals(3, abDummyMatch.getId());
-      Assert.assertEquals(4, abDummyMatch.getMergedItems().get(0).getId());
-      Assert.assertEquals(2, abDummyMatch.getMergedItems().get(1).getId());
-      Assert.assertEquals(0, abDummyMatch.getMergedItems().get(2).getId());
+      assertEquals(3, abDummyMatch.getMergedItems().size());
+      assertEquals(3, abDummyMatch.getId());
+      assertEquals(4, abDummyMatch.getMergedItems().get(0).getId());
+      assertEquals(2, abDummyMatch.getMergedItems().get(1).getId());
+      assertEquals(0, abDummyMatch.getMergedItems().get(2).getId());
 
       DummyMergeable aDummyMatch = repo.getMatch("a.#");
-      Assert.assertEquals(3, aDummyMatch.getMergedItems().size());
-      Assert.assertEquals(1, aDummyMatch.getId());
-      Assert.assertEquals(4, aDummyMatch.getMergedItems().get(0).getId());
-      Assert.assertEquals(2, aDummyMatch.getMergedItems().get(1).getId());
-      Assert.assertEquals(0, aDummyMatch.getMergedItems().get(2).getId());
+      assertEquals(3, aDummyMatch.getMergedItems().size());
+      assertEquals(1, aDummyMatch.getId());
+      assertEquals(4, aDummyMatch.getMergedItems().get(0).getId());
+      assertEquals(2, aDummyMatch.getMergedItems().get(1).getId());
+      assertEquals(0, aDummyMatch.getMergedItems().get(2).getId());
    }
 
    @Test
@@ -102,10 +105,10 @@ public class RepositoryTest extends ActiveMQTestBase {
       HierarchicalObjectRepository<String> repo = new HierarchicalObjectRepository<>();
 
       repo.addMatch("#", "root");
-      Assert.assertEquals("root", repo.getMatch("b"));
+      assertEquals("root", repo.getMatch("b"));
 
       repo.addMatch("b", "leaf");
-      Assert.assertEquals("leaf", repo.getMatch("b"));
+      assertEquals("leaf", repo.getMatch("b"));
    }
 
    @Test
@@ -119,17 +122,17 @@ public class RepositoryTest extends ActiveMQTestBase {
       repository.addMatch("a.b.c.d.e.#", "a.b.c.d.e.#");//6
 
       String val = repository.getMatch("a.b.c.d.e.f");//matches all
-      Assert.assertEquals("a.b.c.d.e.f", val);
+      assertEquals("a.b.c.d.e.f", val);
       val = repository.getMatch("a.b.c.d.e.x");//matches 2,3,6
-      Assert.assertEquals("a.b.c.d.e.*", val);
+      assertEquals("a.b.c.d.e.*", val);
       val = repository.getMatch("a.b.x.d.x.f");//matches 3,5
-      Assert.assertEquals("a.*.*.*.*.*", val);
+      assertEquals("a.*.*.*.*.*", val);
       val = repository.getMatch("x.b.c.d.e.f");//matches 4,5
-      Assert.assertEquals("*.b.c.d.*.f", val);
+      assertEquals("*.b.c.d.*.f", val);
       val = repository.getMatch("x.b.x.d.e.f");//matches 5
-      Assert.assertEquals("*.b.*.d.*.f", val);
+      assertEquals("*.b.*.d.*.f", val);
       val = repository.getMatch("a.b.c.d.e.f.g");//matches 6
-      Assert.assertEquals("a.b.c.d.e.#", val);
+      assertEquals("a.b.c.d.e.#", val);
    }
 
    @Test
@@ -142,13 +145,13 @@ public class RepositoryTest extends ActiveMQTestBase {
       repo.addMatch("a_b_d_#", "abd#");
       repo.addMatch("#", "root");
 
-      Assert.assertEquals("ab#", repo.getMatch("a_b"));
-      Assert.assertEquals("ab#", repo.getMatch("a_b_c"));
-      Assert.assertEquals("abd#", repo.getMatch("a_b_d_lll"));
-      Assert.assertEquals("root", repo.getMatch("z_z_z_z_z"));
-      Assert.assertEquals("root", repo.getMatch("a_babc"));
-      Assert.assertEquals("ab#", repo.getMatch("a_b_dabc"));
-      Assert.assertEquals("abd#", repo.getMatch("a_b_d"));
+      assertEquals("ab#", repo.getMatch("a_b"));
+      assertEquals("ab#", repo.getMatch("a_b_c"));
+      assertEquals("abd#", repo.getMatch("a_b_d_lll"));
+      assertEquals("root", repo.getMatch("z_z_z_z_z"));
+      assertEquals("root", repo.getMatch("a_babc"));
+      assertEquals("ab#", repo.getMatch("a_b_dabc"));
+      assertEquals("abd#", repo.getMatch("a_b_d"));
    }
 
    @Test
@@ -161,48 +164,48 @@ public class RepositoryTest extends ActiveMQTestBase {
       repo.addMatch("a/b/d/#", "abd#");
       repo.addMatch("#", "root");
 
-      Assert.assertEquals("ab#", repo.getMatch("a/b"));
-      Assert.assertEquals("ab#", repo.getMatch("a/b/c"));
-      Assert.assertEquals("abd#", repo.getMatch("a/b/d/lll"));
-      Assert.assertEquals("root", repo.getMatch("z/z/z/z/z"));
-      Assert.assertEquals("root", repo.getMatch("a/babc"));
-      Assert.assertEquals("ab#", repo.getMatch("a/b/dabc"));
-      Assert.assertEquals("abd#", repo.getMatch("a/b/d"));
+      assertEquals("ab#", repo.getMatch("a/b"));
+      assertEquals("ab#", repo.getMatch("a/b/c"));
+      assertEquals("abd#", repo.getMatch("a/b/d/lll"));
+      assertEquals("root", repo.getMatch("z/z/z/z/z"));
+      assertEquals("root", repo.getMatch("a/babc"));
+      assertEquals("ab#", repo.getMatch("a/b/dabc"));
+      assertEquals("abd#", repo.getMatch("a/b/d"));
    }
 
    @Test
    public void testSingleMatch() {
       securityRepository.addMatch("queues.*", new HashSet<Role>());
       HashSet<Role> hashSet = securityRepository.getMatch("queues.something");
-      Assert.assertEquals(hashSet.size(), 0);
+      assertEquals(hashSet.size(), 0);
    }
 
    @Test
    public void testSingletwo() {
       securityRepository.addMatch("queues.another.aq.*", new HashSet<Role>());
       HashSet<Role> roles = new HashSet<>(2);
-      roles.add(new Role("test1", true, true, true, true, true, true, true, true, true, true));
-      roles.add(new Role("test2", true, true, true, true, true, true, true, true, true, true));
+      roles.add(new Role("test1", true, true, true, true, true, true, true, true, true, true, false, false));
+      roles.add(new Role("test2", true, true, true, true, true, true, true, true, true, true, false, false));
       securityRepository.addMatch("queues.aq", roles);
       HashSet<Role> roles2 = new HashSet<>(2);
-      roles2.add(new Role("test1", true, true, true, true, true, true, true, true, true, true));
-      roles2.add(new Role("test2", true, true, true, true, true, true, true, true, true, true));
-      roles2.add(new Role("test3", true, true, true, true, true, true, true, true, true, true));
+      roles2.add(new Role("test1", true, true, true, true, true, true, true, true, true, true, false, false));
+      roles2.add(new Role("test2", true, true, true, true, true, true, true, true, true, true, false, false));
+      roles2.add(new Role("test3", true, true, true, true, true, true, true, true, true, true, false, false));
       securityRepository.addMatch("queues.another.andanother", roles2);
 
       HashSet<Role> hashSet = securityRepository.getMatch("queues.another.andanother");
-      Assert.assertEquals(hashSet.size(), 3);
+      assertEquals(hashSet.size(), 3);
    }
 
    @Test
    public void testWithoutWildcard() {
       securityRepository.addMatch("queues.1.*", new HashSet<Role>());
       HashSet<Role> roles = new HashSet<>(2);
-      roles.add(new Role("test1", true, true, true, true, true, true, true, true, true, true));
-      roles.add(new Role("test2", true, true, true, true, true, true, true, true, true, true));
+      roles.add(new Role("test1", true, true, true, true, true, true, true, true, true, true, false, false));
+      roles.add(new Role("test2", true, true, true, true, true, true, true, true, true, true, false, false));
       securityRepository.addMatch("queues.2.aq", roles);
       HashSet<Role> hashSet = securityRepository.getMatch("queues.2.aq");
-      Assert.assertEquals(hashSet.size(), 2);
+      assertEquals(hashSet.size(), 2);
    }
 
    @Test
@@ -222,31 +225,31 @@ public class RepositoryTest extends ActiveMQTestBase {
       repository.addMatch("a.*.*.d", "a.*.*.d");
       repository.addMatch("a.*.d.#", "a.*.d.#");
       String val = repository.getMatch("a");
-      Assert.assertEquals("a", val);
+      assertEquals("a", val);
       val = repository.getMatch("a.b");
-      Assert.assertEquals("a.b", val);
+      assertEquals("a.b", val);
       val = repository.getMatch("a.x");
-      Assert.assertEquals("a.*", val);
+      assertEquals("a.*", val);
       val = repository.getMatch("a.b.x");
-      Assert.assertEquals("a.b.#", val);
+      assertEquals("a.b.#", val);
       val = repository.getMatch("a.b.c");
-      Assert.assertEquals("a.b.c", val);
+      assertEquals("a.b.c", val);
       val = repository.getMatch("a.d.c");
-      Assert.assertEquals("a.d.c", val);
+      assertEquals("a.d.c", val);
       val = repository.getMatch("a.x.c");
-      Assert.assertEquals("a.*.c", val);
+      assertEquals("a.*.c", val);
       val = repository.getMatch("a.b.c.d");
-      Assert.assertEquals("a.b.c.d", val);
+      assertEquals("a.b.c.d", val);
       val = repository.getMatch("a.x.c.d");
-      Assert.assertEquals("a.*.*.d", val);
+      assertEquals("a.*.*.d", val);
       val = repository.getMatch("a.b.x.d");
-      Assert.assertEquals("a.*.*.d", val);
+      assertEquals("a.*.*.d", val);
       val = repository.getMatch("a.d.x.d");
-      Assert.assertEquals("a.*.*.d", val);
+      assertEquals("a.*.*.d", val);
       val = repository.getMatch("a.d.d.g");
-      Assert.assertEquals("a.*.d.#", val);
+      assertEquals("a.*.d.#", val);
       val = repository.getMatch("zzzz.z.z.z.d.r.g.f.sd.s.fsdfd.fsdfs");
-      Assert.assertEquals("#", val);
+      assertEquals("#", val);
    }
 
    @Test
@@ -261,22 +264,22 @@ public class RepositoryTest extends ActiveMQTestBase {
       repository.addMatch("a.b.*.d", new DummyMergeable(7));
       repository.addMatch("a.b.c.*", new DummyMergeable(8));
       DummyMergeable abcdDummyMatch = repository.getMatch("a.b.c.d");
-      Assert.assertEquals(5, abcdDummyMatch.getMergedItems().size());
-      Assert.assertEquals(8, abcdDummyMatch.getId());
-      Assert.assertEquals(7, abcdDummyMatch.getMergedItems().get(0).getId());
-      Assert.assertEquals(6, abcdDummyMatch.getMergedItems().get(1).getId());
-      Assert.assertEquals(4, abcdDummyMatch.getMergedItems().get(2).getId());
-      Assert.assertEquals(2, abcdDummyMatch.getMergedItems().get(3).getId());
-      Assert.assertEquals(1, abcdDummyMatch.getMergedItems().get(4).getId());
+      assertEquals(5, abcdDummyMatch.getMergedItems().size());
+      assertEquals(8, abcdDummyMatch.getId());
+      assertEquals(7, abcdDummyMatch.getMergedItems().get(0).getId());
+      assertEquals(6, abcdDummyMatch.getMergedItems().get(1).getId());
+      assertEquals(4, abcdDummyMatch.getMergedItems().get(2).getId());
+      assertEquals(2, abcdDummyMatch.getMergedItems().get(3).getId());
+      assertEquals(1, abcdDummyMatch.getMergedItems().get(4).getId());
       DummyMergeable abcDummyMatch = repository.getMatch("a.b.c");
-      Assert.assertEquals(3, abcDummyMatch.getMergedItems().size());
-      Assert.assertEquals(6, abcDummyMatch.getId());
-      Assert.assertEquals(4, abcDummyMatch.getMergedItems().get(0).getId());
-      Assert.assertEquals(2, abcDummyMatch.getMergedItems().get(1).getId());
-      Assert.assertEquals(1, abcDummyMatch.getMergedItems().get(2).getId());
+      assertEquals(3, abcDummyMatch.getMergedItems().size());
+      assertEquals(6, abcDummyMatch.getId());
+      assertEquals(4, abcDummyMatch.getMergedItems().get(0).getId());
+      assertEquals(2, abcDummyMatch.getMergedItems().get(1).getId());
+      assertEquals(1, abcDummyMatch.getMergedItems().get(2).getId());
       DummyMergeable zDummyMatch = repository.getMatch("z");
-      Assert.assertEquals(0, zDummyMatch.getMergedItems().size());
-      Assert.assertEquals(1, zDummyMatch.getId());
+      assertEquals(0, zDummyMatch.getMergedItems().size());
+      assertEquals(1, zDummyMatch.getId());
    }
 
    @Test
@@ -345,40 +348,40 @@ public class RepositoryTest extends ActiveMQTestBase {
       repository.addMatch("foo.1.#", new DummyMergeable(2, Map.of("so", "b", "s1", "b")));
 
       DummyMergeable fooxMatch = repository.getMatch("foo.x");
-      Assert.assertEquals(0, fooxMatch.getId());
-      Assert.assertEquals(0, fooxMatch.getMergedItems().size());
-      Assert.assertEquals("x", fooxMatch.getSettings().get("s0"));
-      Assert.assertNull(fooxMatch.getSettings().get("s1"));
+      assertEquals(0, fooxMatch.getId());
+      assertEquals(0, fooxMatch.getMergedItems().size());
+      assertEquals("x", fooxMatch.getSettings().get("s0"));
+      assertNull(fooxMatch.getSettings().get("s1"));
 
       DummyMergeable foo1Match = repository.getMatch("foo.0");
-      Assert.assertEquals(0, foo1Match.getId());
-      Assert.assertEquals(1, foo1Match.getMergedItems().size());
-      Assert.assertEquals("x", fooxMatch.getSettings().get("s0"));
-      Assert.assertEquals("a", foo1Match.getSettings().get("s1"));
+      assertEquals(0, foo1Match.getId());
+      assertEquals(1, foo1Match.getMergedItems().size());
+      assertEquals("x", fooxMatch.getSettings().get("s0"));
+      assertEquals("a", foo1Match.getSettings().get("s1"));
 
       DummyMergeable foo2Match = repository.getMatch("foo.1");
-      Assert.assertEquals(0, foo2Match.getId());
-      Assert.assertEquals(1, foo2Match.getMergedItems().size());
-      Assert.assertEquals("x", fooxMatch.getSettings().get("s0"));
-      Assert.assertEquals("b", foo2Match.getSettings().get("s1"));
+      assertEquals(0, foo2Match.getId());
+      assertEquals(1, foo2Match.getMergedItems().size());
+      assertEquals("x", fooxMatch.getSettings().get("s0"));
+      assertEquals("b", foo2Match.getSettings().get("s1"));
 
       DummyMergeable fooxBisMatch = repository.getMatch("foo.x");
-      Assert.assertEquals(0, fooxBisMatch.getId());
-      Assert.assertEquals(0, fooxBisMatch.getMergedItems().size());
-      Assert.assertEquals("x", fooxBisMatch.getSettings().get("s0"));
-      Assert.assertNull(fooxBisMatch.getSettings().get("s1"));
+      assertEquals(0, fooxBisMatch.getId());
+      assertEquals(0, fooxBisMatch.getMergedItems().size());
+      assertEquals("x", fooxBisMatch.getSettings().get("s0"));
+      assertNull(fooxBisMatch.getSettings().get("s1"));
 
       DummyMergeable foo1BisMatch = repository.getMatch("foo.0");
-      Assert.assertEquals(0, foo1BisMatch.getId());
-      Assert.assertEquals(1, foo1BisMatch.getMergedItems().size());
-      Assert.assertEquals("x", foo1BisMatch.getSettings().get("s0"));
-      Assert.assertEquals("a", foo1BisMatch.getSettings().get("s1"));
+      assertEquals(0, foo1BisMatch.getId());
+      assertEquals(1, foo1BisMatch.getMergedItems().size());
+      assertEquals("x", foo1BisMatch.getSettings().get("s0"));
+      assertEquals("a", foo1BisMatch.getSettings().get("s1"));
 
       DummyMergeable foo2BisMatch = repository.getMatch("foo.1");
-      Assert.assertEquals(0, foo2BisMatch.getId());
-      Assert.assertEquals(1, foo2BisMatch.getMergedItems().size());
-      Assert.assertEquals("x", foo2BisMatch.getSettings().get("s0"));
-      Assert.assertEquals("b", foo2BisMatch.getSettings().get("s1"));
+      assertEquals(0, foo2BisMatch.getId());
+      assertEquals(1, foo2BisMatch.getMergedItems().size());
+      assertEquals("x", foo2BisMatch.getSettings().get("s0"));
+      assertEquals("b", foo2BisMatch.getSettings().get("s1"));
    }
 
    @Test
@@ -393,28 +396,28 @@ public class RepositoryTest extends ActiveMQTestBase {
       repository.addMatch("foo.1.#", foo1);
 
       AddressSettings fooxMatch = repository.getMatch("foo.x");
-      Assert.assertEquals(10000, fooxMatch.getMaxRedeliveryDelay());
-      Assert.assertEquals(Long.valueOf(AddressSettings.DEFAULT_MAX_EXPIRY_DELAY), fooxMatch.getMaxExpiryDelay());
+      assertEquals(10000, fooxMatch.getMaxRedeliveryDelay());
+      assertEquals(Long.valueOf(AddressSettings.DEFAULT_MAX_EXPIRY_DELAY), fooxMatch.getMaxExpiryDelay());
 
       AddressSettings foo0Match = repository.getMatch("foo.0");
-      Assert.assertEquals(10000, foo0Match.getMaxRedeliveryDelay());
-      Assert.assertEquals(Long.valueOf(20000), foo0Match.getMaxExpiryDelay());
+      assertEquals(10000, foo0Match.getMaxRedeliveryDelay());
+      assertEquals(Long.valueOf(20000), foo0Match.getMaxExpiryDelay());
 
       AddressSettings foo1Match = repository.getMatch("foo.1");
-      Assert.assertEquals(10000, foo1Match.getMaxRedeliveryDelay());
-      Assert.assertEquals(Long.valueOf(30000), foo1Match.getMaxExpiryDelay());
+      assertEquals(10000, foo1Match.getMaxRedeliveryDelay());
+      assertEquals(Long.valueOf(30000), foo1Match.getMaxExpiryDelay());
 
       AddressSettings fooxBisMatch = repository.getMatch("foo.x");
-      Assert.assertEquals(10000, fooxBisMatch.getMaxRedeliveryDelay());
-      Assert.assertEquals(Long.valueOf(AddressSettings.DEFAULT_MAX_EXPIRY_DELAY), fooxBisMatch.getMaxExpiryDelay());
+      assertEquals(10000, fooxBisMatch.getMaxRedeliveryDelay());
+      assertEquals(Long.valueOf(AddressSettings.DEFAULT_MAX_EXPIRY_DELAY), fooxBisMatch.getMaxExpiryDelay());
 
       AddressSettings foo0BisMatch = repository.getMatch("foo.0");
-      Assert.assertEquals(10000, foo0BisMatch.getMaxRedeliveryDelay());
-      Assert.assertEquals(Long.valueOf(20000), foo0BisMatch.getMaxExpiryDelay());
+      assertEquals(10000, foo0BisMatch.getMaxRedeliveryDelay());
+      assertEquals(Long.valueOf(20000), foo0BisMatch.getMaxExpiryDelay());
 
       AddressSettings foo1BisMatch = repository.getMatch("foo.1");
-      Assert.assertEquals(10000, foo1BisMatch.getMaxRedeliveryDelay());
-      Assert.assertEquals(Long.valueOf(30000), foo1BisMatch.getMaxExpiryDelay());
+      assertEquals(10000, foo1BisMatch.getMaxRedeliveryDelay());
+      assertEquals(Long.valueOf(30000), foo1BisMatch.getMaxExpiryDelay());
    }
 
    static class DummyMergeable implements Mergeable<DummyMergeable> {
