@@ -1,12 +1,12 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with
+ * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
+ * the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *      http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -14,9 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.activemq.artemis.core.transaction.impl;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+
 import javax.transaction.xa.Xid;
 import java.nio.ByteBuffer;
 import java.util.List;
@@ -34,6 +37,7 @@ import org.apache.activemq.artemis.core.io.IOCallback;
 import org.apache.activemq.artemis.core.io.SequentialFile;
 import org.apache.activemq.artemis.core.journal.Journal;
 import org.apache.activemq.artemis.core.journal.JournalLoadInformation;
+import org.apache.activemq.artemis.core.journal.RecordInfo;
 import org.apache.activemq.artemis.core.paging.PageTransactionInfo;
 import org.apache.activemq.artemis.core.paging.PagedMessage;
 import org.apache.activemq.artemis.core.paging.PagingManager;
@@ -45,7 +49,10 @@ import org.apache.activemq.artemis.core.persistence.GroupingInfo;
 import org.apache.activemq.artemis.core.persistence.OperationContext;
 import org.apache.activemq.artemis.core.persistence.QueueBindingInfo;
 import org.apache.activemq.artemis.core.persistence.StorageManager;
-import org.apache.activemq.artemis.core.persistence.config.PersistedAddressSetting;
+import org.apache.activemq.artemis.core.persistence.config.AbstractPersistedAddressSetting;
+import org.apache.activemq.artemis.core.persistence.config.PersistedAddressSettingJSON;
+import org.apache.activemq.artemis.core.persistence.config.PersistedBridgeConfiguration;
+import org.apache.activemq.artemis.core.persistence.config.PersistedConnector;
 import org.apache.activemq.artemis.core.persistence.config.PersistedDivertConfiguration;
 import org.apache.activemq.artemis.core.persistence.config.PersistedKeyValuePair;
 import org.apache.activemq.artemis.core.persistence.config.PersistedRole;
@@ -65,19 +72,22 @@ import org.apache.activemq.artemis.core.server.impl.JournalLoader;
 import org.apache.activemq.artemis.core.transaction.ResourceManager;
 import org.apache.activemq.artemis.core.transaction.Transaction;
 import org.apache.activemq.artemis.core.transaction.TransactionOperation;
-import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
+import org.apache.activemq.artemis.tests.util.ServerTestBase;
 import org.apache.activemq.artemis.utils.ArtemisCloseable;
-import org.jboss.logging.Logger;
-import org.junit.Assert;
-import org.junit.Test;
+import org.apache.activemq.artemis.utils.UUIDGenerator;
+import org.junit.jupiter.api.Test;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import java.lang.invoke.MethodHandles;
+import java.util.function.Consumer;
 
-public class TransactionImplTest extends ActiveMQTestBase {
-   private static final Logger log = Logger.getLogger(TransactionImplTest.class);
+public class TransactionImplTest extends ServerTestBase {
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
    @Test
    public void testTimeoutAndThenCommitWithARollback() throws Exception {
       TransactionImpl tx = new TransactionImpl(newXID(), new FakeSM(), 10);
-      Assert.assertTrue(tx.hasTimedOut(System.currentTimeMillis() + 60000, 10));
+      assertTrue(tx.hasTimedOut(System.currentTimeMillis() + 60000, 10));
 
       final AtomicInteger commit = new AtomicInteger(0);
       final AtomicInteger rollback = new AtomicInteger(0);
@@ -100,7 +110,7 @@ public class TransactionImplTest extends ActiveMQTestBase {
 
          @Override
          public void afterCommit(Transaction tx) {
-            log.debug("commit...");
+            logger.debug("commit...");
             commit.incrementAndGet();
          }
 
@@ -111,7 +121,7 @@ public class TransactionImplTest extends ActiveMQTestBase {
 
          @Override
          public void afterRollback(Transaction tx) {
-            log.debug("rollback...");
+            logger.debug("rollback...");
             rollback.incrementAndGet();
          }
 
@@ -129,7 +139,7 @@ public class TransactionImplTest extends ActiveMQTestBase {
       for (int i = 0; i < 2; i++) {
          try {
             tx.commit();
-            Assert.fail("Exception expected!");
+            fail("Exception expected!");
          } catch (ActiveMQException expected) {
          }
       }
@@ -137,15 +147,15 @@ public class TransactionImplTest extends ActiveMQTestBase {
       // it should just be ignored!
       tx.rollback();
 
-      Assert.assertEquals(0, commit.get());
-      Assert.assertEquals(1, rollback.get());
+      assertEquals(0, commit.get());
+      assertEquals(1, rollback.get());
 
    }
 
    @Test
    public void testTimeoutThenRollbackWithRollback() throws Exception {
       TransactionImpl tx = new TransactionImpl(newXID(), new FakeSM(), 10);
-      Assert.assertTrue(tx.hasTimedOut(System.currentTimeMillis() + 60000, 10));
+      assertTrue(tx.hasTimedOut(System.currentTimeMillis() + 60000, 10));
 
       final AtomicInteger commit = new AtomicInteger(0);
       final AtomicInteger rollback = new AtomicInteger(0);
@@ -168,7 +178,7 @@ public class TransactionImplTest extends ActiveMQTestBase {
 
          @Override
          public void afterCommit(Transaction tx) {
-            log.debug("commit...");
+            logger.debug("commit...");
             commit.incrementAndGet();
          }
 
@@ -179,7 +189,7 @@ public class TransactionImplTest extends ActiveMQTestBase {
 
          @Override
          public void afterRollback(Transaction tx) {
-            log.debug("rollback...");
+            logger.debug("rollback...");
             rollback.incrementAndGet();
          }
 
@@ -200,11 +210,118 @@ public class TransactionImplTest extends ActiveMQTestBase {
       tx.markAsRollbackOnly(new ActiveMQException("rollback only again"));
       tx.rollback();
 
-      Assert.assertEquals(0, commit.get());
-      Assert.assertEquals(1, rollback.get());
+      assertEquals(0, commit.get());
+      assertEquals(1, rollback.get());
 
    }
 
+   @Test
+   public void testAlreadyCommitted() throws Exception {
+      TransactionImpl tx = new TransactionImpl(newXID(), new FakeSM(), 10);
+
+      final AtomicInteger commit = new AtomicInteger(0);
+      final AtomicInteger rollback = new AtomicInteger(0);
+      tx.commit();
+
+      // simulating a race, the addOperation happened after the commit
+      tx.addOperation(new TransactionOperation() {
+         @Override
+         public void beforePrepare(Transaction tx) throws Exception {
+
+         }
+
+         @Override
+         public void afterPrepare(Transaction tx) {
+
+         }
+
+         @Override
+         public void beforeCommit(Transaction tx) throws Exception {
+
+         }
+
+         @Override
+         public void afterCommit(Transaction tx) {
+            commit.incrementAndGet();
+         }
+
+         @Override
+         public void beforeRollback(Transaction tx) throws Exception {
+
+         }
+
+         @Override
+         public void afterRollback(Transaction tx) {
+            rollback.incrementAndGet();
+         }
+
+         @Override
+         public List<MessageReference> getRelatedMessageReferences() {
+            return null;
+         }
+
+         @Override
+         public List<MessageReference> getListOnConsumer(long consumerID) {
+            return null;
+         }
+      });
+      assertEquals(1, commit.get());
+      assertEquals(0, rollback.get());
+   }
+
+   @Test
+   public void testAlreadyRolledBack() throws Exception {
+      TransactionImpl tx = new TransactionImpl(newXID(), new FakeSM(), 10);
+
+      final AtomicInteger rollback = new AtomicInteger(0);
+      final AtomicInteger commit = new AtomicInteger(0);
+      tx.rollback();
+
+      tx.addOperation(new TransactionOperation() {
+         @Override
+         public void beforePrepare(Transaction tx) throws Exception {
+
+         }
+
+         @Override
+         public void afterPrepare(Transaction tx) {
+
+         }
+
+         @Override
+         public void beforeCommit(Transaction tx) throws Exception {
+
+         }
+
+         @Override
+         public void afterCommit(Transaction tx) {
+            commit.incrementAndGet();
+         }
+
+         @Override
+         public void beforeRollback(Transaction tx) throws Exception {
+
+         }
+
+         @Override
+         public void afterRollback(Transaction tx) {
+            rollback.incrementAndGet();
+         }
+
+         @Override
+         public List<MessageReference> getRelatedMessageReferences() {
+            return null;
+         }
+
+         @Override
+         public List<MessageReference> getListOnConsumer(long consumerID) {
+            return null;
+         }
+      });
+      assertEquals(0, commit.get());
+      assertEquals(1, rollback.get());
+   }
+
    class FakeSM implements StorageManager {
 
       @Override
@@ -217,6 +334,16 @@ public class TransactionImplTest extends ActiveMQTestBase {
 
       }
 
+      @Override
+      public AbstractPersistedAddressSetting recoverAddressSettings(SimpleString address) {
+         return null;
+      }
+
+      @Override
+      public void asyncCommit(long txID) throws Exception {
+
+      }
+
       @Override
       public ArtemisCloseable closeableReadLock() {
          return () -> { };
@@ -247,6 +374,11 @@ public class TransactionImplTest extends ActiveMQTestBase {
 
       }
 
+      @Override
+      public void storeAddressSetting(PersistedAddressSettingJSON addressSetting) throws Exception {
+
+      }
+
       @Override
       public void stop(boolean ioCriticalError, boolean sendFailover) throws Exception {
 
@@ -453,17 +585,17 @@ public class TransactionImplTest extends ActiveMQTestBase {
       }
 
       @Override
-      public LargeServerMessage createLargeMessage() {
+      public LargeServerMessage createCoreLargeMessage() {
          return null;
       }
 
       @Override
-      public LargeServerMessage createLargeMessage(long id, Message message) throws Exception {
+      public LargeServerMessage createCoreLargeMessage(long id, Message message) throws Exception {
          return null;
       }
 
       @Override
-      public LargeServerMessage largeMessageCreated(long id, LargeServerMessage largeMessage) throws Exception {
+      public LargeServerMessage onLargeMessageCreate(long id, LargeServerMessage largeMessage) throws Exception {
          return null;
       }
 
@@ -524,8 +656,10 @@ public class TransactionImplTest extends ActiveMQTestBase {
                                                        Map<Long, QueueBindingInfo> queueInfos,
                                                        Map<SimpleString, List<Pair<byte[], Long>>> duplicateIDMap,
                                                        Set<Pair<Long, Long>> pendingLargeMessages,
+                                                       Set<Long> largeMessagesInFolder,
                                                        List<PageCountPending> pendingNonTXPageCounter,
-                                                       JournalLoader journalLoader) throws Exception {
+                                                       JournalLoader journalLoader,
+                                                       List<Consumer<RecordInfo>> extraLoaders) throws Exception {
          return null;
       }
 
@@ -576,18 +710,13 @@ public class TransactionImplTest extends ActiveMQTestBase {
 
       }
 
-      @Override
-      public void storeAddressSetting(PersistedAddressSetting addressSetting) throws Exception {
-
-      }
-
       @Override
       public void deleteAddressSetting(SimpleString addressMatch) throws Exception {
 
       }
 
       @Override
-      public List<PersistedAddressSetting> recoverAddressSettings() throws Exception {
+      public List<AbstractPersistedAddressSetting> recoverAddressSettings() throws Exception {
          return null;
       }
 
@@ -621,6 +750,32 @@ public class TransactionImplTest extends ActiveMQTestBase {
          return null;
       }
 
+      @Override
+      public void storeBridgeConfiguration(PersistedBridgeConfiguration persistedBridgeConfiguration) throws Exception {
+      }
+
+      @Override
+      public void deleteBridgeConfiguration(String bridgeName) throws Exception {
+      }
+
+      @Override
+      public List<PersistedBridgeConfiguration> recoverBridgeConfigurations() {
+         return null;
+      }
+
+      @Override
+      public void storeConnector(PersistedConnector persistedConnector) throws Exception {
+      }
+
+      @Override
+      public void deleteConnector(String connectorName) throws Exception {
+      }
+
+      @Override
+      public List<PersistedConnector> recoverConnectors() {
+         return null;
+      }
+
       @Override
       public void storeUser(PersistedUser persistedUser) throws Exception {
 
@@ -788,4 +943,8 @@ public class TransactionImplTest extends ActiveMQTestBase {
 
       }
    }
+
+   protected XidImpl newXID() {
+      return new XidImpl("xa1".getBytes(), 1, UUIDGenerator.getInstance().generateStringUUID().getBytes());
+   }
 }
