@@ -16,6 +16,11 @@
  */
 package org.apache.activemq.artemis.tests.integration.amqp;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import javax.jms.Connection;
 import javax.jms.ConnectionFactory;
 import javax.jms.Message;
@@ -23,6 +28,7 @@ import javax.jms.MessageConsumer;
 import javax.jms.MessageProducer;
 import javax.jms.Session;
 import javax.jms.TextMessage;
+import java.lang.invoke.MethodHandles;
 import java.util.HashMap;
 import java.util.UUID;
 import java.util.concurrent.TimeUnit;
@@ -47,12 +53,17 @@ import org.apache.activemq.transport.amqp.client.AmqpMessage;
 import org.apache.activemq.transport.amqp.client.AmqpReceiver;
 import org.apache.activemq.transport.amqp.client.AmqpSender;
 import org.apache.activemq.transport.amqp.client.AmqpSession;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
 
-   @Test(timeout = 60000)
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
+
+   @Test
+   @Timeout(60)
    public void testSendMessageThatIsAlreadyExpiredUsingAbsoluteTime() throws Exception {
       AmqpClient client = createAmqpClient();
       AmqpConnection connection = addConnection(client.connect());
@@ -82,7 +93,8 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       connection.close();
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testExpiryThroughTTL() throws Exception {
       AmqpClient client = createAmqpClient();
       AmqpConnection connection = addConnection(client.connect());
@@ -132,7 +144,7 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       receiverDLQ.flow(1);
       received = receiverDLQ.receive(5, TimeUnit.SECONDS);
 
-      assertNotNull("Should have read message from DLQ", received);
+      assertNotNull(received, "Should have read message from DLQ");
       assertEquals(0, received.getTimeToLive());
       assertNotNull(received);
       assertEquals("Value1", received.getApplicationProperty("key1"));
@@ -140,7 +152,8 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       connection.close();
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testRetryExpiry() throws Exception {
       AmqpClient client = createAmqpClient();
       AmqpConnection connection = addConnection(client.connect());
@@ -168,7 +181,7 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       final Queue dlqView = getProxyToQueue(getDeadLetterAddress());
 
       Wait.assertEquals(2, dlqView::getMessageCount);
-      Assert.assertEquals(2, dlqView.retryMessages(null));
+      assertEquals(2, dlqView.retryMessages(null));
       Wait.assertEquals(0, dlqView::getMessageCount);
       Wait.assertEquals(2, queueView::getMessageCount);
 
@@ -188,7 +201,8 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
 
    /** This test is validating a broker feature where the message copy through the DLQ will receive an annotation.
     *  It is also testing filter on that annotation. */
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testExpiryThroughTTLValidateAnnotation() throws Exception {
       AmqpClient client = createAmqpClient();
       AmqpConnection connection = addConnection(client.connect());
@@ -237,8 +251,8 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       AmqpReceiver receiverDLQ = session.createReceiver(getDeadLetterAddress(), "\"m.x-opt-ORIG-ADDRESS\"='" + getQueueName() + "'");
       receiverDLQ.flow(1);
       received = receiverDLQ.receive(5, TimeUnit.SECONDS);
-      Assert.assertNotNull(received);
-      Assert.assertEquals(getQueueName(), received.getMessageAnnotation("x-opt-ORIG-ADDRESS"));
+      assertNotNull(received);
+      assertEquals(getQueueName(), received.getMessageAnnotation("x-opt-ORIG-ADDRESS"));
       // close without accepting on purpose, it will issue a redelivery on the second filter
       receiverDLQ.close();
 
@@ -246,11 +260,11 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       receiverDLQ = session.createReceiver(getDeadLetterAddress(), "_AMQ_ORIG_ADDRESS='" + getQueueName() + "'");
       receiverDLQ.flow(1);
       received = receiverDLQ.receive(5, TimeUnit.SECONDS);
-      Assert.assertEquals(getQueueName(), received.getMessageAnnotation("x-opt-ORIG-ADDRESS"));
-      Assert.assertNotNull(received);
+      assertEquals(getQueueName(), received.getMessageAnnotation("x-opt-ORIG-ADDRESS"));
+      assertNotNull(received);
       received.accept();
 
-      assertNotNull("Should have read message from DLQ", received);
+      assertNotNull(received, "Should have read message from DLQ");
       assertEquals(0, received.getTimeToLive());
       assertNotNull(received);
       assertEquals("Value1", received.getApplicationProperty("key1"));
@@ -260,7 +274,8 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
 
    /** This test is validating a broker feature where the message copy through the DLQ will receive an annotation.
     *  It is also testing filter on that annotation. */
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testExpiryQpidJMS() throws Exception {
       ConnectionFactory factory = CFUtil.createConnectionFactory("AMQP", getBrokerAmqpConnectionURI().toString());
       Connection connection = factory.createConnection();
@@ -288,7 +303,7 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
          javax.jms.Queue queueDLQ = session.createQueue(getDeadLetterAddress());
          MessageConsumer receiverDLQ = session.createConsumer(queueDLQ, "\"m.x-opt-ORIG-ADDRESS\"='" + getQueueName() + "'");
          Message received = receiverDLQ.receive(5000);
-         Assert.assertNotNull(received);
+         assertNotNull(received);
          receiverDLQ.close();
       } finally {
          connection.close();
@@ -296,7 +311,8 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
 
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testSendMessageThatIsNotExpiredUsingAbsoluteTime() throws Exception {
       AmqpClient client = createAmqpClient();
       AmqpConnection connection = addConnection(client.connect());
@@ -327,7 +343,8 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       connection.close();
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testSendMessageThatIsExiredUsingAbsoluteTimeWithLongTTL() throws Exception {
       AmqpClient client = createAmqpClient();
       AmqpConnection connection = addConnection(client.connect());
@@ -360,7 +377,8 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       connection.close();
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testSendMessageThatIsExpiredUsingTTLWhenAbsoluteIsZero() throws Exception {
       AmqpClient client = createAmqpClient();
       AmqpConnection connection = addConnection(client.connect());
@@ -393,7 +411,8 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       connection.close();
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testSendMessageThatIsNotExpiredUsingAbsoluteTimeWithElspsedTTL() throws Exception {
       AmqpClient client = createAmqpClient();
       AmqpConnection connection = addConnection(client.connect());
@@ -426,7 +445,8 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       connection.close();
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testSendMessageThatIsNotExpiredUsingTimeToLive() throws Exception {
       AmqpClient client = createAmqpClient();
       AmqpConnection connection = addConnection(client.connect());
@@ -457,7 +477,8 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       connection.close();
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testSendMessageThenAllowToExpiredUsingTimeToLive() throws Exception {
       AmqpClient client = createAmqpClient();
       AmqpConnection connection = addConnection(client.connect());
@@ -490,12 +511,14 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       connection.close();
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testExpiredMessageLandsInDLQ() throws Throwable {
       internalSendExpiry(false);
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testExpiredMessageLandsInDLQAndExistsAfterRestart() throws Throwable {
       internalSendExpiry(true);
    }
@@ -518,7 +541,7 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
          sender.send(message);
 
          Queue dlq = getProxyToQueue(getDeadLetterAddress());
-         assertTrue("Message not movied to DLQ", Wait.waitFor(() -> dlq.getMessageCount() > 0, 7000, 500));
+         assertTrue(Wait.waitFor(() -> dlq.getMessageCount() > 0, 7000, 500), "Message not movied to DLQ");
 
          connection.close();
 
@@ -544,10 +567,11 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       }
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testExpirationAfterDivert() throws Throwable {
       final String FORWARDING_ADDRESS = RandomUtil.randomString();
-      server.createQueue(new QueueConfiguration(FORWARDING_ADDRESS).setRoutingType(RoutingType.ANYCAST));
+      server.createQueue(QueueConfiguration.of(FORWARDING_ADDRESS).setRoutingType(RoutingType.ANYCAST));
       server.deployDivert(new DivertConfiguration()
                              .setName(RandomUtil.randomString())
                              .setAddress(getQueueName())
@@ -568,13 +592,17 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
          message.setText("Test-Message");
          message.setDeliveryAnnotation("shouldDisappear", 1);
          message.setMessageAnnotation("x-opt-routing-type", (byte) 1);
+
+         logger.debug("*******************************************************************************************************************************");
+         logger.debug("message being sent {}", message);
          sender.send(message);
+         logger.debug("*******************************************************************************************************************************");
 
          Queue forward = getProxyToQueue(FORWARDING_ADDRESS);
-         assertTrue("Message not diverted", Wait.waitFor(() -> forward.getMessageCount() > 0, 7000, 500));
+         assertTrue(Wait.waitFor(() -> forward.getMessageCount() > 0, 7000, 500), "Message not diverted");
 
          Queue dlq = getProxyToQueue(getDeadLetterAddress());
-         assertTrue("Message not moved to DLQ", Wait.waitFor(() -> dlq.getMessageCount() > 0, 7000, 500));
+         assertTrue(Wait.waitFor(() -> dlq.getMessageCount() > 0, 7000, 500), "Message not moved to DLQ");
 
          connection.close();
 
@@ -605,7 +633,8 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       }
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testDLQdMessageCanBeRedeliveredMultipleTimes() throws Throwable {
       AmqpClient client = createAmqpClient();
       AmqpConnection connection = client.connect();
@@ -624,7 +653,7 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
          sender.send(message);
 
          Queue dlqView = getProxyToQueue(getDeadLetterAddress());
-         assertTrue("Message not movied to DLQ", Wait.waitFor(() -> dlqView.getMessageCount() > 0, 7000, 200));
+         assertTrue(Wait.waitFor(() -> dlqView.getMessageCount() > 0, 7000, 200), "Message not movied to DLQ");
 
          // Read and Modify the message for redelivery repeatedly
          AmqpReceiver receiver = session.createReceiver(getDeadLetterAddress());
@@ -656,12 +685,14 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       }
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testExpireThorughAddressSettings() throws Exception {
       testExpireThorughAddressSettings(false);
    }
 
-   @Test(timeout = 60000)
+   @Test
+   @Timeout(60)
    public void testExpireThorughAddressSettingsRebootServer() throws Exception {
       testExpireThorughAddressSettings(true);
    }
@@ -674,8 +705,8 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       addressSettings.setAddressFullMessagePolicy(AddressFullMessagePolicy.PAGE);
       addressSettings.setAutoCreateQueues(isAutoCreateQueues());
       addressSettings.setAutoCreateAddresses(isAutoCreateAddresses());
-      addressSettings.setDeadLetterAddress(SimpleString.toSimpleString(getDeadLetterAddress()));
-      addressSettings.setExpiryAddress(SimpleString.toSimpleString(getDeadLetterAddress()));
+      addressSettings.setDeadLetterAddress(SimpleString.of(getDeadLetterAddress()));
+      addressSettings.setExpiryAddress(SimpleString.of(getDeadLetterAddress()));
       addressSettings.setExpiryDelay(1000L);
 
       server.getAddressSettingsRepository().clear();
@@ -715,9 +746,9 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       try (LinkedListIterator<MessageReference> referenceIterator = serverQueue.iterator()) {
          while (referenceIterator.hasNext()) {
             MessageReference ref = referenceIterator.next();
-            Assert.assertEquals(ref.getMessage().getExpiration(), ref.getMessage().toCore().getExpiration());
-            Assert.assertTrue(ref.getMessage().getExpiration() > 0);
-            Assert.assertTrue(ref.getMessage().toCore().getExpiration() > 0);
+            assertEquals(ref.getMessage().getExpiration(), ref.getMessage().toCore().getExpiration());
+            assertTrue(ref.getMessage().getExpiration() > 0);
+            assertTrue(ref.getMessage().toCore().getExpiration() > 0);
          }
       }
 
@@ -735,8 +766,8 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
       addressSettings.setAddressFullMessagePolicy(AddressFullMessagePolicy.PAGE);
       addressSettings.setAutoCreateQueues(isAutoCreateQueues());
       addressSettings.setAutoCreateAddresses(isAutoCreateAddresses());
-      addressSettings.setDeadLetterAddress(SimpleString.toSimpleString(getDeadLetterAddress()));
-      addressSettings.setExpiryAddress(SimpleString.toSimpleString(getDeadLetterAddress()));
+      addressSettings.setDeadLetterAddress(SimpleString.of(getDeadLetterAddress()));
+      addressSettings.setExpiryAddress(SimpleString.of(getDeadLetterAddress()));
       addressSettings.setExpiryDelay(1000L);
 
       server.getAddressSettingsRepository().clear();
@@ -777,7 +808,7 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
          dataSet.put(idUsed, ref.getMessage().getExpiration());
       }
 
-      Assert.assertEquals(2, count);
+      assertEquals(2, count);
       linkedListIterator.close();
 
       server.stop();
@@ -799,9 +830,9 @@ public class AmqpExpiredMessageTest extends AmqpClientTestSupport {
          String idUsed = ref.getMessage().getStringProperty("id");
          long originalExpiration = dataSet.get(idUsed);
          System.out.println("original Expiration = " + originalExpiration + " while this expiration = " + ref.getMessage().getExpiration());
-         Assert.assertEquals(originalExpiration, ref.getMessage().getExpiration());
+         assertEquals(originalExpiration, ref.getMessage().getExpiration());
       }
-      Assert.assertEquals(2, count);
+      assertEquals(2, count);
       linkedListIterator.close();
 
 
