@@ -16,6 +16,13 @@
  */
 package org.apache.activemq.artemis.tests.integration.amqp.connect;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import javax.jms.Connection;
 import javax.jms.ConnectionFactory;
 import javax.jms.DeliveryMode;
@@ -38,6 +45,7 @@ import java.util.concurrent.atomic.AtomicInteger;
 import org.apache.activemq.artemis.api.core.QueueConfiguration;
 import org.apache.activemq.artemis.api.core.RoutingType;
 import org.apache.activemq.artemis.api.core.SimpleString;
+import org.apache.activemq.artemis.api.core.management.SimpleManagement;
 import org.apache.activemq.artemis.core.config.amqpBrokerConnectivity.AMQPBrokerConnectConfiguration;
 import org.apache.activemq.artemis.core.config.amqpBrokerConnectivity.AMQPBrokerConnectionAddressType;
 import org.apache.activemq.artemis.core.config.amqpBrokerConnectivity.AMQPMirrorBrokerConnectionElement;
@@ -61,10 +69,9 @@ import org.apache.activemq.transport.amqp.client.AmqpMessage;
 import org.apache.activemq.transport.amqp.client.AmqpReceiver;
 import org.apache.activemq.transport.amqp.client.AmqpSender;
 import org.apache.activemq.transport.amqp.client.AmqpSession;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -78,21 +85,27 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
 
    ActiveMQServer server_2;
 
+   private AssertionLoggerHandler loggerHandler;
 
-   @Before
+   @BeforeEach
    public void startLogging() {
-      AssertionLoggerHandler.startCapture();
+      loggerHandler = new AssertionLoggerHandler();
    }
 
-   @After
-   public void stopLogging() {
+   @AfterEach
+   public void stopLogging() throws Exception {
       try {
-         Assert.assertFalse(AssertionLoggerHandler.findText("AMQ222214"));
+         assertFalse(loggerHandler.findText("AMQ222214"));
       } finally {
-         AssertionLoggerHandler.stopCapture();
+         loggerHandler.close();
       }
    }
 
+   @Override
+   protected String getConfiguredProtocols() {
+      return "AMQP,OPENWIRE,CORE";
+   }
+
    @Override
    protected ActiveMQServer createServer() throws Exception {
       return createServer(AMQP_PORT, false);
@@ -112,14 +125,14 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       server_2.start();
 
       server_2.addAddressInfo(new AddressInfo("sometest").setAutoCreated(false));
-      server_2.createQueue(new QueueConfiguration("sometest").setDurable(true));
+      server_2.createQueue(QueueConfiguration.of("sometest").setDurable(true));
 
       Wait.assertTrue(() -> server_2.locateQueue("sometest") != null);
 
       server_2.stop();
 
       server.start();
-      Assert.assertTrue(server.locateQueue("sometest") == null);
+      assertTrue(server.locateQueue("sometest") == null);
       Wait.assertTrue(server::isActive);
       server_2.start();
       // if this does not succeed the catch up did not arrive at the other server
@@ -144,7 +157,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       server_2.start();
 
       server_2.addAddressInfo(new AddressInfo("sometest").setAutoCreated(false));
-      server_2.createQueue(new QueueConfiguration("sometest").setDurable(true));
+      server_2.createQueue(QueueConfiguration.of("sometest").setDurable(true));
 
 
       Wait.assertTrue(() -> server_2.locateQueue("sometest") != null);
@@ -152,25 +165,24 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
 
       Wait.waitFor(() -> server_2.locateQueue("$ACTIVEMQ_ARTEMIS_MIRROR_test") != null);
       Queue mirrorQueue = server_2.locateQueue("$ACTIVEMQ_ARTEMIS_MIRROR_test");
-      Assert.assertNotNull(mirrorQueue);
+      assertNotNull(mirrorQueue);
 
 
-      AssertionLoggerHandler.startCapture();
-      runAfter(() -> AssertionLoggerHandler.stopCapture());
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
 
-      // Adding some PostAck event that will never be found on the target for an expiry
-      org.apache.activemq.artemis.api.core.Message message = AMQPMirrorMessageFactory.createMessage(mirrorQueue.getAddress().toString(), SimpleString.toSimpleString("sometest"), SimpleString.toSimpleString("sometest"), AMQPMirrorControllerSource.POST_ACK, "0000", 3333L, AckReason.EXPIRED).setDurable(true);
-      message.setMessageID(server_2.getStorageManager().generateID());
-      server_2.getPostOffice().route(message, false);
+         // Adding some PostAck event that will never be found on the target for an expiry
+         org.apache.activemq.artemis.api.core.Message message = AMQPMirrorMessageFactory.createMessage(mirrorQueue.getAddress().toString(), SimpleString.of("sometest"), SimpleString.of("sometest"), AMQPMirrorControllerSource.POST_ACK, "0000", 3333L, AckReason.EXPIRED).setDurable(true);
+         message.setMessageID(server_2.getStorageManager().generateID());
+         server_2.getPostOffice().route(message, false);
 
-      // Adding some PostAck event that will never be found on the target for a regular ack
-      message = AMQPMirrorMessageFactory.createMessage(mirrorQueue.getAddress().toString(), SimpleString.toSimpleString("sometest"), SimpleString.toSimpleString("sometest"), AMQPMirrorControllerSource.POST_ACK, "0000", 3334L, AckReason.NORMAL).setDurable(true);
-      message.setMessageID(server_2.getStorageManager().generateID());
-      server_2.getPostOffice().route(message, false);
+         // Adding some PostAck event that will never be found on the target for a regular ack
+         message = AMQPMirrorMessageFactory.createMessage(mirrorQueue.getAddress().toString(), SimpleString.of("sometest"), SimpleString.of("sometest"), AMQPMirrorControllerSource.POST_ACK, "0000", 3334L, AckReason.NORMAL).setDurable(true);
+         message.setMessageID(server_2.getStorageManager().generateID());
+         server_2.getPostOffice().route(message, false);
 
-      Wait.assertEquals(0L, mirrorQueue::getMessageCount, 2000, 100);
-      Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224041"));
-      AssertionLoggerHandler.stopCapture();
+         Wait.assertEquals(0L, mirrorQueue::getMessageCount, 2000, 100);
+         assertFalse(loggerHandler.findText("AMQ224041"));
+      }
 
       server_2.stop();
       server.stop();
@@ -193,7 +205,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       SimpleString queueName = RandomUtil.randomSimpleString();
 
       server_2.addAddressInfo(new AddressInfo(queueName).setAutoCreated(false));
-      server_2.createQueue(new QueueConfiguration(queueName).setDurable(true));
+      server_2.createQueue(QueueConfiguration.of(queueName).setDurable(true));
 
       Wait.assertTrue(() -> server_2.locateQueue(queueName) != null);
       Wait.assertTrue(() -> server.locateQueue(queueName) != null);
@@ -203,7 +215,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       Wait.assertTrue(() -> server_2.locateQueue(queueName) == null);
       Thread.sleep(100);
 
-      Assert.assertTrue("Queue was removed when it was configured to not remove it", server.locateQueue(queueName) != null);
+      assertTrue(server.locateQueue(queueName) != null, "Queue was removed when it was configured to not remove it");
 
       server_2.stop();
       server.stop();
@@ -223,7 +235,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
    private void doSendCreateQueueTestImpl(boolean sendCreate) throws Exception {
       server.start();
 
-      final SimpleString ADDRESS_NAME = SimpleString.toSimpleString("address");
+      final SimpleString ADDRESS_NAME = SimpleString.of("address");
 
       server_2 = createServer(AMQP_PORT_2, false);
 
@@ -242,15 +254,15 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       Wait.assertTrue(server::isActive);
 
       server_2.addAddressInfo(new AddressInfo(ADDRESS_NAME).addRoutingType(RoutingType.ANYCAST));
-      server_2.createQueue(new QueueConfiguration(ADDRESS_NAME).setDurable(true).setAddress(ADDRESS_NAME));
+      server_2.createQueue(QueueConfiguration.of(ADDRESS_NAME).setDurable(true).setAddress(ADDRESS_NAME));
 
       if (sendCreate) {
          Wait.assertTrue(() -> server.locateQueue(ADDRESS_NAME) != null);
          Wait.assertTrue(() -> server.getAddressInfo(ADDRESS_NAME) != null);
       } else {
          Thread.sleep(250); // things are asynchronous, I need to wait some time to make sure things are transferred over
-         Assert.assertTrue(server.locateQueue(ADDRESS_NAME) == null);
-         Assert.assertTrue(server.getAddressInfo(ADDRESS_NAME) == null);
+         assertTrue(server.locateQueue(ADDRESS_NAME) == null);
+         assertTrue(server.getAddressInfo(ADDRESS_NAME) == null);
       }
       server_2.stop();
       server.stop();
@@ -262,7 +274,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       server.setIdentity("Server1");
       server.addAddressInfo(new AddressInfo("sometest").setAutoCreated(false).addRoutingType(RoutingType.MULTICAST));
       // This queue will disappear from the source, so it should go
-      server.createQueue(new QueueConfiguration("ToBeGone").setDurable(true).setRoutingType(RoutingType.MULTICAST));
+      server.createQueue(QueueConfiguration.of("ToBeGone").setDurable(true).setRoutingType(RoutingType.MULTICAST));
       server.stop();
 
       server_2 = createServer(AMQP_PORT_2, false);
@@ -275,7 +287,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       server_2.start();
 
       server_2.addAddressInfo(new AddressInfo("sometest").setAutoCreated(false).addRoutingType(RoutingType.MULTICAST));
-      server_2.createQueue(new QueueConfiguration("sometest").setDurable(true).setRoutingType(RoutingType.MULTICAST));
+      server_2.createQueue(QueueConfiguration.of("sometest").setDurable(true).setRoutingType(RoutingType.MULTICAST));
 
       Wait.assertTrue(() -> server_2.locateQueue("sometest") != null);
 
@@ -289,8 +301,8 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       server_2.getConfiguration().addAMQPConnection(amqpConnection);
 
       server.start();
-      Assert.assertTrue(server.locateQueue("sometest") == null);
-      Assert.assertTrue(server.locateQueue("ToBeGone") != null);
+      assertTrue(server.locateQueue("sometest") == null);
+      assertTrue(server.locateQueue("ToBeGone") != null);
       Wait.assertTrue(server::isActive);
       server_2.start();
       // if this does not succeed the catch up did not arrive at the other server
@@ -317,7 +329,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       server_2.start();
 
       server_2.addAddressInfo(new AddressInfo("sometest").setAutoCreated(false).addRoutingType(RoutingType.MULTICAST));
-      server_2.createQueue(new QueueConfiguration("sometest").setDurable(true).setRoutingType(RoutingType.MULTICAST));
+      server_2.createQueue(QueueConfiguration.of("sometest").setDurable(true).setRoutingType(RoutingType.MULTICAST));
 
       Wait.assertTrue(() -> server_2.locateQueue("sometest") != null);
 
@@ -331,7 +343,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       server_2.getConfiguration().addAMQPConnection(amqpConnection);
 
       server.start();
-      Assert.assertTrue(server.locateQueue("sometest") == null);
+      assertTrue(server.locateQueue("sometest") == null);
       Wait.assertTrue(server::isActive);
       server_2.start();
       // if this does not succeed the catch up did not arrive at the other server
@@ -422,9 +434,9 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
 
       // We create the address to avoid auto delete on the queue
       server_2.addAddressInfo(new AddressInfo(getQueueName()).addRoutingType(RoutingType.ANYCAST).setAutoCreated(false));
-      server_2.createQueue(new QueueConfiguration(getQueueName()).setRoutingType(RoutingType.ANYCAST).setAddress(getQueueName()).setAutoCreated(false));
+      server_2.createQueue(QueueConfiguration.of(getQueueName()).setRoutingType(RoutingType.ANYCAST).setAddress(getQueueName()).setAutoCreated(false));
 
-      Assert.assertFalse(AssertionLoggerHandler.findText("AMQ222214"));
+      assertFalse(loggerHandler.findText("AMQ222214"));
 
       // Get the Queue View early to avoid racing the delivery.
       final Queue queueView = locateQueue(server_2, getQueueName());
@@ -461,10 +473,10 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
          for (int i = 0; i < NUMBER_OF_MESSAGES; i++) {
             AmqpMessage received = receiver.receive(5, TimeUnit.SECONDS);
             assertNotNull(received);
-            Assert.assertEquals(getText(true, i), received.getText());
-            Assert.assertNull(received.getDeliveryAnnotation("gone"));
+            assertEquals(getText(true, i), received.getText());
+            assertNull(received.getDeliveryAnnotation("gone"));
          }
-         Assert.assertNull(receiver.receiveNoWait());
+         assertNull(receiver.receiveNoWait());
 
          connection.close();
       }
@@ -492,9 +504,9 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
 
       // We create the address to avoid auto delete on the queue
       server_2.addAddressInfo(new AddressInfo(getQueueName()).addRoutingType(RoutingType.ANYCAST).setAutoCreated(false));
-      server_2.createQueue(new QueueConfiguration(getQueueName()).setRoutingType(RoutingType.ANYCAST).setAddress(getQueueName()).setAutoCreated(false));
+      server_2.createQueue(QueueConfiguration.of(getQueueName()).setRoutingType(RoutingType.ANYCAST).setAddress(getQueueName()).setAutoCreated(false));
 
-      Assert.assertFalse(AssertionLoggerHandler.findText("AMQ222214"));
+      assertFalse(loggerHandler.findText("AMQ222214"));
 
       { // sender
          AmqpClient client = new AmqpClient(new URI("tcp://localhost:" + AMQP_PORT_2), null, null);
@@ -524,10 +536,10 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
          for (int i = 0; i < NUMBER_OF_MESSAGES; i++) {
             AmqpMessage received = receiver.receive(5, TimeUnit.SECONDS);
             assertNotNull(received);
-            Assert.assertEquals(getText(false, i), received.getText());
-            Assert.assertNull(received.getDeliveryAnnotation("gone"));
+            assertEquals(getText(false, i), received.getText());
+            assertNull(received.getDeliveryAnnotation("gone"));
          }
-         Assert.assertNull(receiver.receiveNoWait());
+         assertNull(receiver.receiveNoWait());
 
          connection.close();
       }
@@ -565,7 +577,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
          }
 
          // Check nothing was added to SnF queue
-         Assert.assertEquals(0, server_2.locateQueue(replica.getMirrorSNF()).getMessagesAdded());
+         assertEquals(0, server_2.locateQueue(replica.getMirrorSNF()).getMessagesAdded());
 
          // Send to replicated address
          try (MessageProducer producer = session.createProducer(session.createQueue(REPLICATED))) {
@@ -576,9 +588,12 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
          }
 
          // Check some messages were sent to SnF queue
-         Assert.assertTrue(server_2.locateQueue(replica.getMirrorSNF()).getMessagesAdded() > 0);
+         assertTrue(server_2.locateQueue(replica.getMirrorSNF()).getMessagesAdded() > 0);
       }
 
+      SimpleManagement simpleManagement = new SimpleManagement("tcp://localhost:" + AMQP_PORT_2, null, null);
+      Wait.assertEquals(0, () -> simpleManagement.getMessageCountOnQueue("$ACTIVEMQ_ARTEMIS_MIRROR_mirror-source"), 5000);
+
       try (Connection connection = CFUtil.createConnectionFactory("AMQP", "tcp://localhost:" + AMQP_PORT).createConnection()) {
          connection.start();
 
@@ -586,12 +601,12 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
 
          try (MessageConsumer consumer = session.createConsumer(session.createQueue(REPLICATED))) {
             Message message = consumer.receive(3000);
-            Assert.assertNotNull(message);
-            Assert.assertEquals(MSG, message.getBody(String.class));
+            assertNotNull(message);
+            assertEquals(MSG, message.getBody(String.class));
          }
 
          try (MessageConsumer consumer = session.createConsumer(session.createQueue(NON_REPLICATED))) {
-            Assert.assertNull(consumer.receiveNoWait());
+            assertNull(consumer.receiveNoWait());
          }
       }
 
@@ -625,7 +640,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
 
       // We create the address to avoid auto delete on the queue
       server_2.addAddressInfo(new AddressInfo(getQueueName()).addRoutingType(RoutingType.ANYCAST).setAutoCreated(false));
-      server_2.createQueue(new QueueConfiguration(getQueueName()).setRoutingType(RoutingType.ANYCAST).setAddress(getQueueName()).setAutoCreated(false));
+      server_2.createQueue(QueueConfiguration.of(getQueueName()).setRoutingType(RoutingType.ANYCAST).setAddress(getQueueName()).setAutoCreated(false));
 
       int NUMBER_OF_MESSAGES = 200;
 
@@ -704,7 +719,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
 
       // We create the address to avoid auto delete on the queue
       server_2.addAddressInfo(new AddressInfo(getQueueName()).addRoutingType(RoutingType.ANYCAST).setAutoCreated(false));
-      server_2.createQueue(new QueueConfiguration(getQueueName()).setRoutingType(RoutingType.ANYCAST).setAddress(getQueueName()).setAutoCreated(false));
+      server_2.createQueue(QueueConfiguration.of(getQueueName()).setRoutingType(RoutingType.ANYCAST).setAddress(getQueueName()).setAutoCreated(false));
 
       ConnectionFactory factory = CFUtil.createConnectionFactory("AMQP", "tcp://localhost:" + AMQP_PORT_2);
       Connection connection = factory.createConnection();
@@ -724,7 +739,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
          queueOnServer2.getPagingStore().startPaging();
       }
 
-      Assert.assertFalse(AssertionLoggerHandler.findText("AMQ222214"));
+      assertFalse(loggerHandler.findText("AMQ222214"));
 
 
       for (int i = 0; i < NUMBER_OF_MESSAGES; i++) {
@@ -733,7 +748,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
          producer.send(message);
       }
 
-      Assert.assertFalse(AssertionLoggerHandler.findText("AMQ222214"));
+      assertFalse(loggerHandler.findText("AMQ222214"));
 
       Queue queueOnServer1;
       if (deferredStart) {
@@ -749,7 +764,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       }
       Queue snfreplica = server_2.locateQueue(replica.getMirrorSNF());
 
-      Assert.assertNotNull(snfreplica);
+      assertNotNull(snfreplica);
 
       Wait.assertEquals(0, snfreplica::getMessageCount);
 
@@ -765,7 +780,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
          server_2.startBrokerConnection(brokerConnectionName);
       }
 
-      Assert.assertSame(snfreplica, server_2.locateQueue(replica.getMirrorSNF()));
+      assertSame(snfreplica, server_2.locateQueue(replica.getMirrorSNF()));
 
       if (pagingTarget) {
          assertTrue(queueOnServer1.getPagingStore().isPaging());
@@ -844,8 +859,8 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
    }
 
    public Queue locateQueue(ActiveMQServer server, String queueName) throws Exception {
-      Assert.assertNotNull(queueName);
-      Assert.assertNotNull(server);
+      assertNotNull(queueName);
+      assertNotNull(server);
       Wait.waitFor(() -> server.locateQueue(queueName) != null);
       return server.locateQueue(queueName);
    }
@@ -932,12 +947,12 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       Wait.assertEquals(0L, replica1Queue.getPagingStore()::getAddressSize, 1000, 100);
 
       if (pagingTarget) {
-         Assert.assertTrue(queue_server_1.getPagingStore().isPaging());
-         Assert.assertTrue(queue_server_3.getPagingStore().isPaging());
+         assertTrue(queue_server_1.getPagingStore().isPaging());
+         assertTrue(queue_server_3.getPagingStore().isPaging());
       }
 
       if (pagingSource) {
-         Assert.assertTrue(queue_server_2.getPagingStore().isPaging());
+         assertTrue(queue_server_2.getPagingStore().isPaging());
       }
 
       consumeMessages(largeMessage, 0, NUMBER_OF_MESSAGES / 2 - 1, AMQP_PORT_2, false);
@@ -1071,21 +1086,21 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       MessageConsumer consumer = sess.createConsumer(sess.createQueue(getQueueName()));
       for (int i = START_ID; i <= LAST_ID; i++) {
          Message message = consumer.receive(3000);
-         Assert.assertNotNull(message);
+         assertNotNull(message);
          Integer id = message.getIntProperty("i");
-         Assert.assertNotNull(id);
-         Assert.assertTrue(idsReceived.add(id));
+         assertNotNull(id);
+         assertTrue(idsReceived.add(id));
       }
 
       if (assertNull) {
-         Assert.assertNull(consumer.receiveNoWait());
+         assertNull(consumer.receiveNoWait());
       }
 
       for (int i = START_ID; i <= LAST_ID; i++) {
-         Assert.assertTrue(idsReceived.remove(i));
+         assertTrue(idsReceived.remove(i));
       }
 
-      Assert.assertTrue(idsReceived.isEmpty());
+      assertTrue(idsReceived.isEmpty());
       conn.close();
    }
 
@@ -1109,21 +1124,21 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
       MessageConsumer consumer = sess.createDurableConsumer(topic, subscriptionName);
       for (int i = START_ID; i <= LAST_ID; i++) {
          Message message = consumer.receive(3000);
-         Assert.assertNotNull(message);
+         assertNotNull(message);
          Integer id = message.getIntProperty("i");
-         Assert.assertNotNull(id);
-         Assert.assertTrue(idsReceived.add(id));
+         assertNotNull(id);
+         assertTrue(idsReceived.add(id));
       }
 
       if (assertNull) {
-         Assert.assertNull(consumer.receiveNoWait());
+         assertNull(consumer.receiveNoWait());
       }
 
       for (int i = START_ID; i <= LAST_ID; i++) {
-         Assert.assertTrue(idsReceived.remove(i));
+         assertTrue(idsReceived.remove(i));
       }
 
-      Assert.assertTrue(idsReceived.isEmpty());
+      assertTrue(idsReceived.isEmpty());
       conn.close();
    }
 
@@ -1202,13 +1217,13 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
 
       Queue subs0Server1 = locateQueue(server, subs0Name);
       Queue subs1Server1 = locateQueue(server, subs1Name);
-      Assert.assertNotNull(subs0Server1);
-      Assert.assertNotNull(subs1Server1);
+      assertNotNull(subs0Server1);
+      assertNotNull(subs1Server1);
 
       Queue subs0Server2 = locateQueue(server_2, subs0Name);
       Queue subs1Server2 = locateQueue(server_2, subs1Name);
-      Assert.assertNotNull(subs0Server2);
-      Assert.assertNotNull(subs1Server2);
+      assertNotNull(subs0Server2);
+      assertNotNull(subs1Server2);
 
       if (pagingTarget) {
          subs0Server1.getPagingStore().startPaging();
@@ -1230,7 +1245,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
 
       Queue snfreplica = server_2.locateQueue(replica.getMirrorSNF());
 
-      Assert.assertNotNull(snfreplica);
+      assertNotNull(snfreplica);
 
       Wait.assertEquals(0, snfreplica::getMessageCount);
 
@@ -1247,7 +1262,7 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
          server_2.startBrokerConnection(brokerConnectionName);
       }
 
-      Assert.assertSame(snfreplica, server_2.locateQueue(replica.getMirrorSNF()));
+      assertSame(snfreplica, server_2.locateQueue(replica.getMirrorSNF()));
 
       if (pagingTarget) {
          assertTrue(subs0Server1.getPagingStore().isPaging());
@@ -1279,8 +1294,8 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
          }
       }
 
-      Assert.assertTrue(done.await(60, TimeUnit.SECONDS));
-      Assert.assertEquals(0, errors.get());
+      assertTrue(done.await(60, TimeUnit.SECONDS));
+      assertEquals(0, errors.get());
 
       // Replica is async, so we need to wait acks to arrive before we finish consuming there
       Wait.assertEquals(0, snfreplica::getMessageCount);
@@ -1297,5 +1312,154 @@ public class AMQPReplicaTest extends AmqpClientTestSupport {
    }
 
 
+   @Test
+   public void testSimpleReplicaTX() throws Exception {
 
-}
+      String brokerConnectionName = "brokerConnectionName:" + UUIDGenerator.getInstance().generateStringUUID();
+      server.setIdentity("targetServer");
+      server.start();
+      server_2 = createServer(AMQP_PORT_2, false);
+      server_2.setIdentity("server_2");
+      server_2.getConfiguration().setName("thisone");
+
+      AMQPBrokerConnectConfiguration amqpConnection = new AMQPBrokerConnectConfiguration(brokerConnectionName, "tcp://localhost:" + AMQP_PORT).setReconnectAttempts(-1).setRetryInterval(100);
+      AMQPMirrorBrokerConnectionElement replica = new AMQPMirrorBrokerConnectionElement().setMessageAcknowledgements(true).setDurable(true);
+      replica.setName("theReplica");
+      amqpConnection.addElement(replica);
+      server_2.getConfiguration().addAMQPConnection(amqpConnection);
+      server_2.getConfiguration().setName("server_2");
+
+      int NUMBER_OF_MESSAGES = 10;
+
+      server_2.start();
+      Wait.assertTrue(server_2::isStarted);
+
+      // We create the address to avoid auto delete on the queue
+      server_2.addAddressInfo(new AddressInfo(getQueueName()).addRoutingType(RoutingType.ANYCAST).setAutoCreated(false));
+      server_2.createQueue(QueueConfiguration.of(getQueueName()).setRoutingType(RoutingType.ANYCAST).setAddress(getQueueName()).setAutoCreated(false));
+
+      ConnectionFactory factory = CFUtil.createConnectionFactory("AMQP", "tcp://localhost:" + AMQP_PORT_2);
+      Connection connection = factory.createConnection();
+      Session session = connection.createSession(true, Session.SESSION_TRANSACTED);
+      MessageProducer producer = session.createProducer(session.createQueue(getQueueName()));
+
+      for (int i = 0; i < NUMBER_OF_MESSAGES; i++) {
+         Message message = session.createTextMessage(getText(true, i));
+         message.setIntProperty("i", i);
+         producer.send(message);
+      }
+      session.commit();
+
+      Queue queueOnServer1 = locateQueue(server, getQueueName());
+      Queue snfreplica = server_2.locateQueue(replica.getMirrorSNF());
+      assertNotNull(snfreplica);
+
+      Wait.assertEquals(0, snfreplica::getMessageCount);
+
+      Wait.assertEquals(NUMBER_OF_MESSAGES, queueOnServer1::getMessageCount, 2000);
+      Queue queueOnServer2 = locateQueue(server_2, getQueueName());
+      Wait.assertEquals(NUMBER_OF_MESSAGES, queueOnServer1::getMessageCount);
+      Wait.assertEquals(NUMBER_OF_MESSAGES, queueOnServer2::getMessageCount);
+
+      MessageConsumer consumer = session.createConsumer(session.createQueue(getQueueName()));
+      connection.start();
+
+      for (int i = 0; i < NUMBER_OF_MESSAGES; i++) {
+         Message m = consumer.receive(1000);
+         assertNotNull(m);
+      }
+      session.commit();
+
+      Wait.assertEquals(0, snfreplica::getMessageCount);
+      Wait.assertEquals(0, queueOnServer1::getMessageCount);
+      Wait.assertEquals(0, queueOnServer2::getMessageCount);
+   }
+
+
+   @Test
+   public void testCalculationSize() throws Exception {
+      testCalculationSize(false);
+   }
+
+   @Test
+   public void testCalculationSizeRestartSource() throws Exception {
+      testCalculationSize(true);
+   }
+
+   private void testCalculationSize(boolean restartSource) throws Exception {
+      String brokerConnectionName = "brokerConnectionName:" + UUIDGenerator.getInstance().generateStringUUID();
+      server.setIdentity("targetServer");
+      server.start();
+
+      server_2 = createServer(AMQP_PORT_2, false);
+      server_2.setIdentity("server_2");
+      server_2.getConfiguration().setName("server2");
+
+      AMQPBrokerConnectConfiguration amqpConnection = new AMQPBrokerConnectConfiguration(brokerConnectionName, "tcp://localhost:" + AMQP_PORT).setReconnectAttempts(-1).setRetryInterval(100);
+      AMQPMirrorBrokerConnectionElement replica = new AMQPMirrorBrokerConnectionElement().setMessageAcknowledgements(true).setDurable(true);
+      replica.setName("theReplica");
+      amqpConnection.addElement(replica);
+      server_2.getConfiguration().addAMQPConnection(amqpConnection);
+      server_2.getConfiguration().setName("server_2");
+
+      int NUMBER_OF_MESSAGES = 1;
+
+      server_2.start();
+      Wait.assertTrue(server_2::isStarted);
+
+      // We create the address to avoid auto delete on the queue
+      server_2.addAddressInfo(new AddressInfo(getQueueName()).addRoutingType(RoutingType.ANYCAST).setAutoCreated(false));
+      server_2.createQueue(new QueueConfiguration(getQueueName()).setRoutingType(RoutingType.ANYCAST).setAddress(getQueueName()).setAutoCreated(false));
+
+      ConnectionFactory factory = CFUtil.createConnectionFactory("AMQP", "tcp://localhost:" + AMQP_PORT_2);
+      Connection connection = factory.createConnection();
+      Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
+      MessageProducer producer = session.createProducer(session.createQueue(getQueueName()));
+
+      Queue queueOnServer2 = locateQueue(server_2, getQueueName());
+
+      server.stop();
+
+      for (int i = 0; i < NUMBER_OF_MESSAGES; i++) {
+         Message message = session.createTextMessage(getText(false, i));
+         message.setIntProperty("i", i);
+         producer.send(message);
+      }
+
+      if (restartSource) {
+         server_2.stop();
+         // Have to disable queueCreation, otherwise once the server restarts more data will be added to the SNF queue what will messup with the Assertions.
+         // The idea is to make sure the reference counting between two addresses will act correctly
+         replica.setQueueCreation(false).setQueueRemoval(false);
+         server_2.start();
+      }
+
+      Queue snfreplica = server_2.locateQueue(replica.getMirrorSNF());
+      assertNotNull(snfreplica);
+
+      logger.info("Size on queueOnServer2:: {}", queueOnServer2.getPagingStore().getAddressSize());
+      logger.info("Size on SNF:: {}", snfreplica.getPagingStore().getAddressSize());
+
+      Wait.assertTrue(() -> queueOnServer2.getPagingStore().getAddressSize() == snfreplica.getPagingStore().getAddressSize(), 5000);
+      Wait.assertTrue(() -> queueOnServer2.getPagingStore().getAddressElements() == snfreplica.getPagingStore().getAddressElements(), 5000);
+
+      logger.info("Size on queueOnServer2:: {}, elements={}", queueOnServer2.getPagingStore().getAddressSize(), queueOnServer2.getPagingStore().getAddressElements());
+      logger.info("Size on SNF:: {}, elements={}", snfreplica.getPagingStore().getAddressSize(), snfreplica.getPagingStore().getAddressElements());
+
+      server.start();
+      Wait.assertTrue(server::isStarted);
+
+      Queue queueOnServer1 = locateQueue(server, getQueueName());
+      assertFalse(loggerHandler.findText("AMQ222214"));
+
+      Wait.assertEquals(0L, snfreplica.getPagingStore()::getAddressElements);
+      Wait.assertEquals(0L, snfreplica.getPagingStore()::getAddressSize);
+
+      Wait.assertEquals(NUMBER_OF_MESSAGES, queueOnServer1::getMessageCount, 2000);
+      Wait.assertEquals(NUMBER_OF_MESSAGES, queueOnServer1::getMessageCount);
+      Wait.assertEquals(NUMBER_OF_MESSAGES, queueOnServer2::getMessageCount);
+
+      assertSame(snfreplica, server_2.locateQueue(replica.getMirrorSNF()));
+   }
+
+}
\ No newline at end of file
