@@ -19,7 +19,7 @@ package org.apache.activemq.artemis.tests.integration.cluster.distribution;
 import org.apache.activemq.artemis.core.config.ha.SharedStoreBackupPolicyConfiguration;
 import org.apache.activemq.artemis.core.server.cluster.impl.MessageLoadBalancingType;
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class SymmetricClusterWithBackupTest extends SymmetricClusterTest {
 
@@ -234,7 +234,8 @@ public class SymmetricClusterWithBackupTest extends SymmetricClusterTest {
    }
 
    @Override
-   public void _testStartStopServers() throws Exception {
+   @Test
+   public void testStartStopServers() throws Exception {
       setupCluster();
 
       startServers();
