@@ -16,6 +16,11 @@
  */
 package org.apache.activemq.artemis.tests.integration.cluster.failover;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import java.io.File;
 import java.io.RandomAccessFile;
 import java.nio.ByteBuffer;
@@ -52,9 +57,8 @@ import org.apache.activemq.artemis.tests.integration.cluster.util.TestableServer
 import org.apache.activemq.artemis.tests.util.TransportConfigurationUtils;
 import org.apache.activemq.artemis.utils.ReusableLatch;
 import org.apache.activemq.artemis.utils.UUID;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class BackupSyncJournalTest extends FailoverTestBase {
 
@@ -78,7 +82,7 @@ public class BackupSyncJournalTest extends FailoverTestBase {
    protected final FailoverWaiter failoverWaiter = new FailoverWaiter();
 
    @Override
-   @Before
+   @BeforeEach
    public void setUp() throws Exception {
       startBackupServer = false;
       super.setUp();
@@ -86,26 +90,26 @@ public class BackupSyncJournalTest extends FailoverTestBase {
       locator = (ServerLocatorInternal) getServerLocator().setBlockOnNonDurableSend(true).setBlockOnDurableSend(true).setReconnectAttempts(15).setRetryInterval(200);
       sessionFactory = createSessionFactoryAndWaitForTopology(locator, 1);
       sessionFactory.addFailoverListener(failoverWaiter);
-      syncDelay = new BackupSyncDelay(backupServer, liveServer);
+      syncDelay = new BackupSyncDelay(backupServer, primaryServer);
    }
 
    @Test
    public void testNodeID() throws Exception {
       startBackupFinishSyncing();
-      assertTrue("must be running", backupServer.isStarted());
-      assertEquals("backup and live should have the same nodeID", liveServer.getServer().getNodeID(), backupServer.getServer().getNodeID());
+      assertTrue(backupServer.isStarted(), "must be running");
+      assertEquals(primaryServer.getServer().getNodeID(), backupServer.getServer().getNodeID(), "backup and primary should have the same nodeID");
    }
 
    @Test
    public void testReserveFileIdValuesOnBackup() throws Exception {
       final int totalRounds = 5;
       createProducerSendSomeMessages();
-      JournalImpl messageJournal = getMessageJournalFromServer(liveServer);
+      JournalImpl messageJournal = getMessageJournalFromServer(primaryServer);
       for (int i = 0; i < totalRounds; i++) {
          messageJournal.forceMoveNextFile();
          sendMessages(session, producer, n_msgs);
       }
-      Queue queue = liveServer.getServer().locateQueue(ADDRESS);
+      Queue queue = primaryServer.getServer().locateQueue(ADDRESS);
       PagingStore store = queue.getPageSubscription().getPagingStore();
 
       // in case of paging I must close the current page otherwise we will get a pending counter
@@ -139,20 +143,20 @@ public class BackupSyncJournalTest extends FailoverTestBase {
          store.forceAnotherPage();
       }
 
-      Set<Pair<Long, Integer>> liveIds = getFileIds(messageJournal);
+      Set<Pair<Long, Integer>> primaryIds = getFileIds(messageJournal);
       int size = messageJournal.getFileSize();
-      PagingStore ps = liveServer.getServer().getPagingManager().getPageStore(ADDRESS);
+      PagingStore ps = primaryServer.getServer().getPagingManager().getPageStore(ADDRESS);
       if (ps.getPageSizeBytes() == PAGE_SIZE) {
-         assertTrue("isStarted", ps.isStarted());
-         assertFalse("start paging should return false, because we expect paging to be running", ps.startPaging());
+         assertTrue(ps.isStarted(), "isStarted");
+         assertFalse(ps.startPaging(), "start paging should return false, because we expect paging to be running");
       }
       finishSyncAndFailover();
 
-      assertEquals("file sizes must be the same", size, backupMsgJournal.getFileSize());
+      assertEquals(size, backupMsgJournal.getFileSize(), "file sizes must be the same");
       Set<Pair<Long, Integer>> backupIds = getFileIds(backupMsgJournal);
 
       int total = 0;
-      for (Pair<Long, Integer> pair : liveIds) {
+      for (Pair<Long, Integer> pair : primaryIds) {
          total += pair.getB();
       }
       int totalBackup = 0;
@@ -171,7 +175,7 @@ public class BackupSyncJournalTest extends FailoverTestBase {
       session.start();
       ClientConsumer consumer = session.createConsumer(ADDRESS);
       ClientMessage msg = consumer.receiveImmediate();
-      assertNull("there should be no more messages to receive! " + msg, msg);
+      assertNull(msg, "there should be no more messages to receive! " + msg);
       consumer.close();
       session.commit();
 
@@ -199,7 +203,7 @@ public class BackupSyncJournalTest extends FailoverTestBase {
          receiveMsgsInRange(0, n_msgs);
          assertNoMoreMessages();
       } catch (AssertionError error) {
-         printJournal(liveServer);
+         printJournal(primaryServer);
          printJournal(backupServer);
          // test failed
          throw error;
@@ -221,10 +225,10 @@ public class BackupSyncJournalTest extends FailoverTestBase {
    protected void finishSyncAndFailover() throws Exception {
       syncDelay.deliverUpToDateMsg();
       waitForRemoteBackup(sessionFactory, BACKUP_WAIT_TIME, true, backupServer.getServer());
-      assertFalse("should not be initialized", backupServer.getServer().isActive());
+      assertFalse(backupServer.getServer().isActive(), "should not be initialized");
 
       crash(session);
-      assertTrue("backup initialized", backupServer.getServer().waitForActivation(5, TimeUnit.SECONDS));
+      assertTrue(backupServer.getServer().waitForActivation(5, TimeUnit.SECONDS), "backup initialized");
 
       assertNodeIdWasSaved();
    }
@@ -235,14 +239,14 @@ public class BackupSyncJournalTest extends FailoverTestBase {
     * @throws InterruptedException
     */
    private void assertNodeIdWasSaved() throws Exception {
-      assertTrue("backup initialized", backupServer.getServer().waitForActivation(5, TimeUnit.SECONDS));
+      assertTrue(backupServer.getServer().waitForActivation(5, TimeUnit.SECONDS), "backup initialized");
 
       // assert that nodeID was saved (to the right file!)
 
       String journalDirectory = backupConfig.getJournalDirectory();
 
       File serverLockFile = new File(journalDirectory, "server.lock");
-      assertTrue("server.lock must exist!\n " + serverLockFile, serverLockFile.exists());
+      assertTrue(serverLockFile.exists(), "server.lock must exist!\n " + serverLockFile);
       RandomAccessFile raFile = new RandomAccessFile(serverLockFile, "r");
       try {
          // verify the nodeID was written correctly
@@ -250,13 +254,13 @@ public class BackupSyncJournalTest extends FailoverTestBase {
          final int size = 16;
          ByteBuffer id = ByteBuffer.allocateDirect(size);
          int read = channel.read(id, 3);
-         assertEquals("tried to read " + size + " bytes", size, read);
+         assertEquals(size, read, "tried to read " + size + " bytes");
          byte[] bytes = new byte[16];
          id.position(0);
          id.get(bytes);
          UUID uuid = new UUID(UUID.TYPE_TIME_BASED, bytes);
-         SimpleString storedNodeId = new SimpleString(uuid.toString());
-         assertEquals("nodeId must match", backupServer.getServer().getNodeID(), storedNodeId);
+         SimpleString storedNodeId = SimpleString.of(uuid.toString());
+         assertEquals(backupServer.getServer().getNodeID(), storedNodeId, "nodeId must match");
       } finally {
          raFile.close();
       }
@@ -265,7 +269,7 @@ public class BackupSyncJournalTest extends FailoverTestBase {
    @Test
    public void testMessageSyncSimple() throws Exception {
       createProducerSendSomeMessages();
-      startBackupCrashLive();
+      startBackupCrashPrimary();
       receiveMsgsInRange(0, n_msgs);
       assertNoMoreMessages();
    }
@@ -278,7 +282,7 @@ public class BackupSyncJournalTest extends FailoverTestBase {
    @Test
    public void testFailBack() throws Exception {
       createProducerSendSomeMessages();
-      startBackupCrashLive();
+      startBackupCrashPrimary();
       receiveMsgsInRange(0, n_msgs);
       assertNoMoreMessages();
 
@@ -287,30 +291,30 @@ public class BackupSyncJournalTest extends FailoverTestBase {
       assertNoMoreMessages();
 
       sendMessages(session, producer, 2 * n_msgs);
-      assertFalse("must NOT be a backup", liveServer.getServer().getHAPolicy().isBackup());
-      adaptLiveConfigForReplicatedFailBack(liveServer);
-      FileMoveManager liveMoveManager = new FileMoveManager(liveServer.getServer().getConfiguration().getJournalLocation(), -1);
-      liveServer.getServer().lockActivation();
+      assertFalse(primaryServer.getServer().getHAPolicy().isBackup(), "must NOT be a backup");
+      adaptPrimaryConfigForReplicatedFailBack(primaryServer);
+      FileMoveManager primaryMoveManager = new FileMoveManager(primaryServer.getServer().getConfiguration().getJournalLocation(), -1);
+      primaryServer.getServer().lockActivation();
       try {
-         liveServer.start();
-         assertTrue("must have become a backup", liveServer.getServer().getHAPolicy().isBackup());
-         Assert.assertEquals(0, liveMoveManager.getNumberOfFolders());
+         primaryServer.start();
+         assertTrue(primaryServer.getServer().getHAPolicy().isBackup(), "must have become a backup");
+         assertEquals(0, primaryMoveManager.getNumberOfFolders());
       } finally {
-         liveServer.getServer().unlockActivation();
+         primaryServer.getServer().unlockActivation();
       }
-      waitForServerToStart(liveServer.getServer());
-      liveServer.getServer().waitForActivation(10, TimeUnit.SECONDS);
-      Assert.assertEquals(1, liveMoveManager.getNumberOfFolders());
-      assertTrue("must be active now", !liveServer.getServer().getHAPolicy().isBackup());
+      waitForServerToStart(primaryServer.getServer());
+      primaryServer.getServer().waitForActivation(10, TimeUnit.SECONDS);
+      assertEquals(1, primaryMoveManager.getNumberOfFolders());
+      assertTrue(!primaryServer.getServer().getHAPolicy().isBackup(), "must be active now");
 
-      assertTrue("Fail-back must initialize live!", liveServer.getServer().waitForActivation(15, TimeUnit.SECONDS));
-      assertFalse("must be LIVE!", liveServer.getServer().getHAPolicy().isBackup());
+      assertTrue(primaryServer.getServer().waitForActivation(15, TimeUnit.SECONDS), "Fail-back must initialize primary!");
+      assertFalse(primaryServer.getServer().getHAPolicy().isBackup(), "must be primary!");
       int i = 0;
       while (!backupServer.isStarted() && i++ < 100) {
          Thread.sleep(100);
       }
       assertTrue(backupServer.getServer().isStarted());
-      assertTrue(liveServer.getServer().isStarted());
+      assertTrue(primaryServer.getServer().isStarted());
       receiveMsgsInRange(0, 2 * n_msgs);
       assertNoMoreMessages();
    }
@@ -319,7 +323,7 @@ public class BackupSyncJournalTest extends FailoverTestBase {
    public void testMessageSync() throws Exception {
       createProducerSendSomeMessages();
       receiveMsgsInRange(0, n_msgs / 2);
-      startBackupCrashLive();
+      startBackupCrashPrimary();
       receiveMsgsInRange(n_msgs / 2, n_msgs);
       assertNoMoreMessages();
    }
@@ -328,9 +332,9 @@ public class BackupSyncJournalTest extends FailoverTestBase {
    public void testRemoveAllMessageWithPurgeOnNoConsumers() throws Exception {
       final boolean purgeOnNoConsumers = true;
       createProducerSendSomeMessages();
-      liveServer.getServer().locateQueue(ADDRESS).setPurgeOnNoConsumers(purgeOnNoConsumers);
-      assertEquals(n_msgs, ((QueueControl) liveServer.getServer().getManagementService().getResource(ResourceNames.QUEUE + ADDRESS.toString())).removeAllMessages());
-      startBackupCrashLive();
+      primaryServer.getServer().locateQueue(ADDRESS).setPurgeOnNoConsumers(purgeOnNoConsumers);
+      assertEquals(n_msgs, ((QueueControl) primaryServer.getServer().getManagementService().getResource(ResourceNames.QUEUE + ADDRESS.toString())).removeAllMessages());
+      startBackupCrashPrimary();
       assertNoMoreMessages();
    }
 
@@ -338,15 +342,15 @@ public class BackupSyncJournalTest extends FailoverTestBase {
    public void testReceiveAllMessagesWithPurgeOnNoConsumers() throws Exception {
       final boolean purgeOnNoConsumers = true;
       createProducerSendSomeMessages();
-      liveServer.getServer().locateQueue(ADDRESS).setPurgeOnNoConsumers(purgeOnNoConsumers);
+      primaryServer.getServer().locateQueue(ADDRESS).setPurgeOnNoConsumers(purgeOnNoConsumers);
       receiveMsgsInRange(0, n_msgs);
-      startBackupCrashLive();
+      startBackupCrashPrimary();
       assertNoMoreMessages();
    }
 
-   private void startBackupCrashLive() throws Exception {
-      assertFalse("backup is started?", backupServer.isStarted());
-      liveServer.removeInterceptor(syncDelay);
+   private void startBackupCrashPrimary() throws Exception {
+      assertFalse(backupServer.isStarted(), "backup is started?");
+      primaryServer.removeInterceptor(syncDelay);
       backupServer.start();
       waitForBackup(sessionFactory, BACKUP_WAIT_TIME);
       failoverWaiter.reset();
@@ -355,12 +359,12 @@ public class BackupSyncJournalTest extends FailoverTestBase {
       //for some system the retryAttempts and retryInterval may be too small
       //so that during failover all attempts have failed before the backup
       //server is fully activated.
-      assertTrue("Session didn't failover, the maxRetryAttempts and retryInterval may be too small", failoverWaiter.waitFailoverComplete());
+      assertTrue(failoverWaiter.waitFailoverComplete(), "Session didn't failover, the maxRetryAttempts and retryInterval may be too small");
    }
 
    protected void createProducerSendSomeMessages() throws ActiveMQException {
       session = addClientSession(sessionFactory.createSession(true, true));
-      session.createQueue(new QueueConfiguration(ADDRESS));
+      session.createQueue(QueueConfiguration.of(ADDRESS));
       if (producer != null)
          producer.close();
       producer = addClientProducer(session.createProducer(ADDRESS));
@@ -404,13 +408,13 @@ public class BackupSyncJournalTest extends FailoverTestBase {
    }
 
    @Override
-   protected TransportConfiguration getAcceptorTransportConfiguration(boolean live) {
-      return TransportConfigurationUtils.getInVMAcceptor(live);
+   protected TransportConfiguration getAcceptorTransportConfiguration(boolean primary) {
+      return TransportConfigurationUtils.getInVMAcceptor(primary);
    }
 
    @Override
-   protected TransportConfiguration getConnectorTransportConfiguration(boolean live) {
-      return TransportConfigurationUtils.getInVMConnector(live);
+   protected TransportConfiguration getConnectorTransportConfiguration(boolean primary) {
+      return TransportConfigurationUtils.getInVMConnector(primary);
    }
 
    private class FailoverWaiter implements FailoverEventListener {
