@@ -1,18 +1,23 @@
 /*
- * Copyright 2009 Red Hat, Inc.
- * Red Hat licenses this file to you under the Apache License, version
- * 2.0 (the "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *    http://www.apache.org/licenses/LICENSE-2.0
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
- * implied.  See the License for the specific language governing
- * permissions and limitations under the License.
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
-
 package org.apache.activemq.artemis.tests.integration.cluster.failover;
 
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import java.lang.invoke.MethodHandles;
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -47,11 +52,10 @@ import org.apache.activemq.artemis.core.server.cluster.impl.MessageLoadBalancing
 import org.apache.activemq.artemis.tests.util.Wait;
 import org.apache.activemq.artemis.spi.core.protocol.RemotingConnection;
 import org.apache.activemq.artemis.utils.network.NetUtil;
-import org.apache.activemq.artemis.utils.network.NetUtilResource;
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Rule;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -65,10 +69,7 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
 
    private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
-   @Rule
-   public NetUtilResource netUtilResource = new NetUtilResource();
-
-   @BeforeClass
+   @BeforeAll
    public static void start() {
       NetUtil.skipIfNotSudo();
    }
@@ -78,15 +79,21 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
 
    private int beforeTime;
 
+   @BeforeEach
    @Override
    public void setUp() throws Exception {
       NetUtil.netUp(LIVE_IP);
       super.setUp();
    }
 
+   @AfterEach
    @Override
    public void tearDown() throws Exception {
-      super.tearDown();
+      try {
+         super.tearDown();
+      } finally {
+         NetUtil.cleanup();
+      }
    }
 
    @Override
@@ -158,14 +165,14 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
       final AtomicInteger sentMessages = new AtomicInteger(0);
       final AtomicInteger blockedAt = new AtomicInteger(0);
 
-      Assert.assertTrue(NetUtil.checkIP(LIVE_IP));
+      assertTrue(NetUtil.checkIP(LIVE_IP));
       Map<String, Object> params = new HashMap<>();
       params.put(TransportConstants.HOST_PROP_NAME, LIVE_IP);
       TransportConfiguration tc = createTransportConfiguration(true, false, params);
 
       final AtomicInteger countSent = new AtomicInteger(0);
 
-      liveServer.addInterceptor(new Interceptor() {
+      primaryServer.addInterceptor(new Interceptor() {
          @Override
          public boolean intercept(Packet packet, RemotingConnection connection) throws ActiveMQException {
             //logger.debug("Received {}", packet);
@@ -176,7 +183,7 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
                      NetUtil.netDown(LIVE_IP);
                      logger.debug("Blocking traffic");
                      // Thread.sleep(3000); // this is important to let stuff to block
-                     liveServer.crash(true, false);
+                     primaryServer.crash(true, false);
                   } catch (Exception e) {
                      e.printStackTrace();
                   }
@@ -225,7 +232,7 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
 
       ClientSession sessionProducer = createSession(sfProducer, true, true, 0);
 
-      sessionProducer.createQueue(new QueueConfiguration(FailoverTestBase.ADDRESS));
+      sessionProducer.createQueue(QueueConfiguration.of(FailoverTestBase.ADDRESS));
 
       ClientProducer producer = sessionProducer.createProducer(FailoverTestBase.ADDRESS);
 
@@ -293,7 +300,7 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
          latchReceived.countDown();
       }
 
-      Assert.assertTrue(latchReceived.await(1, TimeUnit.MINUTES));
+      assertTrue(latchReceived.await(1, TimeUnit.MINUTES));
 
       running.set(false);
 
@@ -318,7 +325,7 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
       final AtomicInteger sentMessages = new AtomicInteger(0);
       final AtomicInteger blockedAt = new AtomicInteger(0);
 
-      Assert.assertTrue(NetUtil.checkIP(LIVE_IP));
+      assertTrue(NetUtil.checkIP(LIVE_IP));
       Map<String, Object> params = new HashMap<>();
       params.put(TransportConstants.HOST_PROP_NAME, LIVE_IP);
       TransportConfiguration tc = createTransportConfiguration(true, false, params);
@@ -357,7 +364,7 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
 
       ClientSession sessionProducer = createSession(sfProducer, true, true, 0);
 
-      sessionProducer.createQueue(new QueueConfiguration(FailoverTestBase.ADDRESS));
+      sessionProducer.createQueue(QueueConfiguration.of(FailoverTestBase.ADDRESS));
 
       ClientProducer producer = sessionProducer.createProducer(FailoverTestBase.ADDRESS);
 
@@ -389,7 +396,7 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
                         if (received == 300) {
                            logger.debug("Shutting down IP");
                            NetUtil.netDown(LIVE_IP);
-                           liveServer.crash(true, false);
+                           primaryServer.crash(true, false);
                         }
                         logger.debug("Received {}", received);
                         sessionConsumer.commit();
@@ -435,7 +442,7 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
          latchReceived.countDown();
       }
 
-      Assert.assertTrue(latchReceived.await(1, TimeUnit.MINUTES));
+      assertTrue(latchReceived.await(1, TimeUnit.MINUTES));
 
       running.set(false);
 
@@ -447,7 +454,7 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
       final AtomicInteger sentMessages = new AtomicInteger(0);
       final AtomicInteger blockedAt = new AtomicInteger(0);
 
-      Assert.assertTrue(NetUtil.checkIP(LIVE_IP));
+      assertTrue(NetUtil.checkIP(LIVE_IP));
       Map<String, Object> params = new HashMap<>();
       params.put(TransportConstants.HOST_PROP_NAME, LIVE_IP);
       TransportConfiguration tc = createTransportConfiguration(true, false, params);
@@ -456,7 +463,7 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
 
       final CountDownLatch latchDown = new CountDownLatch(1);
 
-      liveServer.addInterceptor(new Interceptor() {
+      primaryServer.addInterceptor(new Interceptor() {
          @Override
          public boolean intercept(Packet packet, RemotingConnection connection) throws ActiveMQException {
             //logger.debug("Received {}", packet);
@@ -535,16 +542,16 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
 
       t.start();
 
-      Assert.assertTrue(latchDown.await(1, TimeUnit.MINUTES));
+      assertTrue(latchDown.await(1, TimeUnit.MINUTES));
 
       Thread.sleep(1000);
 
       logger.debug("Server crashed now!!!");
 
-      liveServer.crash(true, false);
+      primaryServer.crash(true, false);
 
       try {
-         Assert.assertTrue(latchCreated.await(5, TimeUnit.MINUTES));
+         assertTrue(latchCreated.await(5, TimeUnit.MINUTES));
 
       } finally {
          running.set(false);
@@ -558,7 +565,7 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
       final AtomicInteger sentMessages = new AtomicInteger(0);
       final AtomicInteger blockedAt = new AtomicInteger(0);
 
-      Assert.assertTrue(NetUtil.checkIP(LIVE_IP));
+      assertTrue(NetUtil.checkIP(LIVE_IP));
       Map<String, Object> params = new HashMap<>();
       params.put(TransportConstants.HOST_PROP_NAME, LIVE_IP);
       TransportConfiguration tc = createTransportConfiguration(true, false, params);
@@ -567,7 +574,7 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
 
       final CountDownLatch latchBlocked = new CountDownLatch(1);
 
-      liveServer.addInterceptor(new Interceptor() {
+      primaryServer.addInterceptor(new Interceptor() {
          @Override
          public boolean intercept(Packet packet, RemotingConnection connection) throws ActiveMQException {
             //logger.debug("Received {}", packet);
@@ -639,7 +646,7 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
 
       final ClientSession sessionProducer = createSession(sfProducer, true, true, 0);
 
-      sessionProducer.createQueue(new QueueConfiguration(FailoverTestBase.ADDRESS));
+      sessionProducer.createQueue(QueueConfiguration.of(FailoverTestBase.ADDRESS));
 
       final ClientProducer producer = sessionProducer.createProducer(FailoverTestBase.ADDRESS);
 
@@ -670,9 +677,9 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
 
       t.start();
 
-      Assert.assertTrue(latchBlocked.await(1, TimeUnit.MINUTES));
+      assertTrue(latchBlocked.await(1, TimeUnit.MINUTES));
 
-      Assert.assertTrue(failing.await(1, TimeUnit.MINUTES));
+      assertTrue(failing.await(1, TimeUnit.MINUTES));
 
       for (int i = 0; i < 5; i++) {
          for (Thread tint : setThread) {
@@ -681,9 +688,9 @@ public class NetworkFailureFailoverTest extends FailoverTestBase {
          Thread.sleep(500);
       }
 
-      liveServer.crash(true, false);
+      primaryServer.crash(true, false);
 
-      Assert.assertTrue(messagesSentlatch.await(3, TimeUnit.MINUTES));
+      assertTrue(messagesSentlatch.await(3, TimeUnit.MINUTES));
 
       running.set(false);
 
