@@ -16,6 +16,10 @@
  */
 package org.apache.activemq.artemis.tests.integration.mqtt5.spec.controlpackets;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import org.apache.activemq.artemis.api.core.SimpleString;
 import org.apache.activemq.artemis.core.protocol.mqtt.MQTTReasonCodes;
 import org.apache.activemq.artemis.tests.integration.mqtt5.MQTT5TestSupport;
@@ -24,7 +28,8 @@ import org.eclipse.paho.mqttv5.client.IMqttToken;
 import org.eclipse.paho.mqttv5.client.MqttAsyncClient;
 import org.eclipse.paho.mqttv5.common.MqttSubscription;
 import org.eclipse.paho.mqttv5.common.packet.MqttUnsubAck;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
 
 /**
  * The broker doesn't send any "Reason String" or "User Property" in the UNSUBACK packet for any reason. Therefore, these are not tested here:
@@ -35,10 +40,6 @@ import org.junit.Test;
 
 public class UnsubAckTests extends MQTT5TestSupport {
 
-   public UnsubAckTests(String protocol) {
-      super(protocol);
-   }
-
    /*
     * [MQTT-3.11.3-1] The order of Reason Codes in the UNSUBACK packet MUST match the order of Topic Filters in the
     * UNSUBSCRIBE packet.
@@ -46,13 +47,14 @@ public class UnsubAckTests extends MQTT5TestSupport {
     * [MQTT-3.11.3-2] The Server sending the UNSUBACK packet MUST use one of the UNSUBSCRIBE Reason Code values for each
     * Topic Filter received.
     */
-   @Test(timeout = DEFAULT_TIMEOUT)
+   @Test
+   @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testUnsubscribeAck() throws Exception {
       final int SUBSCRIPTION_COUNT = 10;
       final String TOPIC = RandomUtil.randomString();
       SimpleString[] topicNames = new SimpleString[SUBSCRIPTION_COUNT];
       for (int i = 0; i < SUBSCRIPTION_COUNT; i++) {
-         topicNames[i] = new SimpleString(i + "-" + TOPIC);
+         topicNames[i] = SimpleString.of(i + "-" + TOPIC);
       }
 
       MqttAsyncClient consumer = createAsyncPahoClient("consumer");
