@@ -16,6 +16,13 @@
  */
 package org.apache.activemq.artemis.tests.integration.paging;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+
 import javax.jms.Connection;
 import javax.jms.ConnectionFactory;
 import javax.jms.DeliveryMode;
@@ -50,13 +57,14 @@ import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
 import org.apache.activemq.artemis.tests.util.CFUtil;
 import org.apache.activemq.artemis.tests.util.Wait;
 import org.apache.activemq.artemis.utils.SizeAwareMetric;
-import org.jboss.logging.Logger;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import java.lang.invoke.MethodHandles;
 
 public class MaxMessagesPagingTest extends ActiveMQTestBase {
 
-   private static final Logger logger = Logger.getLogger(MaxMessagesPagingTest.class);
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
    protected static final int PAGE_MAX = 100 * 1024;
    protected static final int PAGE_SIZE = 10 * 1024;
@@ -64,7 +72,7 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
 
    @Test
    public void testGlobalMaxMessages() throws Exception {
-      final SimpleString ADDRESS = new SimpleString("testGlobalMaxMessages");
+      final SimpleString ADDRESS = SimpleString.of("testGlobalMaxMessages");
       clearDataRecreateServerDirs();
 
       Configuration config = createDefaultInVMConfig();
@@ -85,7 +93,7 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
 
       ClientSession session = sf.createSession(null, null, false, true, true, false, 0);
 
-      session.createQueue(new QueueConfiguration(ADDRESS).setAddress(ADDRESS));
+      session.createQueue(QueueConfiguration.of(ADDRESS).setAddress(ADDRESS));
 
       ClientProducer producer = session.createProducer(ADDRESS);
 
@@ -117,7 +125,7 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
 
       for (int i = 0; i < 30; i++) {
          message = consumer.receive(5000);
-         Assert.assertNotNull(message);
+         assertNotNull(message);
          message.acknowledge();
       }
       session.commit();
@@ -145,8 +153,8 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
       SizeAwareMetric globalSizeMetric = PagingManagerTestAccessor.globalSizeAwareMetric(server.getPagingManager());
 
       // this is validating the test is actually validating paging after over elements
-      Assert.assertTrue(globalSizeMetric.isOverElements());
-      Assert.assertFalse(globalSizeMetric.isOverSize());
+      assertTrue(globalSizeMetric.isOverElements());
+      assertFalse(globalSizeMetric.isOverSize());
 
       session.close();
    }
@@ -175,12 +183,12 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
       ClientSession session = sf.createSession(null, null, false, true, true, false, 0);
 
       for (int adr = 1; adr <= 2; adr++) {
-         SimpleString address = new SimpleString(baseAddress + adr);
-         session.createQueue(new QueueConfiguration(address).setAddress(address));
+         SimpleString address = SimpleString.of(baseAddress + adr);
+         session.createQueue(QueueConfiguration.of(address).setAddress(address));
       }
 
       for (int adr = 1; adr <= 2; adr++) {
-         SimpleString address = new SimpleString(baseAddress + adr);
+         SimpleString address = SimpleString.of(baseAddress + adr);
          ClientProducer producer = session.createProducer(address);
 
          ClientMessage message = null;
@@ -208,8 +216,8 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
       SizeAwareMetric globalSizeMetric = PagingManagerTestAccessor.globalSizeAwareMetric(server.getPagingManager());
 
       // this is validating the test is actually validating paging after over elements
-      Assert.assertTrue(globalSizeMetric.isOverElements());
-      Assert.assertFalse(globalSizeMetric.isOverSize());
+      assertTrue(globalSizeMetric.isOverElements());
+      assertFalse(globalSizeMetric.isOverSize());
 
       session.close();
    }
@@ -241,12 +249,12 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
       ClientSession session = sf.createSession(null, null, false, true, true, false, 0);
 
       for (int adr = 1; adr <= 2; adr++) {
-         SimpleString address = new SimpleString(baseAddress + adr);
-         session.createQueue(new QueueConfiguration(address).setAddress(address));
+         SimpleString address = SimpleString.of(baseAddress + adr);
+         session.createQueue(QueueConfiguration.of(address).setAddress(address));
       }
 
       for (int adr = 1; adr <= 1; adr++) {
-         SimpleString address = new SimpleString(baseAddress + adr);
+         SimpleString address = SimpleString.of(baseAddress + adr);
          ClientProducer producer = session.createProducer(address);
 
          ClientMessage message = null;
@@ -263,7 +271,7 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
             if (i >= 4) {
                Wait.assertTrue(queue.getPagingStore()::isPaging);
             } else {
-               Assert.assertFalse(queue.getPagingStore().isPaging());
+               assertFalse(queue.getPagingStore().isPaging());
             }
          }
       }
@@ -296,8 +304,8 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
       ClientSession session = sf.createSession(null, null, false, true, true, false, 0);
 
       for (int adr = 0; adr < 11; adr++) {
-         SimpleString address = new SimpleString(baseAddress + adr);
-         session.createQueue(new QueueConfiguration(address).setAddress(address));
+         SimpleString address = SimpleString.of(baseAddress + adr);
+         session.createQueue(QueueConfiguration.of(address).setAddress(address));
          ClientProducer producer = session.createProducer(address);
 
          ClientMessage message = null;
@@ -316,7 +324,7 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
          if (adr >= 9) {
             Wait.assertTrue(queue.getPagingStore()::isPaging);
          } else {
-            Assert.assertFalse(queue.getPagingStore().isPaging());
+            assertFalse(queue.getPagingStore().isPaging());
          }
       }
    }
@@ -365,7 +373,7 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
 
 
       server.addAddressInfo(new AddressInfo(ADDRESS).addRoutingType(RoutingType.ANYCAST));
-      server.createQueue(new QueueConfiguration(ADDRESS).setRoutingType(RoutingType.ANYCAST));
+      server.createQueue(QueueConfiguration.of(ADDRESS).setRoutingType(RoutingType.ANYCAST));
 
       ConnectionFactory factory = CFUtil.createConnectionFactory(protocol, "tcp://localhost:61616");
 
@@ -378,9 +386,6 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
 
       Queue queue = server.locateQueue(ADDRESS);
 
-      AssertionLoggerHandler.startCapture();
-      runAfter(() -> AssertionLoggerHandler.stopCapture());
-
       for (int repeat = 0; repeat < 5; repeat++) {
          boolean durable = repeat % 2 == 0;
 
@@ -395,15 +400,13 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
 
          Wait.assertEquals(MESSAGE_COUNT, queue::getMessageCount);
 
-         AssertionLoggerHandler.clear();
-
-         try {
+         try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler(true)) {
             producer.send(session.createTextMessage("should fail"));
             if (durable) {
-               Assert.fail(("supposed to fail"));
+               fail(("supposed to fail"));
             } else {
                // in case of async send, the exception will not propagate to the client, and we should still check the logger on that case
-               Wait.assertTrue(() -> AssertionLoggerHandler.findText("is full")); // my intention was to assert for "AMQ229102" howerver openwire is not using the code here
+               Wait.assertTrue(() -> loggerHandler.findTrace("is full")); // my intention was to assert for "AMQ229102" howerver openwire is not using the code here
             }
          } catch (Exception expected) {
          }
@@ -412,11 +415,11 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
 
          for (int i = 0; i < 10; i++) {
             TextMessage message = (TextMessage) consumer.receive(1000);
-            Assert.assertNotNull(message);
-            Assert.assertEquals("OK", message.getText());
+            assertNotNull(message);
+            assertEquals("OK", message.getText());
          }
 
-         Assert.assertNull(consumer.receiveNoWait());
+         assertNull(consumer.receiveNoWait());
 
          consumer.close();
          producer.close();
@@ -462,10 +465,9 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
 
    private void internalBlockMaxMessages(String protocolSend, String protocolReceive, ActiveMQServer server, boolean global) throws Exception {
 
-      final int MESSAGES = 1000;
+      final int MESSAGES = 1200;
 
-      logger.info("\n********************************************************************************\nSending " + protocolSend + ", Receiving " + protocolReceive +
-                     "\n********************************************************************************");
+      logger.info("\n{}\nSending {}, Receiving {}\n{}", "*".repeat(80), protocolSend, protocolReceive, "*".repeat(80));
 
       final String ADDRESS = "FAIL_MAX_MESSAGES_" + protocolSend + "_" + protocolReceive;
 
@@ -479,7 +481,7 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
       server.getAddressSettingsRepository().addMatch(ADDRESS, set);
 
       server.addAddressInfo(new AddressInfo(ADDRESS).addRoutingType(RoutingType.ANYCAST));
-      server.createQueue(new QueueConfiguration(ADDRESS).setRoutingType(RoutingType.ANYCAST));
+      server.createQueue(QueueConfiguration.of(ADDRESS).setRoutingType(RoutingType.ANYCAST));
 
       ConnectionFactory factorySend = CFUtil.createConnectionFactory(protocolSend, "tcp://localhost:61616");
       Connection connSend = factorySend.createConnection();
@@ -491,46 +493,46 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
       runAfter(connSend::close); // not using closeable because OPENWIRE might not support it depending on the version
       runAfter(connReceive::close); // not using closeable because OPENWIRE might not support it depending on the version
 
-      AssertionLoggerHandler.startCapture();
-      runAfter(() -> AssertionLoggerHandler.stopCapture());
-
       ExecutorService executorService = Executors.newSingleThreadExecutor();
       runAfter(executorService::shutdownNow);
 
-      CountDownLatch done = new CountDownLatch(1);
-      executorService.execute(() -> {
-         try {
-            Session session = connSend.createSession(false, Session.AUTO_ACKNOWLEDGE);
-            MessageProducer producer = session.createProducer(session.createQueue(ADDRESS));
-            producer.setDeliveryMode(DeliveryMode.PERSISTENT);
-            for (int i = 0; i < MESSAGES; i++) {
-               producer.send(session.createTextMessage("OK!" + i));
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
+         CountDownLatch done = new CountDownLatch(1);
+         executorService.execute(() -> {
+            try {
+               Session session = connSend.createSession(false, Session.AUTO_ACKNOWLEDGE);
+               MessageProducer producer = session.createProducer(session.createQueue(ADDRESS));
+               producer.setDeliveryMode(protocolSend.equals("OPENWIRE") ? DeliveryMode.PERSISTENT : DeliveryMode.NON_PERSISTENT);
+               for (int i = 0; i < MESSAGES; i++) {
+                  logger.debug("Sending {} protocol {}", i, protocolSend);
+                  producer.send(session.createTextMessage("OK!" + i));
+               }
+               session.close();
+            } catch (Exception e) {
+               // e.printStackTrace();
             }
-            session.close();
-         } catch (Exception e) {
-            e.printStackTrace();
-         }
 
-         done.countDown();
-      });
+            done.countDown();
+         });
 
-      Wait.assertTrue(() -> AssertionLoggerHandler.findText("AMQ222183"), 5000, 10); //unblock
-      Assert.assertFalse(AssertionLoggerHandler.findText("AMQ221046")); // should not been unblocked
+         Wait.assertTrue(() -> loggerHandler.findText("AMQ222183"), 5000, 10); //unblock
+         assertFalse(loggerHandler.findText("AMQ221046")); // should not been unblocked
 
-      AssertionLoggerHandler.clear();
-
-      Assert.assertFalse(done.await(100, TimeUnit.MILLISECONDS));
-
-      Session sessionReceive = connReceive.createSession(false, Session.AUTO_ACKNOWLEDGE);
-      MessageConsumer consumer = sessionReceive.createConsumer(sessionReceive.createQueue(ADDRESS));
-      for (int i = 0; i < MESSAGES; i++) {
-         TextMessage message = (TextMessage) consumer.receive(5000);
-         Assert.assertNotNull(message);
-         Assert.assertEquals("OK!" + i, message.getText());
+         assertFalse(done.await(200, TimeUnit.MILLISECONDS));
       }
-      sessionReceive.close();
 
-      Wait.assertTrue(() -> AssertionLoggerHandler.findText("AMQ221046"), 5000, 10); // unblock
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
+         Session sessionReceive = connReceive.createSession(false, Session.AUTO_ACKNOWLEDGE);
+         MessageConsumer consumer = sessionReceive.createConsumer(sessionReceive.createQueue(ADDRESS));
+         for (int i = 0; i < MESSAGES; i++) {
+            TextMessage message = (TextMessage) consumer.receive(5000);
+            assertNotNull(message);
+            assertEquals("OK!" + i, message.getText());
+         }
+         sessionReceive.close();
+
+         Wait.assertTrue(() -> loggerHandler.findText("AMQ221046"), 5000, 10); // unblock
+      }
    }
 
 
@@ -573,8 +575,7 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
 
       final int MESSAGES = 20;
 
-      logger.info("\n********************************************************************************\nSending " + protocolSend + ", Receiving " + protocolReceive +
-                     "\n********************************************************************************");
+      logger.info("\n{}\nSending {}, Receiving {}\n", "*".repeat(80), protocolSend, protocolReceive, "*".repeat(80));
 
       final String ADDRESS = "FAIL_MAX_MESSAGES_" + protocolSend + "_" + protocolReceive;
 
@@ -588,7 +589,7 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
       server.getAddressSettingsRepository().addMatch(ADDRESS, set);
 
       server.addAddressInfo(new AddressInfo(ADDRESS).addRoutingType(RoutingType.ANYCAST));
-      server.createQueue(new QueueConfiguration(ADDRESS).setRoutingType(RoutingType.ANYCAST));
+      server.createQueue(QueueConfiguration.of(ADDRESS).setRoutingType(RoutingType.ANYCAST));
 
       ConnectionFactory factorySend = CFUtil.createConnectionFactory(protocolSend, "tcp://localhost:61616");
       Connection connSend = factorySend.createConnection();
@@ -600,12 +601,8 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
       runAfter(connSend::close); // not using closeable because OPENWIRE might not support it depending on the version
       runAfter(connReceive::close); // not using closeable because OPENWIRE might not support it depending on the version
 
-      AssertionLoggerHandler.startCapture();
-      runAfter(() -> AssertionLoggerHandler.stopCapture());
-
       for (int repeat = 0; repeat < 5; repeat++) {
-         AssertionLoggerHandler.clear();
-         {
+         try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
             Session session = connSend.createSession(false, Session.AUTO_ACKNOWLEDGE);
             MessageProducer producer = session.createProducer(session.createQueue(ADDRESS));
             producer.setDeliveryMode(DeliveryMode.PERSISTENT);
@@ -613,25 +610,23 @@ public class MaxMessagesPagingTest extends ActiveMQTestBase {
                producer.send(session.createTextMessage("OK!" + i));
             }
             session.close();
-         }
 
-         if (repeat == 0) {
-            // the server will only log it on the first repeat as expected
-            Assert.assertTrue(AssertionLoggerHandler.findText("AMQ222039")); // dropped messages
-         }
+            if (repeat == 0) {
+               // the server will only log it on the first repeat as expected
+               assertTrue(loggerHandler.findText("AMQ222039")); // dropped messages
+            }
 
-         {
             Session sessionReceive = connReceive.createSession(false, Session.AUTO_ACKNOWLEDGE);
             MessageConsumer consumer = sessionReceive.createConsumer(sessionReceive.createQueue(ADDRESS));
             for (int i = 0; i < 10; i++) {
                TextMessage message = (TextMessage) consumer.receive(5000);
-               Assert.assertNotNull(message);
+               assertNotNull(message);
             }
-            Assert.assertNull(consumer.receiveNoWait());
+            assertNull(consumer.receiveNoWait());
             sessionReceive.close();
          }
       }
 
    }
 
-}
\ No newline at end of file
+}
