@@ -16,6 +16,12 @@
  */
 package org.apache.activemq.artemis.tests.integration.ssl;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLEngine;
 import java.util.Arrays;
@@ -45,24 +51,24 @@ import org.apache.activemq.artemis.core.remoting.impl.netty.TransportConstants;
 import org.apache.activemq.artemis.core.remoting.impl.ssl.SSLSupport;
 import org.apache.activemq.artemis.core.server.ActiveMQServer;
 import org.apache.activemq.artemis.logs.AssertionLoggerHandler;
+import org.apache.activemq.artemis.tests.extensions.parameterized.ParameterizedTestExtension;
+import org.apache.activemq.artemis.tests.extensions.parameterized.Parameters;
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
 import org.apache.activemq.artemis.utils.DefaultSensitiveStringCodec;
 import org.apache.activemq.artemis.utils.PasswordMaskingUtil;
 import org.apache.activemq.artemis.utils.RandomUtil;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
 /**
  * See the tests/security-resources/build.sh script for details on the security resources used.
  */
-@RunWith(value = Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
 
-   public static final SimpleString QUEUE = new SimpleString("QueueOverSSL");
+   public static final SimpleString QUEUE = SimpleString.of("QueueOverSSL");
 
    private boolean generateWarning;
    private boolean useKeystoreAlias;
@@ -77,7 +83,9 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
 
    private TransportConfiguration tc;
 
-   @Parameterized.Parameters(name = "storeProvider={0}, storeType={1}, generateWarning={2}, useKeystoreAlias={3}")
+   private AssertionLoggerHandler loggerHandler;
+
+   @Parameters(name = "storeProvider={0}, storeType={1}, generateWarning={2}, useKeystoreAlias={3}")
    public static Collection getParameters() {
       return Arrays.asList(new Object[][]{
          {TransportConstants.DEFAULT_KEYSTORE_PROVIDER, TransportConstants.DEFAULT_KEYSTORE_TYPE, false, false},
@@ -105,25 +113,28 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       CLIENT_SIDE_TRUSTSTORE = "server-ca-truststore." + suffix;
    }
 
-   @Before
-   public void validateLogging() {
-      AssertionLoggerHandler.startCapture();
+   @Override
+   @BeforeEach
+   public void setUp() throws Exception {
+      loggerHandler = new AssertionLoggerHandler();
+
+      super.setUp();
    }
 
-   @After
-   public void afterValidateLogging() {
+   @AfterEach
+   public void afterValidateLogging() throws Exception {
       try {
          if (this.generateWarning) {
-            Assert.assertTrue(AssertionLoggerHandler.findText("AMQ212080"));
+            assertTrue(loggerHandler.findText("AMQ212080"));
          } else {
-            Assert.assertFalse(AssertionLoggerHandler.findText("AMQ212080"));
+            assertFalse(loggerHandler.findText("AMQ212080"));
          }
       } finally {
-         AssertionLoggerHandler.stopCapture();
+         loggerHandler.close();
       }
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSL() throws Exception {
       createCustomSslServer();
       String text = RandomUtil.randomString();
@@ -137,7 +148,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       ClientSessionFactory sf = addSessionFactory(createSessionFactory(locator));
       ClientSession session = addClientSession(sf.createSession(false, true, true));
-      session.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
+      session.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
       ClientProducer producer = addClientProducer(session.createProducer(CoreClientOverOneWaySSLTest.QUEUE));
 
       ClientMessage message = createTextMessage(session, text);
@@ -147,11 +158,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       session.start();
 
       ClientMessage m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLwithSNI() throws Exception {
       createCustomSslServer("myhost\\.com");
       String text = RandomUtil.randomString();
@@ -166,7 +177,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       ClientSessionFactory sf = addSessionFactory(createSessionFactory(locator));
       ClientSession session = addClientSession(sf.createSession(false, true, true));
-      session.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
+      session.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
       ClientProducer producer = addClientProducer(session.createProducer(CoreClientOverOneWaySSLTest.QUEUE));
 
       ClientMessage message = createTextMessage(session, text);
@@ -176,11 +187,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       session.start();
 
       ClientMessage m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLwithSNINegative() throws Exception {
       createCustomSslServer("myhost\\.com");
 
@@ -200,7 +211,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       }
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLwithSNINegativeAndURL() throws Exception {
       createCustomSslServer("myhost\\.com");
 
@@ -220,7 +231,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       }
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLwithSNIOnlyOnTheClient() throws Exception {
       createCustomSslServer();
       String text = RandomUtil.randomString();
@@ -235,7 +246,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       ClientSessionFactory sf = addSessionFactory(createSessionFactory(locator));
       ClientSession session = addClientSession(sf.createSession(false, true, true));
-      session.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
+      session.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
       ClientProducer producer = addClientProducer(session.createProducer(CoreClientOverOneWaySSLTest.QUEUE));
 
       ClientMessage message = createTextMessage(session, text);
@@ -245,11 +256,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       session.start();
 
       ClientMessage m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLwithSNIOnlyOnTheBroker() throws Exception {
       createCustomSslServer("myhost\\.com");
       String text = RandomUtil.randomString();
@@ -263,7 +274,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       ClientSessionFactory sf = addSessionFactory(createSessionFactory(locator));
       ClientSession session = addClientSession(sf.createSession(false, true, true));
-      session.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
+      session.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
       ClientProducer producer = addClientProducer(session.createProducer(CoreClientOverOneWaySSLTest.QUEUE));
 
       ClientMessage message = createTextMessage(session, text);
@@ -273,11 +284,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       session.start();
 
       ClientMessage m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLwithTrustManagerPlugin() throws Exception {
       createCustomSslServer(null, null, false, null, TestTrustManagerFactoryPlugin.class.getName());
       String text = RandomUtil.randomString();
@@ -294,7 +305,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       assertTrue(TestTrustManagerFactoryPlugin.triggered.get());
 
       ClientSession session = addClientSession(sf.createSession(false, true, true));
-      session.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
+      session.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
       ClientProducer producer = addClientProducer(session.createProducer(CoreClientOverOneWaySSLTest.QUEUE));
 
       ClientMessage message = createTextMessage(session, text);
@@ -304,11 +315,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       session.start();
 
       ClientMessage m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLwithURL() throws Exception {
       createCustomSslServer();
       String text = RandomUtil.randomString();
@@ -324,7 +335,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
 
       ClientSessionFactory sf = addSessionFactory(createSessionFactory(locator));
       ClientSession session = addClientSession(sf.createSession(false, true, true));
-      session.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
+      session.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
       ClientProducer producer = addClientProducer(session.createProducer(CoreClientOverOneWaySSLTest.QUEUE));
 
       ClientMessage message = createTextMessage(session, text);
@@ -334,11 +345,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       session.start();
 
       ClientMessage m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLwithURLandMaskedPasswordProperty() throws Exception {
       createCustomSslServer();
       String text = RandomUtil.randomString();
@@ -358,7 +369,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocator(url));
       ClientSessionFactory sf = addSessionFactory(createSessionFactory(locator));
       ClientSession session = addClientSession(sf.createSession(false, true, true));
-      session.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
+      session.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
       ClientProducer producer = addClientProducer(session.createProducer(CoreClientOverOneWaySSLTest.QUEUE));
 
       ClientMessage message = createTextMessage(session, text);
@@ -368,11 +379,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       session.start();
 
       ClientMessage m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLwithURLandMaskedPasswordENCSyntax() throws Exception {
       createCustomSslServer();
       String text = RandomUtil.randomString();
@@ -394,7 +405,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
 //      ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocator("tcp://127.0.0.1:61616?sslEnabled=true;trustStoreProvider=" + storeProvider + ";trustStoreType=" + storeType + ";trustStorePath=" + CLIENT_SIDE_TRUSTSTORE + ";trustStorePassword=ENC(" + masked + ")"));
       ClientSessionFactory sf = addSessionFactory(createSessionFactory(locator));
       ClientSession session = addClientSession(sf.createSession(false, true, true));
-      session.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
+      session.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
       ClientProducer producer = addClientProducer(session.createProducer(CoreClientOverOneWaySSLTest.QUEUE));
 
       ClientMessage message = createTextMessage(session, text);
@@ -404,11 +415,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       session.start();
 
       ClientMessage m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLUsingDefaultSslContext() throws Exception {
       createCustomSslServer();
       String text = RandomUtil.randomString();
@@ -427,7 +438,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       ClientSessionFactory sf = addSessionFactory(createSessionFactory(locator));
       ClientSession session = addClientSession(sf.createSession(false, true, true));
-      session.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
+      session.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
       ClientProducer producer = addClientProducer(session.createProducer(CoreClientOverOneWaySSLTest.QUEUE));
 
       ClientMessage message = createTextMessage(session, text);
@@ -437,11 +448,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       session.start();
 
       ClientMessage m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLVerifyHost() throws Exception {
       createCustomSslServer();
       String text = RandomUtil.randomString();
@@ -456,7 +467,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       ClientSessionFactory sf = addSessionFactory(createSessionFactory(locator));
       ClientSession session = addClientSession(sf.createSession(false, true, true));
-      session.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
+      session.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
       ClientProducer producer = addClientProducer(session.createProducer(CoreClientOverOneWaySSLTest.QUEUE));
 
       ClientMessage message = createTextMessage(session, text);
@@ -466,11 +477,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       session.start();
 
       Message m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLVerifyHostNegative() throws Exception {
       createCustomSslServer(true);
       String text = RandomUtil.randomString();
@@ -492,10 +503,10 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       }
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLReloaded() throws Exception {
       createCustomSslServer();
-      server.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setRoutingType(RoutingType.ANYCAST).setDurable(false));
+      server.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setRoutingType(RoutingType.ANYCAST).setDurable(false));
       String text = RandomUtil.randomString();
 
       // create a valid SSL connection and keep it for use later
@@ -547,18 +558,18 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ClientConsumer consumer = addClientConsumer(session.createConsumer(CoreClientOverOneWaySSLTest.QUEUE));
       session.start();
       Message m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
       consumer.close();
 
       // use the existing connection to prove it wasn't lost when the acceptor was reloaded
       existingSession.start();
       m = existingConsumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLWithBadClientCipherSuite() throws Exception {
       createCustomSslServer();
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
@@ -571,13 +582,13 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       try {
          createSessionFactory(locator);
-         Assert.fail();
+         fail();
       } catch (ActiveMQNotConnectedException e) {
-         Assert.assertTrue(true);
+         assertTrue(true);
       }
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLWithBadServerCipherSuite() throws Exception {
       createCustomSslServer("myBadCipherSuite", null);
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
@@ -589,13 +600,13 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       try {
          createSessionFactory(locator);
-         Assert.fail();
+         fail();
       } catch (ActiveMQNotConnectedException e) {
-         Assert.assertTrue(true);
+         assertTrue(true);
       }
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLWithMismatchedCipherSuites() throws Exception {
       createCustomSslServer(getEnabledCipherSuites()[0], "TLSv1.2");
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
@@ -609,13 +620,13 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       try {
          createSessionFactory(locator);
-         Assert.fail();
+         fail();
       } catch (ActiveMQNotConnectedException e) {
-         Assert.assertTrue(true);
+         assertTrue(true);
       }
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLWithBadClientProtocol() throws Exception {
       createCustomSslServer();
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
@@ -628,13 +639,13 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       try {
          createSessionFactory(locator);
-         Assert.fail();
+         fail();
       } catch (ActiveMQNotConnectedException e) {
-         Assert.assertTrue(true);
+         assertTrue(true);
       }
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLWithBadServerProtocol() throws Exception {
       createCustomSslServer(null, "myBadProtocol");
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
@@ -646,13 +657,13 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       try {
          createSessionFactory(locator);
-         Assert.fail();
+         fail();
       } catch (ActiveMQNotConnectedException e) {
-         Assert.assertTrue(true);
+         assertTrue(true);
       }
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLWithMismatchedProtocols() throws Exception {
       createCustomSslServer(null, "TLSv1");
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
@@ -665,13 +676,13 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       try {
          createSessionFactory(locator);
-         Assert.fail();
+         fail();
       } catch (ActiveMQNotConnectedException e) {
-         Assert.assertTrue(true);
+         assertTrue(true);
       }
    }
 
-   @Test
+   @TestTemplate
    // http://www.oracle.com/technetwork/topics/security/poodlecve-2014-3566-2339408.html
    public void testPOODLE() throws Exception {
       createCustomSslServer(null, "SSLv3");
@@ -685,13 +696,13 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       try {
          createSessionFactory(locator);
-         Assert.fail();
+         fail();
       } catch (ActiveMQNotConnectedException e) {
-         Assert.assertTrue(true);
+         assertTrue(true);
       }
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLWithGoodClientCipherSuite() throws Exception {
       createCustomSslServer();
       String text = RandomUtil.randomString();
@@ -709,11 +720,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       try {
          sf = createSessionFactory(locator);
       } catch (ActiveMQNotConnectedException e) {
-         Assert.fail();
+         fail();
       }
 
       ClientSession session = sf.createSession(false, true, true);
-      session.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
+      session.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
       ClientProducer producer = session.createProducer(CoreClientOverOneWaySSLTest.QUEUE);
 
       ClientMessage message = createTextMessage(session, text);
@@ -723,11 +734,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       session.start();
 
       Message m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLWithGoodServerCipherSuite() throws Exception {
       createCustomSslServer(getSuitableCipherSuite(), null);
       String text = RandomUtil.randomString();
@@ -744,11 +755,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       try {
          sf = createSessionFactory(locator);
       } catch (ActiveMQNotConnectedException e) {
-         Assert.fail();
+         fail();
       }
 
       ClientSession session = sf.createSession(false, true, true);
-      session.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
+      session.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
       ClientProducer producer = session.createProducer(CoreClientOverOneWaySSLTest.QUEUE);
 
       ClientMessage message = createTextMessage(session, text);
@@ -758,11 +769,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       session.start();
 
       Message m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLWithGoodClientProtocol() throws Exception {
       createCustomSslServer();
       String text = RandomUtil.randomString();
@@ -778,13 +789,13 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ClientSessionFactory sf = null;
       try {
          sf = createSessionFactory(locator);
-         Assert.assertTrue(true);
+         assertTrue(true);
       } catch (ActiveMQNotConnectedException e) {
-         Assert.fail();
+         fail();
       }
 
       ClientSession session = sf.createSession(false, true, true);
-      session.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
+      session.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
       ClientProducer producer = session.createProducer(CoreClientOverOneWaySSLTest.QUEUE);
 
       ClientMessage message = createTextMessage(session, text);
@@ -794,11 +805,11 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       session.start();
 
       Message m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLWithGoodServerProtocol() throws Exception {
       createCustomSslServer(null, "TLSv1.2");
       String text = RandomUtil.randomString();
@@ -813,13 +824,13 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ClientSessionFactory sf = null;
       try {
          sf = createSessionFactory(locator);
-         Assert.assertTrue(true);
+         assertTrue(true);
       } catch (ActiveMQNotConnectedException e) {
-         Assert.fail();
+         fail();
       }
 
       ClientSession session = sf.createSession(false, true, true);
-      session.createQueue(new QueueConfiguration(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
+      session.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setDurable(false));
       ClientProducer producer = session.createProducer(CoreClientOverOneWaySSLTest.QUEUE);
 
       ClientMessage message = createTextMessage(session, text);
@@ -829,8 +840,8 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       session.start();
 
       Message m = consumer.receive(1000);
-      Assert.assertNotNull(m);
-      Assert.assertEquals(text, m.getBodyBuffer().readString());
+      assertNotNull(m);
+      assertEquals(text, m.getBodyBuffer().readString());
    }
 
    public String getSuitableCipherSuite() throws Exception {
@@ -878,7 +889,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       return engine.getEnabledCipherSuites();
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLWithoutTrustStore() throws Exception {
       createCustomSslServer();
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
@@ -886,7 +897,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       try {
          createSessionFactory(locator);
-         Assert.fail();
+         fail();
       } catch (ActiveMQNotConnectedException se) {
          //ok
       } catch (ActiveMQException e) {
@@ -894,7 +905,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       }
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLWithIncorrectTrustStorePassword() throws Exception {
       createCustomSslServer();
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
@@ -906,7 +917,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       try {
          ClientSessionFactory sf = createSessionFactory(locator);
-         Assert.fail();
+         fail();
       } catch (ActiveMQNotConnectedException se) {
          //ok
       } catch (ActiveMQException e) {
@@ -914,7 +925,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       }
    }
 
-   @Test
+   @TestTemplate
    public void testOneWaySSLWithIncorrectTrustStorePath() throws Exception {
       createCustomSslServer();
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
@@ -924,7 +935,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       ServerLocator locator = addServerLocator(ActiveMQClient.createServerLocatorWithoutHA(tc));
       try {
          ClientSessionFactory sf = createSessionFactory(locator);
-         Assert.fail();
+         fail();
       } catch (ActiveMQNotConnectedException se) {
          //ok
       } catch (ActiveMQException e) {
@@ -933,7 +944,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    }
 
    // see https://jira.jboss.org/jira/browse/HORNETQ-234
-   @Test
+   @TestTemplate
    public void testPlainConnectionToSSLEndpoint() throws Exception {
       createCustomSslServer();
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, false);
@@ -951,12 +962,6 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       }
    }
 
-   @Override
-   @Before
-   public void setUp() throws Exception {
-      super.setUp();
-   }
-
    private void createCustomSslServer() throws Exception {
       createCustomSslServer(null, null);
    }
