@@ -1,31 +1,36 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with
+ * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * <p>
- * http://www.apache.org/licenses/LICENSE-2.0
- * <p>
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.activemq.artemis.tests.unit;
 
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
+
 import com.google.common.collect.ImmutableSet;
 import com.google.common.reflect.ClassPath;
-import org.apache.activemq.artemis.utils.RandomUtil;
-import org.jboss.logging.Logger;
-import org.junit.Assume;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
 
+import org.apache.activemq.artemis.tests.extensions.parameterized.ParameterizedTestExtension;
+import org.apache.activemq.artemis.tests.extensions.parameterized.Parameters;
+import org.apache.activemq.artemis.utils.RandomUtil;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.Timeout;
+import org.junit.jupiter.api.extension.ExtendWith;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import java.lang.invoke.MethodHandles;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;
 import java.lang.reflect.Parameter;
@@ -35,11 +40,11 @@ import java.util.Collection;
 import java.util.Comparator;
 import java.util.List;
 
-@RunWith(value = Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public class AllClassesTest {
-   private static final Logger log = Logger.getLogger(AllClassesTest.class);
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
-   @Parameterized.Parameters(name = "classInfo={0}")
+   @Parameters(name = "classInfo={0}")
    public static Collection getParameters() {
       List<Class> parameters = new ArrayList<>();
       ClassLoader classLoader = AllClassesTest.class.getClassLoader();
@@ -56,7 +61,7 @@ public class AllClassesTest {
                      parameters.add(loadedClass);
                   }
                } catch (Throwable loadThrowable) {
-                  log.debug("cannot load " + classInfo.getName() + ": " + loadThrowable);
+                  logger.debug("cannot load {} : {}", classInfo.getName(), loadThrowable);
                }
             }
          }
@@ -65,7 +70,7 @@ public class AllClassesTest {
 
          return parameters;
       } catch (Exception e) {
-         log.warn("Exception on loading all classes: " + e);
+         logger.warn("Exception on loading all classes: {}", e.toString());
       }
 
       return parameters;
@@ -78,27 +83,28 @@ public class AllClassesTest {
    }
 
 
-   @Test
+   @TestTemplate
+   @Timeout(3)
    public void testToString() {
       Object targetInstance = null;
 
       try {
          targetInstance = newInstance(targetClass);
       } catch (Throwable t) {
-         log.debug("Error creating a new instance of " + targetClass.getName() + ": " + t);
+         logger.debug("Error creating a new instance of {}: {}", targetClass.getName(), t);
       }
 
-      Assume.assumeTrue("Cannot create " + targetClass.getName(), targetInstance != null);
+      assumeTrue(targetInstance != null, "Cannot create " + targetClass.getName());
 
       try {
          String targetOutput = targetInstance.toString();
-         log.debug("targetOutput: " + targetOutput);
+         logger.debug("targetOutput: {}", targetOutput);
       } finally {
          if (targetInstance instanceof AutoCloseable) {
             try {
                ((AutoCloseable)targetInstance).close();
             } catch (Throwable t) {
-               log.debug("Error closing the instance of " + targetClass.getName() + ": " + t);
+               logger.debug("Error closing the instance of {}: {}", targetClass.getName(), t);
             }
          }
       }
@@ -140,7 +146,9 @@ public class AllClassesTest {
          try {
             return targetConstructor.newInstance(initArgs.toArray());
          } catch (Throwable t) {
-            log.debug("Cannot construct " + targetClass.getName() + ": " + t);
+            if (logger.isDebugEnabled()) {
+               logger.debug("Cannot construct {}: {}", targetClass.getName(), t);
+            }
          }
       }
 
