@@ -16,6 +16,14 @@
  */
 package org.apache.activemq.artemis.tests.unit.util;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+
+import java.lang.invoke.MethodHandles;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -32,33 +40,47 @@ import java.util.concurrent.atomic.AtomicInteger;
 import io.netty.util.collection.LongObjectHashMap;
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
 import org.apache.activemq.artemis.utils.RandomUtil;
-import org.apache.activemq.artemis.utils.collections.NodeStore;
 import org.apache.activemq.artemis.utils.collections.LinkedListImpl;
 import org.apache.activemq.artemis.utils.collections.LinkedListIterator;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.apache.activemq.artemis.utils.collections.NodeStore;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 public class LinkedListTest extends ActiveMQTestBase {
 
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
+
+   private int scans = 0;
    private LinkedListImpl<Integer> list;
 
    @Override
-   @Before
+   @BeforeEach
    public void setUp() throws Exception {
       super.setUp();
-      list = new LinkedListImpl<>(integerComparator);
+      list = new LinkedListImpl<>(integerComparator) {
+         @Override
+         protected boolean addSortedScan(Integer e) {
+            scans++;
+            return super.addSortedScan(e);
+         }
+      };
    }
 
    Comparator<Integer> integerComparator = new Comparator<Integer>() {
       @Override
       public int compare(Integer o1, Integer o2) {
+         logger.trace("Compare {} and {}", o1, o2);
          if (o1.intValue() == o2.intValue()) {
+            logger.trace("Return 0");
             return 0;
          }
          if (o2.intValue() > o1.intValue()) {
+            logger.trace("o2 is greater than, returning 1");
             return 1;
          } else {
+            logger.trace("o2 is lower than, returning -1");
             return -1;
          }
       }
@@ -66,35 +88,104 @@ public class LinkedListTest extends ActiveMQTestBase {
 
    @Test
    public void addSorted() {
+      assertEquals(0, scans); // sanity check
 
       list.addSorted(1);
       list.addSorted(3);
       list.addSorted(2);
       list.addSorted(0);
+
+      assertEquals(0, scans); // all adds were somewhat ordered, it shouldn't be doing any scans
+
       validateOrder(null);
-      Assert.assertEquals(4, list.size());
+      assertEquals(4, list.size());
 
    }
 
+   @Test
+   public void addSortedCachedLast() {
+      assertEquals(0, scans); // just a sanity check
+      list.addSorted(5);
+      list.addSorted(1);
+      list.addSorted(3);
+      list.addSorted(4);
+      list.addSorted(2);
+      list.addSorted(10);
+      list.addSorted(20);
+      list.addSorted(19);
+      list.addSorted(7);
+      list.addSorted(8);
+      assertEquals(0, scans); // no full scans should be done
+      assertEquals(1, (int)list.poll());
+      list.addSorted(9);
+      assertEquals(1, scans); // remove (poll) should clear the last added cache, a scan will be needed
+
+      printDebug();
+      validateOrder(null);
+   }
+
+   @Test
+   public void scanDirectionalTest() {
+      list.addSorted(9);
+      assertEquals(1, list.size());
+      list.addSorted(5);
+      assertEquals(2, list.size());
+      list.addSorted(6);
+      assertEquals(3, list.size());
+      list.addSorted(2);
+      assertEquals(4, list.size());
+      list.addSorted(7);
+      assertEquals(5, list.size());
+      list.addSorted(4);
+      assertEquals(6, list.size());
+      list.addSorted(8);
+      assertEquals(7, list.size());
+      list.addSorted(1);
+      assertEquals(8, list.size());
+      list.addSorted(10);
+      assertEquals(9, list.size());
+      list.addSorted(3);
+      assertEquals(10, list.size());
+      printDebug();
+      validateOrder(null);
+   }
+
+   private void printDebug() {
+      if (logger.isDebugEnabled()) {
+         logger.debug("**** list output:");
+         LinkedListIterator<Integer> integerIterator = list.iterator();
+         while (integerIterator.hasNext()) {
+            logger.debug("list {}", integerIterator.next());
+         }
+         integerIterator.close();
+      }
+   }
 
    @Test
    public void randomSorted() {
 
-      HashSet<Integer> values = new HashSet<>();
-      for (int i = 0; i < 1000; i++) {
+      int elements = 10_000;
 
-         int value = RandomUtil.randomInt();
-         if (!values.contains(value)) {
-            values.add(value);
-            list.addSorted(value);
+      HashSet<Integer> values = new HashSet<>();
+      for (int i = 0; i < elements; i++) {
+         for (;;) { // a retry loop, if a random give me the same value twice, I would retry
+            int value = RandomUtil.randomInt();
+            if (!values.contains(value)) { // validating if the random is repeated or not, and retrying otherwise
+               if (logger.isDebugEnabled()) {
+                  logger.debug("Adding {}", value);
+               }
+               values.add(value);
+               list.addSorted(value);
+               break;
+            }
          }
       }
 
-      Assert.assertEquals(values.size(), list.size());
+      assertEquals(values.size(), list.size());
 
       validateOrder(values);
 
-      Assert.assertEquals(0, values.size());
+      assertEquals(0, values.size());
 
    }
 
@@ -102,11 +193,11 @@ public class LinkedListTest extends ActiveMQTestBase {
       Integer previous = null;
       LinkedListIterator<Integer> integerIterator = list.iterator();
       while (integerIterator.hasNext()) {
-
          Integer value = integerIterator.next();
+         logger.debug("Reading {}", value);
          if (previous != null) {
-            Assert.assertTrue(value + " should be > " + previous, integerComparator.compare(previous, value) > 0);
-            Assert.assertTrue(value + " should be > " + previous, value.intValue() > previous.intValue());
+            assertTrue(integerComparator.compare(previous, value) > 0, value + " should be > " + previous);
+            assertTrue(value.intValue() > previous.intValue(), value + " should be > " + previous);
          }
 
          if (values != null) {
@@ -213,19 +304,19 @@ public class LinkedListTest extends ActiveMQTestBase {
             for (int add = 0; add < 1000; add++) {
                final ObservableNode o = new ObservableNode(null, add);
                objs.addTail(o);
-               assertNotNull("prev", o.publicPrev());
-               assertNull("next", o.publicNext());
+               assertNotNull(o.publicPrev(), "prev");
+               assertNull(o.publicNext(), "next");
             }
 
             for (int remove = 0; remove < 1000; remove++) {
                final ObservableNode next = iter.next();
                assertNotNull(next);
-               assertNotNull("prev", next.publicPrev());
+               assertNotNull(next.publicPrev(), "prev");
                //it's ok to check this, because we've *at least* 100 elements left!
-               assertNotNull("next", next.publicNext());
+               assertNotNull(next.publicNext(), "next");
                iter.remove();
-               assertNull("prev", next.publicPrev());
-               assertNull("next", next.publicNext());
+               assertNull(next.publicPrev(), "prev");
+               assertNull(next.publicNext(), "next");
             }
             assertEquals(100, objs.size());
          }
@@ -234,8 +325,8 @@ public class LinkedListTest extends ActiveMQTestBase {
             final ObservableNode next = iter.next();
             assertNotNull(next);
             iter.remove();
-            assertNull("prev", next.publicPrev());
-            assertNull("next", next.publicNext());
+            assertNull(next.publicPrev(), "prev");
+            assertNull(next.publicNext(), "next");
          }
       }
       assertEquals(0, objs.size());
@@ -273,30 +364,30 @@ public class LinkedListTest extends ActiveMQTestBase {
             objs.addTail(o);
          }
 
-         Assert.assertEquals(1000, objs.size());
+         assertEquals(1000, objs.size());
 
          if (deferSupplier) {
-            Assert.assertEquals(0, nodeStore.size());
+            assertEquals(0, nodeStore.size());
             objs.setNodeStore(nodeStore);
          } else {
             // clear the ID supplier
             objs.clearID();
             // and redo it
-            Assert.assertEquals(0, nodeStore.size());
+            assertEquals(0, nodeStore.size());
             nodeStore = new ListNodeStore();
             objs.setNodeStore(nodeStore);
-            Assert.assertEquals(1000, objs.size());
+            assertEquals(1000, objs.size());
          }
 
-         Assert.assertEquals(1000, nodeStore.size());
+         assertEquals(1000, nodeStore.size());
 
          /** remove all even items */
          for (int i = 1; i <= 1000; i += 2) {
             objs.removeWithID(serverID, i);
          }
 
-         Assert.assertEquals(500, objs.size());
-         Assert.assertEquals(500, nodeStore.size());
+         assertEquals(500, objs.size());
+         assertEquals(500, nodeStore.size());
 
          Iterator<ObservableNode> iterator = objs.iterator();
 
@@ -304,17 +395,17 @@ public class LinkedListTest extends ActiveMQTestBase {
             int i = 2;
             while (iterator.hasNext()) {
                ObservableNode value = iterator.next();
-               Assert.assertEquals(i, value.id);
+               assertEquals(i, value.id);
                i += 2;
             }
          }
 
          for (int i = 2; i <= 1000; i += 2) {
-            Assert.assertNotNull(objs.removeWithID(serverID, i));
+            assertNotNull(objs.removeWithID(serverID, i));
          }
 
-         Assert.assertEquals(0, nodeStore.size());
-         Assert.assertEquals(0, objs.size());
+         assertEquals(0, nodeStore.size());
+         assertEquals(0, objs.size());
 
       }
    }
@@ -334,7 +425,7 @@ public class LinkedListTest extends ActiveMQTestBase {
          for (int i = 0; i < elements; i++) {
             objs.addHead(new ObservableNode(serverID, i));
          }
-         Assert.assertEquals(elements, objs.size());
+         assertEquals(elements, objs.size());
 
          CyclicBarrier barrier = new CyclicBarrier(2);
 
@@ -386,11 +477,11 @@ public class LinkedListTest extends ActiveMQTestBase {
             }
          });
 
-         Assert.assertTrue(latch.await(10, TimeUnit.SECONDS));
+         assertTrue(latch.await(10, TimeUnit.SECONDS));
 
-         Assert.assertEquals(0, objs.size());
+         assertEquals(0, objs.size());
 
-         Assert.assertEquals(0, errors.get());
+         assertEquals(0, errors.get());
       } finally {
          executor.shutdownNow();
       }
@@ -413,12 +504,12 @@ public class LinkedListTest extends ActiveMQTestBase {
          int removed = 0;
          for (countLoop = 0; countLoop <= 1000; countLoop++) {
             final ObservableNode obj = iter.next();
-            Assert.assertNotNull(obj);
+            assertNotNull(obj);
             if (countLoop == 500 || countLoop == 1000) {
-               assertNotNull("prev", obj.publicPrev());
+               assertNotNull(obj.publicPrev(), "prev");
                iter.remove();
-               assertNull("prev", obj.publicPrev());
-               assertNull("next", obj.publicNext());
+               assertNull(obj.publicPrev(), "prev");
+               assertNull(obj.publicNext(), "next");
                removed++;
             }
          }
@@ -433,7 +524,7 @@ public class LinkedListTest extends ActiveMQTestBase {
             assertNotNull(obj);
             countLoop++;
          }
-         Assert.assertEquals(expectedSize, countLoop);
+         assertEquals(expectedSize, countLoop);
       }
       // it's needed to add this line here because IBM JDK calls finalize on all objects in list
       // before previous assert is called and fails the test, this will prevent it
@@ -459,6 +550,25 @@ public class LinkedListTest extends ActiveMQTestBase {
       }
    }
 
+
+   @Test
+   public void testPeek() {
+      assertEquals(0, list.size());
+      assertNull(list.peek());
+      list.addTail(10);
+      assertEquals(10, (int)list.peek());
+      assertEquals(10, (int)list.poll());
+      assertNull(list.peek());
+      list.addTail(12);
+      assertEquals(12, (int)list.peek());
+      list.addHead(5);
+      assertEquals(5, (int)list.peek());
+      list.poll();
+      assertEquals(12, (int)list.peek());
+      list.poll();
+      assertNull(list.peek());
+   }
+
    @Test
    public void testAddHead() {
       int num = 10;
@@ -1429,7 +1539,7 @@ public class LinkedListTest extends ActiveMQTestBase {
       }
 
       for (int i = 0; i < 100; i++) {
-         Assert.assertEquals(i, list.get(i).intValue());
+         assertEquals(i, list.get(i).intValue());
       }
 
       boolean expectedException = false;
@@ -1440,7 +1550,7 @@ public class LinkedListTest extends ActiveMQTestBase {
          expectedException = true;
       }
 
-      Assert.assertTrue(expectedException);
+      assertTrue(expectedException);
    }
 
    @Test
